@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel.h
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: channel.h 5758 2015-04-02 18:26:29Z michael $
  */
 
 #ifndef INCLUDED_channel_h
@@ -68,7 +68,7 @@ struct Channel
   char topic[TOPICLEN + 1];
   char topic_info[USERHOST_REPLYLEN];
 
-  time_t channelts;
+  time_t creationtime;
   time_t topic_time;
   time_t last_knock;  /**< Don't allow knock to flood */
   time_t last_join_time;
@@ -85,7 +85,7 @@ struct Channel
 
   float number_joined;
 
-  char chname[CHANNELLEN + 1];
+  char name[CHANNELLEN + 1];
 };
 
 /*! \brief Membership structure */
@@ -103,10 +103,10 @@ struct Membership
 struct Ban
 {
   dlink_node node;
-  char *name;
-  char *user;
-  char *host;
-  char *who;
+  char name[NICKLEN + 1];
+  char user[USERLEN + 1];
+  char host[HOSTLEN + 1];
+  char who[NICKLEN + USERLEN + HOSTLEN + 3];
   size_t len;
   time_t when;
   struct irc_ssaddr addr;
@@ -120,12 +120,12 @@ extern struct event splitmode_event;
 extern int check_channel_name(const char *, const int);
 extern int can_send(struct Channel *, struct Client *, struct Membership *, const char *);
 extern int is_banned(const struct Channel *, const struct Client *);
-extern int can_join(struct Client *, struct Channel *, const char *);
+extern int can_join(struct Client *, const struct Channel *, const char *);
 extern int has_member_flags(const struct Membership *, const unsigned int);
 
 extern void channel_do_join(struct Client *, char *, char *);
 extern void channel_do_join_0(struct Client *);
-extern void channel_do_part(struct Client *, char *, char *);
+extern void channel_do_part(struct Client *, char *, const char *);
 extern void remove_ban(struct Ban *, dlink_list *);
 extern void channel_init(void);
 extern void add_user_to_channel(struct Channel *, struct Client *, unsigned int, int);
@@ -133,6 +133,7 @@ extern void remove_user_from_channel(struct Membership *);
 extern void channel_member_names(struct Client *, struct Channel *, int);
 extern void add_invite(struct Channel *, struct Client *);
 extern void del_invite(struct Channel *, struct Client *);
+extern void clear_invites(struct Channel *);
 extern void send_channel_modes(struct Client *, struct Channel *);
 extern void channel_modes(struct Channel *, struct Client *, char *, char *);
 extern void check_spambot_warning(struct Client *, const char *);
