@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.h
  * \brief Header including structures, macros and prototypes for client handling
- * \version $Id: client.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: client.h 5773 2015-04-04 15:42:35Z michael $
  */
 
 
@@ -53,7 +53,7 @@ struct MaskItem;
 #define REG_NEED_CAP     0x00000004U  /**< In middle of CAP negotiations */
 #define REG_INIT  (REG_NEED_USER|REG_NEED_NICK)
 
-#define ID_or_name(x,client_p)  ((IsCapable(client_p->from, CAP_TS6) && (x)->id[0]) ? (x)->id : (x)->name)
+#define ID_or_name(x,client_p)  ((IsServer(client_p->from) && (x)->id[0]) ? (x)->id : (x)->name)
 
 #define IsRegistered(x)         ((x)->status  > STAT_UNKNOWN)
 #define IsConnecting(x)         ((x)->status == STAT_CONNECTING)
@@ -82,7 +82,7 @@ struct MaskItem;
                                  (x)->handler = HasUMode(x, UMODE_OPER) ? \
                                  OPER_HANDLER : CLIENT_HANDLER; }
 
-#define MyConnect(x)            ((x)->localClient != NULL)
+#define MyConnect(x)            ((x)->connection != NULL)
 #define MyClient(x)             (MyConnect(x) && IsClient(x))
 
 /*
@@ -90,16 +90,14 @@ struct MaskItem;
  */
 #define TS_CURRENT      6  /**< Current TS protocol version */
 #define TS_MIN          6  /**< Minimum supported TS protocol version */
-#define TS_DOESTS       0x20000000
-#define DoesTS(x)       ((x)->tsinfo == TS_DOESTS)
-
 
 
 #define CAP_MULTI_PREFIX  0x00000001U
 #define CAP_AWAY_NOTIFY   0x00000002U
 #define CAP_UHNAMES       0x00000004U
+#define CAP_EXTENDED_JOIN 0x00000008U
 
-#define HasCap(x, y) ((x)->localClient->cap_active & (y))
+#define HasCap(x, y) ((x)->connection->cap_active & (y))
 
 
 /* housekeeping flags */
@@ -108,30 +106,27 @@ struct MaskItem;
 #define FLAGS_KILLED         0x00000004U  /**< Prevents "QUIT" from being sent for this */
 #define FLAGS_CLOSING        0x00000008U  /**< Set when closing to suppress errors */
 #define FLAGS_GOTID          0x00000010U  /**< Successful ident lookup achieved */
-#define FLAGS_NEEDID         0x00000020U  /**< auth{} block say must use ident return */
-#define FLAGS_SENDQEX        0x00000040U  /**< Sendq exceeded */
-#define FLAGS_IPHASH         0x00000080U  /**< Iphashed this client */
-#define FLAGS_MARK           0x00000100U  /**< Marked client */
-#define FLAGS_CANFLOOD       0x00000200U  /**< Client has the ability to flood */
-#define FLAGS_EXEMPTGLINE    0x00000400U  /**< Client can't be G-lined */
-#define FLAGS_EXEMPTKLINE    0x00000800U  /**< Client is exempt from kline */
-#define FLAGS_NOLIMIT        0x00001000U  /**< Client is exempt from limits */
-#define FLAGS_PING_COOKIE    0x00002000U  /**< PING Cookie */
-#define FLAGS_IP_SPOOFING    0x00004000U  /**< Client IP is spoofed */
-#define FLAGS_FLOODDONE      0x00008000U  /**< Flood grace period has been ended. */
-#define FLAGS_EOB            0x00010000U  /**< Server has sent us an EOB */
-#define FLAGS_HIDDEN         0x00020000U  /**< A hidden server. Not shown in /links */
-#define FLAGS_BLOCKED        0x00040000U  /**< Must wait for COMM_SELECT_WRITE */
-#define FLAGS_USERHOST       0x00080000U  /**< Client is in userhost hash */
-#define FLAGS_BURSTED        0x00100000U  /**< User was already bursted */
-#define FLAGS_EXEMPTRESV     0x00200000U  /**< Client is exempt from RESV */
-#define FLAGS_GOTUSER        0x00400000U  /**< If we received a USER command */
-#define FLAGS_FINISHED_AUTH  0x00800000U  /**< Client has been released from auth */
-#define FLAGS_FLOOD_NOTICED  0x01000000U  /**< Notice to opers about this flooder has been sent */
-#define FLAGS_SERVICE        0x02000000U  /**< Client/server is a network service */
-#define FLAGS_AUTH_SPOOF     0x04000000U  /**< User's hostname has been spoofed by an auth{} spoof */
-#define FLAGS_SSL            0x08000000U  /**< User is connected via TLS/SSL */
-#define FLAGS_SQUIT          0x10000000U
+#define FLAGS_SENDQEX        0x00000020U  /**< Sendq exceeded */
+#define FLAGS_IPHASH         0x00000040U  /**< Iphashed this client */
+#define FLAGS_MARK           0x00000080U  /**< Marked client */
+#define FLAGS_CANFLOOD       0x00000100U  /**< Client has the ability to flood */
+#define FLAGS_EXEMPTGLINE    0x00000200U  /**< Client can't be G-lined */
+#define FLAGS_EXEMPTKLINE    0x00000400U  /**< Client is exempt from kline */
+#define FLAGS_NOLIMIT        0x00000800U  /**< Client is exempt from limits */
+#define FLAGS_PING_COOKIE    0x00001000U  /**< PING Cookie */
+#define FLAGS_FLOODDONE      0x00002000U  /**< Flood grace period has been ended. */
+#define FLAGS_EOB            0x00004000U  /**< Server has sent us an EOB */
+#define FLAGS_HIDDEN         0x00008000U  /**< A hidden server. Not shown in /links */
+#define FLAGS_BLOCKED        0x00010000U  /**< Must wait for COMM_SELECT_WRITE */
+#define FLAGS_USERHOST       0x00020000U  /**< Client is in userhost hash */
+#define FLAGS_BURSTED        0x00040000U  /**< User was already bursted */
+#define FLAGS_EXEMPTRESV     0x00080000U  /**< Client is exempt from RESV */
+#define FLAGS_GOTUSER        0x00100000U  /**< If we received a USER command */
+#define FLAGS_FINISHED_AUTH  0x00200000U  /**< Client has been released from auth */
+#define FLAGS_FLOOD_NOTICED  0x00400000U  /**< Notice to opers about this flooder has been sent */
+#define FLAGS_SERVICE        0x00800000U  /**< Client/server is a network service */
+#define FLAGS_SSL            0x01000000U  /**< User is connected via TLS/SSL */
+#define FLAGS_SQUIT          0x02000000U
 
 #define HasFlag(x, y) ((x)->flags &   (y))
 #define AddFlag(x, y) ((x)->flags |=  (y))
@@ -141,7 +136,7 @@ struct MaskItem;
 
 /* umodes, settable flags */
 #define UMODE_SERVNOTICE   0x00000001U  /**< Server notices such as kill */
-#define UMODE_CCONN        0x00000002U  /**< Client Connections */
+#define UMODE_CCONN        0x00000002U  /**< Can see client connection notices */
 #define UMODE_REJ          0x00000004U  /**< Bot Rejections */
 #define UMODE_SKILL        0x00000008U  /**< Server Killed */
 #define UMODE_FULL         0x00000010U  /**< Full messages */
@@ -155,12 +150,12 @@ struct MaskItem;
 #define UMODE_CALLERID     0x00001000U  /**< Block unless caller id's */
 #define UMODE_SOFTCALLERID 0x00002000U  /**< Block unless on common channel */
 #define UMODE_UNAUTH       0x00004000U  /**< Show unauth connects here */
-#define UMODE_LOCOPS       0x00008000U  /**< Show locops */
+#define UMODE_LOCOPS       0x00008000U  /**< Can see LOCOPS messages */
 #define UMODE_DEAF         0x00010000U  /**< Don't receive channel messages */
 #define UMODE_REGISTERED   0x00020000U  /**< User has identified for that nick. */
 #define UMODE_REGONLY      0x00040000U  /**< Only registered nicks may PM */
-#define UMODE_HIDDEN       0x00080000U  /**< Operator status is hidden */
-#define UMODE_OPER         0x00100000U  /**< Operator */
+#define UMODE_HIDDEN       0x00080000U  /**< IRC operator status is hidden */
+#define UMODE_OPER         0x00100000U  /**< IRC operator */
 #define UMODE_ADMIN        0x00200000U  /**< Admin on server */
 #define UMODE_FARCONNECT   0x00400000U  /**< Can see remote client connects/exits */
 #define UMODE_HIDDENHOST   0x00800000U  /**< User's host is hidden */
@@ -200,12 +195,13 @@ struct MaskItem;
 #define OPER_FLAG_WALLOPS        0x00100000U  /**< Oper can use WALLOPS command */
 #define OPER_FLAG_LOCOPS         0x00200000U  /**< Oper can use LOCOPS command */
 #define OPER_FLAG_UNXLINE        0x00400000U  /**< Oper can use UNXLINE command */
+#define OPER_FLAG_OPME           0x00800000U  /**< Oper can use OPME command */
 
 
-#define HasOFlag(x, y) (MyConnect(x) ? (x)->localClient->operflags & (y) : 0)
-#define AddOFlag(x, y) ((x)->localClient->operflags |=  (y))
-#define DelOFlag(x, y) ((x)->localClient->operflags &= ~(y))
-#define ClrOFlag(x)    ((x)->localClient->operflags = 0)
+#define HasOFlag(x, y) (MyConnect(x) ? (x)->connection->operflags & (y) : 0)
+#define AddOFlag(x, y) ((x)->connection->operflags |=  (y))
+#define DelOFlag(x, y) ((x)->connection->operflags &= ~(y))
+#define ClrOFlag(x)    ((x)->connection->operflags = 0)
 
 
 
@@ -239,9 +235,6 @@ struct MaskItem;
 #define IsPingSent(x)           ((x)->flags & FLAGS_PINGSENT)
 #define ClearPingSent(x)        ((x)->flags &= ~FLAGS_PINGSENT)
 
-#define SetNeedId(x)            ((x)->flags |= FLAGS_NEEDID)
-#define IsNeedId(x)             ((x)->flags & FLAGS_NEEDID)
-
 #define SetGotId(x)             ((x)->flags |= FLAGS_GOTID)
 #define IsGotId(x)              ((x)->flags & FLAGS_GOTID)
 
@@ -253,8 +246,6 @@ struct MaskItem;
 #define SetExemptGline(x)       ((x)->flags |= FLAGS_EXEMPTGLINE)
 #define IsExemptResv(x)         ((x)->flags & FLAGS_EXEMPTRESV)
 #define SetExemptResv(x)        ((x)->flags |= FLAGS_EXEMPTRESV)
-#define SetIPSpoof(x)           ((x)->flags |= FLAGS_IP_SPOOFING)
-#define IsIPSpoof(x)            ((x)->flags & FLAGS_IP_SPOOFING)
 
 #define IsFloodDone(x)          ((x)->flags &  FLAGS_FLOODDONE)
 #define SetFloodDone(x)         ((x)->flags |= FLAGS_FLOODDONE)
@@ -272,6 +263,14 @@ enum addr_mask_type
   MASK_IP  /**< IP is masked. 255.255.255.255 is shown instead */
 };
 
+struct ServicesTag
+{
+  dlink_node node;
+  char *tag;
+  unsigned int numeric;
+  unsigned int umodes;
+};
+
 /*! \brief Server structure */
 struct Server
 {
@@ -296,12 +295,12 @@ struct ListTask
   char topic[TOPICLEN + 1];
 };
 
-/*! \brief LocalUser structure
+/*! \brief Connection structure
  *
  * Allocated only for local clients, that are directly connected
  * to \b this server with a socket.
  */
-struct LocalUser
+struct Connection
 {
   dlink_node   lclient_node;
 
@@ -313,7 +312,7 @@ struct LocalUser
   unsigned int operflags;     /**< IRC Operator privilege flags */
   unsigned int random_ping; /**< Holding a 32bit value used for PING cookies */
 
-  unsigned int serial;     /**< Used to enforce 1 send per nick */
+  uint64_t serial;     /**< Used to enforce 1 send per nick */
 
   time_t       lasttime;   /**< ...should be only LOCAL clients? --msa */
   time_t       firsttime;  /**< Time client was created */
@@ -378,7 +377,7 @@ struct Client
   dlink_node node;
   dlink_node lnode;             /**< Used for Server->servers/users */
 
-  struct LocalUser *localClient;
+  struct Connection *connection;
   struct Client    *hnext;      /**< For client hash table lookups by name */
   struct Client    *idhnext;    /**< For SID hash table lookups by sid */
   struct Server    *serv;       /**< ...defined, if this is a server */
@@ -395,11 +394,12 @@ struct Client
 
   dlink_list        whowas;
   dlink_list        channel;   /**< Chain of channel pointer blocks */
+  dlink_list        svstags;   /**< List of ServicesTag items */
 
   char away[AWAYLEN + 1]; /**< Client's AWAY message. Can be set/unset via AWAY command */
   char name[HOSTLEN + 1]; /**< Unique name for a client nick or host */
-  char svid[SVIDLEN + 1]; /**< Services ID */
   char id[IDLEN + 1];       /**< Client ID, unique ID per client */
+  char account[ACCOUNTLEN + 1]; /**< Services account */
 
   /*
    * client->username is the username from ident or the USER message,
@@ -445,10 +445,12 @@ extern dlink_list unknown_list;       /* unknown clients ON this server only
 extern dlink_list oper_list;          /* our opers, duplicated in local_client_list */
 
 extern int accept_message(struct Client *, struct Client *);
-extern unsigned int idle_time_get(const struct Client *, const struct Client *);
+extern unsigned int client_get_idle_time(const struct Client *, const struct Client *);
 extern struct split_nuh_item *find_accept(const char *, const char *,
                                           const char *, struct Client *,
                                           int (*)(const char *, const char *));
+extern void client_attach_svstag(struct Client *, unsigned int, const char *, const char *const);
+extern void client_clear_svstags(struct Client *);
 extern void del_accept(struct split_nuh_item *, struct Client *);
 extern void del_all_accepts(struct Client *);
 extern void exit_client(struct Client *, const char *);
