@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf.h
  * \brief A header for the configuration functions.
- * \version $Id: conf.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: conf.h 5775 2015-04-04 17:31:06Z michael $
  */
 
 #ifndef INCLUDED_s_conf_h
@@ -34,29 +34,27 @@
 
 #define CONF_NOREASON "<No reason supplied>"
 
-#define IsConfOperator(x)       ((x)->type == CONF_OPER)
 #define IsConfKill(x)           ((x)->type == CONF_KLINE)
 #define IsConfClient(x)         ((x)->type == CONF_CLIENT)
 #define IsConfGline(x)          ((x)->type == CONF_GLINE)
 
 /* MaskItem->flags */
-#define CONF_FLAGS_DO_IDENTD            0x00000001U
-#define CONF_FLAGS_NO_TILDE             0x00000004U
-#define CONF_FLAGS_NEED_IDENTD          0x00000008U
-#define CONF_FLAGS_EXEMPTKLINE          0x00000010U
-#define CONF_FLAGS_NOLIMIT              0x00000020U
-#define CONF_FLAGS_SPOOF_IP             0x00000040U
-#define CONF_FLAGS_SPOOF_NOTICE         0x00000080U
-#define CONF_FLAGS_REDIR                0x00000100U
-#define CONF_FLAGS_EXEMPTGLINE          0x00000200U
-#define CONF_FLAGS_CAN_FLOOD            0x00000400U
-#define CONF_FLAGS_NEED_PASSWORD        0x00000800U
-#define CONF_FLAGS_ALLOW_AUTO_CONN      0x00001000U
-#define CONF_FLAGS_ENCRYPTED            0x00002000U
-#define CONF_FLAGS_IN_DATABASE          0x00004000U
-#define CONF_FLAGS_EXEMPTRESV           0x00008000U
-#define CONF_FLAGS_SSL                  0x00010000U
-#define CONF_FLAGS_WEBIRC               0x00020000U
+#define CONF_FLAGS_NO_TILDE             0x00000001U
+#define CONF_FLAGS_NEED_IDENTD          0x00000002U
+#define CONF_FLAGS_EXEMPTKLINE          0x00000004U
+#define CONF_FLAGS_NOLIMIT              0x00000008U
+#define CONF_FLAGS_SPOOF_IP             0x00000010U
+#define CONF_FLAGS_SPOOF_NOTICE         0x00000020U
+#define CONF_FLAGS_REDIR                0x00000040U
+#define CONF_FLAGS_EXEMPTGLINE          0x00000080U
+#define CONF_FLAGS_CAN_FLOOD            0x00000100U
+#define CONF_FLAGS_NEED_PASSWORD        0x00000200U
+#define CONF_FLAGS_ALLOW_AUTO_CONN      0x00000400U
+#define CONF_FLAGS_ENCRYPTED            0x00000800U
+#define CONF_FLAGS_IN_DATABASE          0x00001000U
+#define CONF_FLAGS_EXEMPTRESV           0x00002000U
+#define CONF_FLAGS_SSL                  0x00004000U
+#define CONF_FLAGS_WEBIRC               0x00008000U
 
 /* Macros for struct MaskItem */
 #define IsConfWebIRC(x)           ((x)->flags & CONF_FLAGS_WEBIRC)
@@ -68,7 +66,6 @@
 #define IsConfExemptLimits(x)     ((x)->flags & CONF_FLAGS_NOLIMIT)
 #define IsConfExemptGline(x)      ((x)->flags & CONF_FLAGS_EXEMPTGLINE)
 #define IsConfExemptResv(x)       ((x)->flags & CONF_FLAGS_EXEMPTRESV)
-#define IsConfDoIdentd(x)         ((x)->flags & CONF_FLAGS_DO_IDENTD)
 #define IsConfDoSpoofIp(x)        ((x)->flags & CONF_FLAGS_SPOOF_IP)
 #define IsConfSpoofNotice(x)      ((x)->flags & CONF_FLAGS_SPOOF_NOTICE)
 #define IsConfAllowAutoConn(x)    ((x)->flags & CONF_FLAGS_ALLOW_AUTO_CONN)
@@ -168,6 +165,7 @@ struct MaskItem
   char              *spasswd;  /* Password to send. */
   char              *reason;
   char              *certfp;
+  char              *whois;
   char              *cipher_list;
   void              *rsa_public_key;
 };
@@ -183,7 +181,7 @@ struct exempt
   struct irc_ssaddr addr;
   int bits;
   int type;
-  int coid;
+  int country_id;
 };
 
 struct CidrItem
@@ -193,14 +191,14 @@ struct CidrItem
   unsigned int number_on_this_cidr;
 };
 
-struct
+struct conf_parser_context
 {
   unsigned int boot;
   unsigned int pass;
   FILE *conf_file;
-} conf_parser_ctx;
+};
 
-struct
+struct config_general_entry
 {
   const char *dpath;
   const char *mpath;
@@ -229,17 +227,16 @@ struct
   unsigned int warn_no_connect_block;
   unsigned int invisible_on_connect;
   unsigned int stats_e_disabled;
-  unsigned int stats_o_oper_only;
-  unsigned int stats_k_oper_only;
   unsigned int stats_i_oper_only;
+  unsigned int stats_k_oper_only;
+  unsigned int stats_m_oper_only;
+  unsigned int stats_o_oper_only;
   unsigned int stats_P_oper_only;
   unsigned int stats_u_oper_only;
   unsigned int short_motd;
   unsigned int no_oper_flood;
-  unsigned int true_no_oper_flood;
   unsigned int oper_pass_resv;
   unsigned int glines;
-  unsigned int hide_spoof_ips;
   unsigned int tkline_expire_notices;
   unsigned int opers_bypass_callerid;
   unsigned int ignore_bogus_ts;
@@ -260,9 +257,9 @@ struct
   unsigned int ping_cookie;
   unsigned int disable_auth;
   unsigned int cycle_on_host_change;
-} ConfigGeneral;
+};
 
-struct
+struct config_channel_entry
 {
   unsigned int disable_fake_channels;
   unsigned int invite_client_count;
@@ -272,13 +269,15 @@ struct
   unsigned int knock_delay_channel;
   unsigned int max_bans;
   unsigned int max_channels;
+  unsigned int default_join_flood_count;
+  unsigned int default_join_flood_time;
   unsigned int no_create_on_split;
   unsigned int no_join_on_split;
   unsigned int default_split_server_count;
   unsigned int default_split_user_count;
-} ConfigChannel;
+};
 
-struct
+struct config_serverhide_entry
 {
   char *hidden_name;
   unsigned int flatten_links;
@@ -289,9 +288,9 @@ struct
   unsigned int links_disabled;
   unsigned int hidden;
   unsigned int hide_server_ips;
-} ConfigServerHide;
+};
 
-struct
+struct config_serverinfo_entry
 {
 #ifdef HAVE_LIBCRYPTO
   const EVP_MD *message_digest_algorithm;
@@ -306,26 +305,26 @@ struct
   void *server_ctx;
   void *client_ctx;
   unsigned int hub;
-  unsigned int max_clients;
+  unsigned int default_max_clients;
   unsigned int max_nick_length;
   unsigned int max_topic_length;
   unsigned int specific_ipv4_vhost;
   unsigned int specific_ipv6_vhost;
   struct irc_ssaddr ip;
   struct irc_ssaddr ip6;
-} ConfigServerInfo;
+};
 
-struct
+struct config_admin_entry
 {
   char *name;
   char *description;
   char *email;
-} ConfigAdminInfo;
+};
 
-struct
+struct config_log_entry
 {
   unsigned int use_logging;
-} ConfigLog;
+};
 
 extern dlink_list flatten_links;
 extern dlink_list server_items;
@@ -336,6 +335,13 @@ extern dlink_list oconf_items;
 extern dlink_list service_items;
 extern dlink_list nresv_items;
 extern dlink_list cresv_items;
+extern struct conf_parser_context conf_parser_ctx;
+extern struct config_log_entry ConfigLog;
+extern struct config_general_entry ConfigGeneral;
+extern struct config_channel_entry ConfigChannel;
+extern struct config_serverhide_entry ConfigServerHide;
+extern struct config_serverinfo_entry ConfigServerInfo;
+extern struct config_admin_entry ConfigAdminInfo;
 
 extern int valid_wild_card_simple(const char *);
 extern int valid_wild_card(struct Client *, int, int, ...);
@@ -351,7 +357,7 @@ extern int check_client(struct Client *);
 extern void detach_conf(struct Client *, enum maskitem_type);
 extern struct MaskItem *find_conf_name(dlink_list *, const char *, enum maskitem_type);
 extern int conf_connect_allowed(struct irc_ssaddr *, int);
-extern char *oper_privs_as_string(const unsigned int);
+extern const char *oper_privs_as_string(const unsigned int);
 extern void split_nuh(struct split_nuh_item *);
 extern struct MaskItem *find_matching_name_conf(enum maskitem_type, const char *,
                                                 const char *, const char *, unsigned int);
@@ -361,7 +367,7 @@ extern void conf_free(struct MaskItem *);
 extern void yyerror(const char *);
 extern void conf_error_report(const char *);
 extern void cleanup_tklines(void *);
-extern int rehash(int);
+extern void conf_rehash(int);
 extern void lookup_confhost(struct MaskItem *);
 extern void conf_add_class_to_conf(struct MaskItem *, const char *);
 
@@ -381,5 +387,5 @@ extern int match_conf_password(const char *, const struct MaskItem *);
 
 #define CLEANUP_TKLINES_TIME 60
 
-extern void cluster_a_line(struct Client *, const char *, int, int, const char *,...);
+extern void cluster_a_line(struct Client *, const char *, unsigned int, unsigned int, const char *,...);
 #endif /* INCLUDED_s_conf_h */
