@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file
  * \brief Configuration managment for class{} blocks
- * \version $Id: conf_class.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: conf_class.h 5410 2015-01-24 19:12:28Z michael $
  */
 
 
@@ -65,9 +65,9 @@ struct ClassItem
 extern struct ClassItem *class_default;
 
 extern struct ClassItem *class_make(void);
-extern struct ClassItem *get_class_ptr(const dlink_list *const);
+extern const struct ClassItem *get_class_ptr(const dlink_list *const);
 extern const dlink_list *class_get_list(void);
-extern void class_free(struct ClassItem *);
+extern void class_free(struct ClassItem *const);
 extern void class_init(void);
 extern const char *get_client_class(const dlink_list *const);
 extern unsigned int get_client_ping(const dlink_list *const);
