@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file ircd.h
  * \brief A header for the ircd startup routines.
- * \version $Id: ircd.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: ircd.h 5613 2015-02-24 19:41:11Z michael $
  */
 
 
@@ -32,8 +32,9 @@
 #include "config.h"
 
 
-struct
+struct SetOptions
 {
+  unsigned int maxclients;
   unsigned int autoconn;      /* autoconn enabled for all servers? */
   int floodcount;    /* Number of messages in 1 second    */
   unsigned int joinfloodtime;
@@ -41,7 +42,7 @@ struct
   unsigned int ident_timeout; /* timeout for identd lookups        */
   int spam_num;
   unsigned int spam_time;
-} GlobalSetOptions;
+};
 
 /*
  * statistics structures
@@ -83,12 +84,12 @@ struct Counter
   unsigned int max_tot;       /* MAX global clients  */
   unsigned int max_loc_con;   /* MAX local connection count (clients + server) */
   unsigned int max_loc_cli;   /* XXX This is redundant - Max local client count */
-} Count;
+};
 
-struct
+struct ServerState_t
 {
   unsigned int foreground;
-} server_state;
+};
 
 
 #ifdef HAVE_LIBGEOIP
@@ -100,13 +101,16 @@ extern const char *serno;
 extern const char *ircd_version;
 extern const char *logFileName;
 extern const char *pidFileName;
-extern int dorehash;
-extern int doremotd;
-extern struct event event_write_links_file;
+extern unsigned int dorehash;
+extern unsigned int doremotd;
+extern struct Counter Count;
 extern struct ServerStatistics ServerStats;
+extern struct SetOptions GlobalSetOptions;
+extern struct ServerState_t server_state;
+extern struct event event_write_links_file;
 extern struct timeval SystemTime;
 #define CurrentTime SystemTime.tv_sec
-extern int unsigned default_server_capabs;
+extern unsigned int default_server_capabs;
 extern unsigned int splitmode;
 extern unsigned int splitchecking;
 extern unsigned int split_users;
