@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file list.h
  * \brief A header for the list manipulation routines.
- * \version $Id: list.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: list.h 5346 2015-01-11 12:41:14Z michael $
  */
 
 #ifndef INCLUDED_list_h
@@ -78,7 +78,7 @@ extern void dlinkAddTail(void *, dlink_node *, dlink_list *);
 extern void dlinkDelete(dlink_node *, dlink_list *);
 extern void dlinkMoveList(dlink_list *, dlink_list *);
 extern void dlink_move_node(dlink_node *, dlink_list *, dlink_list *);
-extern dlink_node *dlinkFind(dlink_list *, void *);
+extern dlink_node *dlinkFind(dlink_list *, const void *);
 extern dlink_node *dlinkFindDelete(dlink_list *, void *);
 extern dlink_node *make_dlink_node(void);
 #endif
