@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file send.h
  * \brief A header for the message sending functions.
- * \version $Id: send.h 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: send.h 5346 2015-01-11 12:41:14Z michael $
  */
 
 #ifndef INCLUDED_send_h
@@ -30,14 +30,6 @@
 #include "fdlist.h"
 #include "numeric.h"
 
-enum { NOCAPS = 0 };
-
-enum
-{
-  ALL_MEMBERS  = 0,
-  ONLY_SERVERS = 1
-};
-
 enum
 {
   L_ALL   = 0,
@@ -77,8 +69,8 @@ extern void sendto_channel_butone(struct Client *, struct Client *,
                                   const char *, ...) AFP(5,6);
 extern void sendto_common_channels_local(struct Client *, int, unsigned int,
                                          const char *, ...) AFP(4,5);
-extern void sendto_channel_local(unsigned int, int, struct Channel *,
-                                 const char *, ...) AFP(4,5);
+extern void sendto_channel_local(unsigned int, struct Channel *,
+                                 const char *, ...) AFP(3,4);
 extern void sendto_channel_local_butone(struct Client *, unsigned int, unsigned int, struct Channel *,
                                         const char *, ...) AFP(5,6);
 extern void sendto_server(struct Client *,
