@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_kill.c
  * \brief Includes required functions for processing the KILL command.
- * \version $Id: m_kill.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_kill.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -40,10 +40,17 @@
 #include "modules.h"
 
 
-/* mo_kill()
- *  parv[0] = command
- *  parv[1] = kill victim
- *  parv[2] = kill path
+/*! \brief KILL command handler
+ *
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = kill victim
+ *      - parv[2] = reason
  */
 static int
 mo_kill(struct Client *source_p, int parc, char *parv[])
@@ -76,9 +83,9 @@ mo_kill(struct Client *source_p, int parc, char *parv[])
      * rewrite the KILL for this new nickname--this keeps
      * servers in synch when nick change and kill collide
      */
-    if ((target_p = whowas_get_history(parv[1],
-                                (time_t)ConfigGeneral.kill_chase_time_limit))
-                                == NULL)
+    target_p = whowas_get_history(parv[1], (time_t)ConfigGeneral.kill_chase_time_limit);
+
+    if (!target_p)
     {
       sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, parv[1]);
       return 0;
@@ -133,12 +140,12 @@ mo_kill(struct Client *source_p, int parc, char *parv[])
    */
   if (!MyConnect(target_p))
   {
-    sendto_server(source_p, NOCAPS, NOCAPS, ":%s KILL %s :%s!%s!%s!%s (%s)",
+    sendto_server(source_p, 0, 0, ":%s KILL %s :%s!%s!%s!%s (%s)",
                   source_p->id, target_p->id, me.name, source_p->host,
                   source_p->username, source_p->name, reason);
 
     /*
-     * Set FLAGS_KILLED. This prevents exit_one_client from sending
+     * Set FLAGS_KILLED. This prevents exit_client() from sending
      * the unnecessary QUIT for this. (This flag should never be
      * set in any other place)
      */
@@ -150,10 +157,17 @@ mo_kill(struct Client *source_p, int parc, char *parv[])
   return 0;
 }
 
-/* ms_kill()
- *  parv[0] = command
- *  parv[1] = kill victim
- *  parv[2] = kill path and reason
+/*! \brief KILL command handler
+ *
+ * \param source_p Pointer to allocated Client struct from which the message
+ *                 originally comes from.  This can be a local or remote client.
+ * \param parc     Integer holding the number of supplied arguments.
+ * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
+ *                 pointers.
+ * \note Valid arguments for this command are:
+ *      - parv[0] = command
+ *      - parv[1] = kill victim
+ *      - parv[2] = kill path and reason
  */
 static int
 ms_kill(struct Client *source_p, int parc, char *parv[])
@@ -209,7 +223,7 @@ ms_kill(struct Client *source_p, int parc, char *parv[])
    * Path must contain at least 2 !'s, or bitchx falsely declares it
    * local --fl
    */
-  if (HasUMode(source_p, UMODE_OPER)) /* send it normally */
+  if (IsClient(source_p))  /* Send it normally */
     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
                          "Received KILL message for %s!%s@%s[%s/%s]. From %s Path: %s!%s!%s!%s %s",
                          target_p->name, target_p->username, target_p->host,
@@ -228,7 +242,7 @@ ms_kill(struct Client *source_p, int parc, char *parv[])
   ilog(LOG_TYPE_KILL, "KILL From %s For %s Path %s %s",
        source_p->name, target_p->name, source_p->name, reason);
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s KILL %s :%s %s",
+  sendto_server(source_p, 0, 0, ":%s KILL %s :%s %s",
                 source_p->id, target_p->id, parv[2], reason);
   AddFlag(target_p, FLAGS_KILLED);
 
@@ -265,7 +279,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
