@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_mode.c
  * \brief Includes required functions for processing the MODE command.
- * \version $Id: m_mode.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_mode.c 5547 2015-02-12 14:25:58Z michael $
  */
 
 #include "stdinc.h"
@@ -52,8 +52,9 @@
 static void
 set_user_mode(struct Client *source_p, const int parc, char *parv[])
 {
-  unsigned int mode = 0, setmodes = 0;
-  struct Client *target_p = NULL;
+  const struct user_modes *tab = NULL;
+  const unsigned int setmodes = source_p->umodes;
+  const struct Client *target_p = NULL;
   int what = MODE_ADD, badmode = 0;
 
   if ((target_p = find_person(source_p, parv[1])) == NULL)
@@ -75,88 +76,82 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
     char *m = buf;
     *m++ = '+';
 
-    for (unsigned int i = 0; i < 128; ++i)
-      if (HasUMode(source_p, user_modes[i]))
-        *m++ = (char)i;
+    for (tab = umode_tab; tab->c; ++tab)
+      if (HasUMode(source_p, tab->flag))
+        *m++ = tab->c;
     *m = '\0';
 
     sendto_one_numeric(source_p, &me, RPL_UMODEIS, buf);
     return;
   }
 
-  /* Find modes already set for user */
-  setmodes = source_p->umodes;
-
   /* parse mode change string(s) */
-  for (char **p = &parv[2]; p && *p; ++p)
+  for (const char *m = parv[2]; *m; ++m)
   {
-    for (const char *m = *p; *m; ++m)
+    switch (*m)
     {
-      switch (*m)
-      {
-        case '+':
-          what = MODE_ADD;
-          break;
-        case '-':
-          what = MODE_DEL;
-          break;
-        case 'o':
-          if (what == MODE_ADD)
+      case '+':
+        what = MODE_ADD;
+        break;
+      case '-':
+        what = MODE_DEL;
+        break;
+      case 'o':
+        if (what == MODE_ADD)
+        {
+          if (!MyConnect(source_p) && !HasUMode(source_p, UMODE_OPER))
           {
-            if (!MyConnect(source_p) && !HasUMode(source_p, UMODE_OPER))
-            {
-              ++Count.oper;
-              SetOper(source_p);
-            }
+            ++Count.oper;
+            SetOper(source_p);
           }
+        }
+        else
+        {
+          if (!HasUMode(source_p, UMODE_OPER))
+            break;
+
+          ClearOper(source_p);
+          --Count.oper;
+
+          if (MyConnect(source_p))
+          {
+            dlink_node *node = NULL;
+
+            detach_conf(source_p, CONF_OPER);
+            ClrOFlag(source_p);
+            DelUMode(source_p, ConfigGeneral.oper_only_umodes);
+
+            if ((node = dlinkFindDelete(&oper_list, source_p)))
+              free_dlink_node(node);
+          }
+        }
+
+        break;
+
+      case 'S':  /* Only servers may set +S in a burst */
+      case 'W':  /* Only servers may set +W in a burst */
+      case 'r':  /* Only services may set +r */
+      case 'x':  /* Only services may set +x */
+        break;
+
+      default:
+        if ((tab = umode_map[(unsigned char)*m]))
+        {
+          if (MyConnect(source_p) && !HasUMode(source_p, UMODE_OPER) &&
+              (ConfigGeneral.oper_only_umodes & tab->flag))
+            badmode = 1;
           else
           {
-            if (!HasUMode(source_p, UMODE_OPER))
-              break;
-
-            ClearOper(source_p);
-            --Count.oper;
-
-            if (MyConnect(source_p))
-            {
-              dlink_node *ptr = NULL;
-
-              detach_conf(source_p, CONF_OPER);
-              ClrOFlag(source_p);
-              DelUMode(source_p, ConfigGeneral.oper_only_umodes);
-
-              if ((ptr = dlinkFindDelete(&oper_list, source_p)))
-                free_dlink_node(ptr);
-            }
-          }
-
-          break;
-
-        case 'S':  /* Only servers may set +S in a burst */
-        case 'W':  /* Only servers may set +W in a burst */
-        case 'r':  /* Only services may set +r */
-        case 'x':  /* Only services may set +x */
-          break;
-
-        default:
-          if ((mode = user_modes[(unsigned char)*m]))
-          {
-            if (MyConnect(source_p) && !HasUMode(source_p, UMODE_OPER) &&
-                (ConfigGeneral.oper_only_umodes & mode))
-              badmode = 1;
+            if (what == MODE_ADD)
+              AddUMode(source_p, tab->flag);
             else
-            {
-              if (what == MODE_ADD)
-                AddUMode(source_p, mode);
-              else
-                DelUMode(source_p, mode);
-            }
+              DelUMode(source_p, tab->flag);
           }
-          else if (MyConnect(source_p))
-            badmode = 1;
+        }
+        else if (MyConnect(source_p))
+          badmode = 1;
 
-          break;
-      }
+        break;
     }
   }
 
@@ -179,7 +174,7 @@ set_user_mode(struct Client *source_p, const int parc, char *parv[])
    * Compare new modes with old modes and send string which
    * will cause servers to update correctly.
    */
-  send_umode_out(source_p, source_p, setmodes);
+  send_umode_out(source_p, setmodes);
 }
 
 /*
@@ -219,8 +214,8 @@ m_mode(struct Client *source_p, int parc, char *parv[])
     char parabuf[MODEBUFLEN] = "";
 
     channel_modes(chptr, source_p, modebuf, parabuf);
-    sendto_one_numeric(source_p, &me, RPL_CHANNELMODEIS, chptr->chname, modebuf, parabuf);
-    sendto_one_numeric(source_p, &me, RPL_CREATIONTIME, chptr->chname, chptr->channelts);
+    sendto_one_numeric(source_p, &me, RPL_CHANNELMODEIS, chptr->name, modebuf, parabuf);
+    sendto_one_numeric(source_p, &me, RPL_CREATIONTIME, chptr->name, chptr->creationtime);
     return 0;
   }
 
@@ -268,7 +263,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5547 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
