@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_nick.c
  * \brief Includes required functions for processing the NICK command.
- * \version $Id: m_nick.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_nick.c 5779 2015-04-04 17:47:27Z michael $
  */
 
 #include "stdinc.h"
@@ -76,7 +76,7 @@ check_clean_nick(struct Client *source_p, char *nick, struct Client *server_p)
     /* Bad nick change */
     if (IsClient(source_p) && !MyConnect(source_p))
     {
-      sendto_server(source_p, NOCAPS, NOCAPS, ":%s KILL %s :%s (Bad Nickname)",
+      sendto_server(source_p, 0, 0, ":%s KILL %s :%s (Bad Nickname)",
                     me.id, source_p->id, me.name);
       AddFlag(source_p, FLAGS_KILLED);
       exit_client(source_p, "Bad Nickname");
@@ -154,11 +154,12 @@ check_clean_host(struct Client *source_p, char *nick,
 static void
 set_initial_nick(struct Client *source_p, const char *nick)
 {
-  /* Client setting NICK the first time */
+  const int samenick = !irccmp(source_p->name, nick);
 
-  /* This had to be copied here to avoid problems.. */
-  source_p->tsinfo = CurrentTime;
-  source_p->localClient->registration &= ~REG_NEED_NICK;
+  if (!samenick)
+    source_p->tsinfo = CurrentTime;
+
+  source_p->connection->registration &= ~REG_NEED_NICK;
 
   if (source_p->name[0])
     hash_del_client(source_p);
@@ -167,9 +168,9 @@ set_initial_nick(struct Client *source_p, const char *nick)
   hash_add_client(source_p);
 
   /* fd_desc is long enough */
-  fd_note(&source_p->localClient->fd, "Nick: %s", nick);
+  fd_note(&source_p->connection->fd, "Nick: %s", nick);
 
-  if (!source_p->localClient->registration)
+  if (!source_p->connection->registration)
     register_local_user(source_p);
 }
 
@@ -194,13 +195,13 @@ change_local_nick(struct Client *source_p, const char *nick)
    * on a channel, send note of change to all clients
    * on that channel. Propagate notice to other servers.
    */
-  if ((source_p->localClient->nick.last_attempt +
+  if ((source_p->connection->nick.last_attempt +
        ConfigGeneral.max_nick_time) < CurrentTime)
-    source_p->localClient->nick.count = 0;
+    source_p->connection->nick.count = 0;
 
   if (ConfigGeneral.anti_nick_flood &&
       !HasUMode(source_p, UMODE_OPER) &&
-      source_p->localClient->nick.count >
+      source_p->connection->nick.count >
       ConfigGeneral.max_nick_changes)
   {
     sendto_one_numeric(source_p, &me, ERR_NICKTOOFAST, nick,
@@ -208,8 +209,8 @@ change_local_nick(struct Client *source_p, const char *nick)
     return;
   }
 
-  source_p->localClient->nick.last_attempt = CurrentTime;
-  source_p->localClient->nick.count++;
+  source_p->connection->nick.last_attempt = CurrentTime;
+  source_p->connection->nick.count++;
 
   samenick = !irccmp(source_p->name, nick);
 
@@ -237,7 +238,7 @@ change_local_nick(struct Client *source_p, const char *nick)
                                source_p->host, nick);
   whowas_add_history(source_p, 1);
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s NICK %s :%lu",
+  sendto_server(source_p, 0, 0, ":%s NICK %s :%lu",
                 source_p->id, nick, (unsigned long)source_p->tsinfo);
 
   hash_del_client(source_p);
@@ -248,7 +249,7 @@ change_local_nick(struct Client *source_p, const char *nick)
     watch_check_hash(source_p, RPL_LOGON);
 
   /* fd_desc is long enough */
-  fd_note(&source_p->localClient->fd, "Nick: %s", nick);
+  fd_note(&source_p->connection->fd, "Nick: %s", nick);
 }
 
 /*!
@@ -287,7 +288,7 @@ change_remote_nick(struct Client *source_p, char *parv[])
                                source_p->host, parv[1]);
 
   whowas_add_history(source_p, 1);
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s NICK %s :%lu",
+  sendto_server(source_p, 0, 0, ":%s NICK %s :%lu",
                 source_p->id, parv[1], (unsigned long)source_p->tsinfo);
 
   /* Set the new nick name */
@@ -330,7 +331,7 @@ change_remote_nick(struct Client *source_p, char *parv[])
  *      - parv[ 6] = hostname
  *      - parv[ 7] = ip
  *      - parv[ 8] = uid
- *      - parv[ 9] = services id (account name)
+ *      - parv[ 9] = services account
  *      - parv[10] = ircname (gecos)
  */
 static void
@@ -343,7 +344,7 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   client_p->hopcount = atoi(parv[2]);
   client_p->tsinfo = atol(parv[3]);
 
-  strlcpy(client_p->svid, (parc == 11 ? parv[9] : "0"), sizeof(client_p->svid));
+  strlcpy(client_p->account, (parc == 11 ? parv[9] : "*"), sizeof(client_p->account));
   strlcpy(client_p->name, parv[1], sizeof(client_p->name));
   strlcpy(client_p->id, parv[8], sizeof(client_p->id));
   strlcpy(client_p->sockhost, parv[7], sizeof(client_p->sockhost));
@@ -357,14 +358,16 @@ uid_from_server(struct Client *source_p, int parc, char *parv[])
   /* Parse usermodes */
   for (const char *m = &parv[4][1]; *m; ++m)
   {
-    unsigned int flag = user_modes[(unsigned char)*m];
+    const struct user_modes *tab = umode_map[(unsigned char)*m];
 
-    if ((flag & UMODE_INVISIBLE) && !HasUMode(client_p, UMODE_INVISIBLE))
+    if (!tab)
+      continue;
+    if ((tab->flag & UMODE_INVISIBLE) && !HasUMode(client_p, UMODE_INVISIBLE))
       ++Count.invisi;
-    if ((flag & UMODE_OPER) && !HasUMode(client_p, UMODE_OPER))
+    if ((tab->flag & UMODE_OPER) && !HasUMode(client_p, UMODE_OPER))
       ++Count.oper;
 
-    AddUMode(client_p, flag);
+    AddUMode(client_p, tab->flag);
   }
 
   register_remote_user(client_p);
@@ -427,7 +430,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
 
     sendto_one(source_p, ":%s KILL %s :%s (Nick collision (new))",
                me.id, uid, me.name);
-    sendto_server(NULL, NOCAPS, NOCAPS, ":%s KILL %s :%s (Nick collision (new))",
+    sendto_server(NULL, 0, 0, ":%s KILL %s :%s (Nick collision (new))",
                   me.id, target_p->id, me.name);
 
     ++ServerStats.is_kill;
@@ -439,7 +442,10 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
   }
 
   /* The timestamps are different */
-  sameuser = !irccmp(target_p->username, parv[5]) && !irccmp(target_p->host, parv[6]);
+  if (!strcmp(target_p->sockhost, "0")) /* XXX: TBR */
+    sameuser = !irccmp(target_p->username, parv[5]) && !irccmp(target_p->host, parv[6]);
+  else
+    sameuser = !irccmp(target_p->username, parv[5]) && !irccmp(target_p->sockhost, parv[7]);
 
   /*
    * If the users are the same (loaded a client on a different server)
@@ -468,7 +474,7 @@ perform_uid_introduction_collides(struct Client *source_p, struct Client *target
   ++ServerStats.is_kill;
   sendto_one_numeric(target_p, &me, ERR_NICKCOLLISION, target_p->name);
 
-  sendto_server(NULL, NOCAPS, NOCAPS, ":%s KILL %s :%s (Nick collision (new))",
+  sendto_server(NULL, 0, 0, ":%s KILL %s :%s (Nick collision (new))",
                 me.id, target_p->id, me.name);
 
   AddFlag(target_p, FLAGS_KILLED);
@@ -512,9 +518,9 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
     sendto_one_numeric(target_p, &me, ERR_NICKCOLLISION, target_p->name);
     ServerStats.is_kill += 2;
 
-    sendto_server(NULL, NOCAPS, NOCAPS, ":%s KILL %s :%s (Nick change collision)",
+    sendto_server(NULL, 0, 0, ":%s KILL %s :%s (Nick change collision)",
                   me.id, source_p->id, me.name);
-    sendto_server(NULL, NOCAPS, NOCAPS, ":%s KILL %s :%s (Nick change collision)",
+    sendto_server(NULL, 0, 0, ":%s KILL %s :%s (Nick change collision)",
                   me.id, target_p->id, me.name);
 
     AddFlag(source_p, FLAGS_KILLED);
@@ -525,8 +531,12 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
   }
 
   /* The timestamps are different */
-  sameuser = !irccmp(target_p->username, source_p->username) &&
-             !irccmp(target_p->host, source_p->host);
+  if (!strcmp(target_p->sockhost, "0") || !strcmp(source_p->sockhost, "0")) /* XXX: TBR */
+    sameuser = !irccmp(target_p->username, source_p->username) &&
+               !irccmp(target_p->host, source_p->host);
+  else
+    sameuser = !irccmp(target_p->username, source_p->username) &&
+               !irccmp(target_p->sockhost, source_p->sockhost);
 
   if ((sameuser && newts < target_p->tsinfo) ||
       (!sameuser && newts > target_p->tsinfo))
@@ -544,7 +554,7 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
 
     ++ServerStats.is_kill;
 
-    sendto_server(NULL, NOCAPS, NOCAPS, ":%s KILL %s :%s (Nick change collision)",
+    sendto_server(NULL, 0, 0, ":%s KILL %s :%s (Nick change collision)",
                   me.id, source_p->id, me.name);
     AddFlag(source_p, FLAGS_KILLED);
 
@@ -566,7 +576,7 @@ perform_nick_change_collides(struct Client *source_p, struct Client *target_p,
                          target_p->name, target_p->from->name,
                          source_p->from->name);
 
-  sendto_server(NULL, NOCAPS, NOCAPS, ":%s KILL %s :%s (Nick collision)",
+  sendto_server(NULL, 0, 0, ":%s KILL %s :%s (Nick collision)",
                 me.id, target_p->id, me.name);
 
   ++ServerStats.is_kill;
@@ -623,10 +633,8 @@ mr_nick(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if ((target_p = hash_find_client(nick)) == NULL)
+  if ((target_p = hash_find_client(nick)) == NULL || target_p == source_p)
     set_initial_nick(source_p, nick);
-  else if (source_p == target_p)
-    strlcpy(source_p->name, nick, sizeof(source_p->name));
   else
     sendto_one_numeric(source_p, &me, ERR_NICKNAMEINUSE, target_p->name);
 
@@ -741,7 +749,7 @@ ms_nick(struct Client *source_p, int parc, char *parv[])
   if (check_clean_nick(source_p, parv[1], source_p->servptr))
     return 0;
 
-  /* If the nick doesnt exist, allow it and process like normal */
+  /* If the nick doesn't exist, allow it and process like normal */
   if ((target_p = hash_find_client(parv[1])) == NULL)
     change_remote_nick(source_p, parv);
   else if (IsUnknown(target_p))
@@ -819,7 +827,7 @@ ms_uid(struct Client *source_p, int parc, char *parv[])
                          target_p->name, target_p->from->name,
                          source_p->from->name);
 
-    sendto_server(NULL, NOCAPS, NOCAPS, ":%s KILL %s :%s (ID collision)",
+    sendto_server(NULL, 0, 0, ":%s KILL %s :%s (ID collision)",
                   me.id, target_p->id, me.name);
 
     ++ServerStats.is_kill;
@@ -870,7 +878,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5779 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
