@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_quit.c
  * \brief Includes required functions for processing the QUIT command.
- * \version $Id: m_quit.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_quit.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -51,7 +51,7 @@ m_quit(struct Client *source_p, int parc, char *parv[])
   char reason[KICKLEN + 1] = "Quit: ";
 
   if (!EmptyString(parv[1]) && (HasUMode(source_p, UMODE_OPER) ||
-      (source_p->localClient->firsttime + ConfigGeneral.anti_spam_exit_message_time)
+      (source_p->connection->firsttime + ConfigGeneral.anti_spam_exit_message_time)
       < CurrentTime))
     strlcpy(reason + 6, parv[1], sizeof(reason) - 6);
 
@@ -104,7 +104,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
