@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_tmode.c
  * \brief Includes required functions for processing the TMODE command.
- * \version $Id: m_tmode.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_tmode.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -30,16 +30,10 @@
 #include "channel_mode.h"
 #include "client.h"
 #include "hash.h"
-#include "irc_string.h"
 #include "ircd.h"
-#include "numeric.h"
-#include "user.h"
-#include "conf.h"
-#include "server.h"
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
-#include "packet.h"
 
 
 /*! \brief TMODE command handler
@@ -66,7 +60,7 @@ ms_tmode(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (atol(parv[1]) > chptr->channelts)
+  if (atol(parv[1]) > chptr->creationtime)
     return 0;
 
   if (IsServer(source_p) || HasFlag(source_p, FLAGS_SERVICE))
@@ -103,7 +97,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
