@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_accept.c
  * \brief Includes required functions for processing the ACCEPT command.
- * \version $Id: m_accept.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_accept.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -48,15 +48,15 @@ list_accepts(struct Client *source_p)
   int len = 0;
   char nicks[IRCD_BUFSIZE] = "";
   char *t = nicks;
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  /* :me.name 281 source_p->name :n1!u1@h1 n2!u2@h2 ...\r\n */ 
+  /* :me.name 281 source_p->name :n1!u1@h1 n2!u2@h2 ...\r\n */
   /* 1       23456              78                     9 10 */
   len = strlen(me.name) + strlen(source_p->name) + 10;
 
-  DLINK_FOREACH(ptr, source_p->localClient->acceptlist.head)
+  DLINK_FOREACH(node, source_p->connection->acceptlist.head)
   {
-    const struct split_nuh_item *accept_p = ptr->data;
+    const struct split_nuh_item *accept_p = node->data;
     size_t masklen = strlen(accept_p->nickptr) +
                      strlen(accept_p->userptr) +
                      strlen(accept_p->hostptr) + 3;  /* +3 for ! + @ + space */
@@ -91,13 +91,13 @@ list_accepts(struct Client *source_p)
 static void
 add_accept(const struct split_nuh_item *nuh, struct Client *source_p)
 {
-  struct split_nuh_item *accept_p = MyCalloc(sizeof(*accept_p));
+  struct split_nuh_item *const accept_p = MyCalloc(sizeof(*accept_p));
 
   accept_p->nickptr = xstrdup(nuh->nickptr);
   accept_p->userptr = xstrdup(nuh->userptr);
   accept_p->hostptr = xstrdup(nuh->hostptr);
 
-  dlinkAdd(accept_p, &accept_p->node, &source_p->localClient->acceptlist);
+  dlinkAdd(accept_p, &accept_p->node, &source_p->connection->acceptlist);
 
   list_accepts(source_p);
 }
@@ -156,7 +156,7 @@ m_accept(struct Client *source_p, int parc, char *parv[])
     }
     else if (*mask)
     {
-      if (dlink_list_length(&source_p->localClient->acceptlist) >=
+      if (dlink_list_length(&source_p->connection->acceptlist) >=
           ConfigGeneral.max_accept)
       {
         sendto_one_numeric(source_p, &me, ERR_ACCEPTFULL);
@@ -209,7 +209,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
