@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_away.c
  * \brief Includes required functions for processing the AWAY command.
- * \version $Id: m_away.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_away.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -34,7 +34,6 @@
 #include "modules.h"
 #include "conf.h"
 #include "server.h"
-#include "packet.h"
 #include "user.h"
 
 
@@ -52,10 +51,9 @@
 static int
 m_away(struct Client *source_p, int parc, char *parv[])
 {
-  if (!IsFloodDone(source_p))
-    flood_endgrace(source_p);
+  const char *const message = parv[1];
 
-  if (parc < 2 || EmptyString(parv[1]))
+  if (EmptyString(message))
   {
     /* Marking as not away */
     if (source_p->away[0])
@@ -63,7 +61,7 @@ m_away(struct Client *source_p, int parc, char *parv[])
       source_p->away[0] = '\0';
 
       /* We now send this only if they were away before --is */
-      sendto_server(source_p, NOCAPS, NOCAPS, ":%s AWAY", source_p->id);
+      sendto_server(source_p, 0, 0, ":%s AWAY", source_p->id);
       sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, ":%s!%s@%s AWAY",
                                    source_p->name, source_p->username,
                                    source_p->host);
@@ -73,25 +71,25 @@ m_away(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if ((source_p->localClient->away.last_attempt + ConfigGeneral.away_time) < CurrentTime)
-    source_p->localClient->away.count = 0;
+  if ((source_p->connection->away.last_attempt + ConfigGeneral.away_time) < CurrentTime)
+    source_p->connection->away.count = 0;
 
-  if (source_p->localClient->away.count > ConfigGeneral.away_count)
+  if (source_p->connection->away.count > ConfigGeneral.away_count)
   {
     sendto_one_numeric(source_p, &me, ERR_TOOMANYAWAY);
     return 0;
   }
 
-  source_p->localClient->away.last_attempt = CurrentTime;
-  source_p->localClient->away.count++;
+  source_p->connection->away.last_attempt = CurrentTime;
+  source_p->connection->away.count++;
 
-  strlcpy(source_p->away, parv[1], sizeof(source_p->away));
+  strlcpy(source_p->away, message, sizeof(source_p->away));
 
   sendto_one_numeric(source_p, &me, RPL_NOWAWAY);
   sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, ":%s!%s@%s AWAY :%s",
                                source_p->name, source_p->username,
                                source_p->host, source_p->away);
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s AWAY :%s",
+  sendto_server(source_p, 0, 0, ":%s AWAY :%s",
                 source_p->id, source_p->away);
   return 0;
 }
@@ -110,7 +108,9 @@ m_away(struct Client *source_p, int parc, char *parv[])
 static int
 ms_away(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc < 2 || EmptyString(parv[1]))
+  const char *const message = parv[1];
+
+  if (EmptyString(message))
   {
     /* Marking as not away */
     if (source_p->away[0])
@@ -118,7 +118,7 @@ ms_away(struct Client *source_p, int parc, char *parv[])
       source_p->away[0] = '\0';
 
       /* We now send this only if they were away before --is */
-      sendto_server(source_p, NOCAPS, NOCAPS, ":%s AWAY", source_p->id);
+      sendto_server(source_p, 0, 0, ":%s AWAY", source_p->id);
       sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, ":%s!%s@%s AWAY",
                                    source_p->name, source_p->username,
                                    source_p->host);
@@ -127,12 +127,12 @@ ms_away(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  strlcpy(source_p->away, parv[1], sizeof(source_p->away));
+  strlcpy(source_p->away, message, sizeof(source_p->away));
 
   sendto_common_channels_local(source_p, 1, CAP_AWAY_NOTIFY, ":%s!%s@%s AWAY :%s",
                                source_p->name, source_p->username,
                                source_p->host, source_p->away);
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s AWAY :%s",
+  sendto_server(source_p, 0, 0, ":%s AWAY :%s",
                 source_p->id, source_p->away);
   return 0;
 }
@@ -161,7 +161,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
