@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2014 ircd-hybrid development team
+ *  Copyright (c) 1998-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,14 +21,13 @@
 
 /*! \file m_capab.c
  * \brief Includes required functions for processing the CAPAB command.
- * \version $Id: m_capab.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_capab.c 5474 2015-02-07 19:44:49Z michael $
  */
 
 #include "stdinc.h"
 #include "client.h"
 #include "irc_string.h"
 #include "server.h"
-#include "conf.h"
 #include "parse.h"
 #include "modules.h"
 
@@ -51,14 +50,6 @@ mr_capab(struct Client *source_p, int parc, char *parv[])
   char *p = NULL;
   char *s = NULL;
 
-  if (source_p->localClient->caps && !IsCapable(source_p, CAP_TS6))
-  {
-    exit_client(source_p, "CAPAB received twice");
-    return 0;
-  }
-
-  SetCapable(source_p, CAP_CAP);
-
   for (s = strtoken(&p, parv[1], " "); s;
        s = strtoken(&p,    NULL, " "))
     if ((cap = find_capability(s)))
@@ -89,7 +80,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5474 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
