@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_close.c
  * \brief Includes required functions for processing the CLOSE command.
- * \version $Id: m_close.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_close.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -47,13 +47,12 @@
 static int
 mo_close(struct Client *source_p, int parc, char *parv[])
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
   unsigned int closed = dlink_list_length(&unknown_list);
 
-
-  DLINK_FOREACH_SAFE(ptr, ptr_next, unknown_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, unknown_list.head)
   {
-    struct Client *target_p = ptr->data;
+    struct Client *target_p = node->data;
 
     sendto_one_numeric(source_p, &me, RPL_CLOSING,
                        get_client_name(target_p, SHOW_IP),
@@ -92,7 +91,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
