@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_connect.c
  * \brief Includes required functions for processing the CONNECT command.
- * \version $Id: m_connect.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_connect.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -29,7 +29,6 @@
 #include "ircd.h"
 #include "irc_string.h"
 #include "numeric.h"
-#include "fdlist.h"
 #include "s_bsd.h"
 #include "conf.h"
 #include "log.h"
@@ -74,8 +73,7 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
       return 0;
     }
 
-    if (hunt_server(source_p, ":%s CONNECT %s %s :%s", 3,
-                    parc, parv) != HUNTED_ISME)
+    if (hunt_server(source_p, ":%s CONNECT %s %s :%s", 3, parc, parv) != HUNTED_ISME)
       return 0;
   }
   else if (!HasOFlag(source_p, OPER_FLAG_CONNECT))
@@ -84,28 +82,26 @@ mo_connect(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if ((target_p = hash_find_server(parv[1])))
+  /*
+   * Try to find the name, then host, if both fail notify ops and bail
+   */
+  if (!(conf = find_matching_name_conf(CONF_SERVER, parv[1], NULL, NULL, 0)) &&
+      !(conf = find_matching_name_conf(CONF_SERVER, NULL, NULL, parv[1], 0)))
+  {
+    sendto_one_notice(source_p, &me, ":Connect: Host %s not listed in configuration file", parv[1]);
+    return 0;
+  }
+
+  if ((target_p = hash_find_server(conf->name)))
   {
     sendto_one_notice(source_p, &me, ":Connect: Server %s already exists from %s.",
-                      parv[1], target_p->from->name);
+                      target_p->name, target_p->from->name);
     return 0;
   }
 
-  /*
-   * Try to find the name, then host, if both fail notify ops and bail
-   */
-  if (!(conf = find_matching_name_conf(CONF_SERVER, parv[1], NULL, NULL, 0)))
-  {
-    if (!(conf = find_matching_name_conf(CONF_SERVER,  NULL, NULL, parv[1], 0)))
-    {
-      sendto_one_notice(source_p, &me, ":Connect: Host %s not listed in ircd.conf", parv[1]);
-      return 0;
-    }
-  }
-
   /*
    * Get port number from user, if given. If not specified,
-   * use the default form configuration structure. If missing
+   * use the default from configuration structure. If missing
    * from there, then use the precompiled default.
    */
   tmpport = port = conf->port;
@@ -184,38 +180,35 @@ ms_connect(struct Client *source_p, int parc, char *parv[])
   struct MaskItem *conf = NULL;
   const struct Client *target_p = NULL;
 
-  if (hunt_server(source_p, ":%s CONNECT %s %s :%s",
-                  3, parc, parv) != HUNTED_ISME)
-    return 0;
-
-  if (EmptyString(parv[1]))
+  if (parc < 4 || EmptyString(parv[3]))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "CONNECT");
     return 0;
   }
 
-  if ((target_p = hash_find_server(parv[1])))
-  {
-    sendto_one_notice(source_p, &me, ":Connect: Server %s already exists from %s.",
-                      parv[1], target_p->from->name);
+  if (hunt_server(source_p, ":%s CONNECT %s %s :%s", 3, parc, parv) != HUNTED_ISME)
     return 0;
-  }
 
   /*
    * Try to find the name, then host, if both fail notify ops and bail
    */
-  if (!(conf = find_matching_name_conf(CONF_SERVER, parv[1], NULL, NULL, 0)))
+  if (!(conf = find_matching_name_conf(CONF_SERVER, parv[1], NULL, NULL, 0)) &&
+      !(conf = find_matching_name_conf(CONF_SERVER, NULL, NULL, parv[1], 0)))
   {
-    if (!(conf = find_matching_name_conf(CONF_SERVER,  NULL, NULL, parv[1], 0)))
-    {
-      sendto_one_notice(source_p, &me, ":Connect: Host %s not listed in ircd.conf", parv[1]);
-      return 0;
-    }
+    sendto_one_notice(source_p, &me, ":Connect: Host %s not listed in configuration file", parv[1]);
+    return 0;
+  }
+
+  if ((target_p = hash_find_server(conf->name)))
+  {
+    sendto_one_notice(source_p, &me, ":Connect: Server %s already exists from %s.",
+                      target_p->name, target_p->from->name);
+    return 0;
   }
 
   /*
    * Get port number from user, if given. If not specified,
-   * use the default form configuration structure. If missing
+   * use the default from configuration structure. If missing
    * from there, then use the precompiled default.
    */
   tmpport = port = conf->port;
@@ -253,7 +246,7 @@ ms_connect(struct Client *source_p, int parc, char *parv[])
    */
   sendto_realops_flags(UMODE_ALL, L_ALL, SEND_GLOBAL, "from %s: Remote CONNECT %s %d from %s",
                        me.name, parv[1], port, source_p->name);
-  sendto_server(NULL, NOCAPS, NOCAPS,
+  sendto_server(NULL, 0, 0,
                 ":%s GLOBOPS :Remote CONNECT %s %d from %s",
                 me.id, parv[1], port, source_p->name);
 
@@ -302,7 +295,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
