@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2004-2014 ircd-hybrid development team
+ *  Copyright (c) 2004-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_etrace.c
  * \brief Includes required functions for processing the ETRACE command.
- * \version $Id: m_etrace.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_etrace.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -51,24 +51,14 @@ report_this_status(struct Client *source_p, const struct Client *target_p)
   if (target_p->status != STAT_CLIENT)
     return;
 
-  if (ConfigGeneral.hide_spoof_ips)
-    sendto_one_numeric(source_p, &me, RPL_ETRACE,
-                       HasUMode(target_p, UMODE_OPER) ? "Oper" : "User",
-                       get_client_class(&target_p->localClient->confs),
-                       target_p->name,
-                       target_p->username,
-                       target_p->host,
-                       IsIPSpoof(target_p) ? "255.255.255.255" : target_p->sockhost,
-                       target_p->info);
-  else
-    sendto_one_numeric(source_p, &me, RPL_ETRACE,
-                       HasUMode(target_p, UMODE_OPER) ? "Oper" : "User",
-                       get_client_class(&target_p->localClient->confs),
-                       target_p->name,
-                       target_p->username,
-                       target_p->host,
-                       target_p->sockhost,
-                       target_p->info);
+  sendto_one_numeric(source_p, &me, RPL_ETRACE,
+                     HasUMode(target_p, UMODE_OPER) ? "Oper" : "User",
+                     get_client_class(&target_p->connection->confs),
+                     target_p->name,
+                     target_p->username,
+                     target_p->host,
+                     target_p->sockhost,
+                     target_p->info);
 }
 
 /*
@@ -79,7 +69,7 @@ do_etrace(struct Client *source_p, const char *arg)
 {
   const char *tname = NULL;
   unsigned int wilds = 0, do_all = 0;
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
   sendto_realops_flags(UMODE_SPY, L_ALL, SEND_NOTICE,
                        "ETRACE requested by %s (%s@%s) [%s]",
@@ -99,18 +89,18 @@ do_etrace(struct Client *source_p, const char *arg)
 
   if (!wilds && !do_all)
   {
-    const struct Client *target_p = hash_find_client(tname);
+    const struct Client *target_p = find_person(source_p, tname);
 
-    if (target_p && MyClient(target_p))
+    if (target_p && MyConnect(target_p))
       report_this_status(source_p, target_p);
 
     sendto_one_numeric(source_p, &me, RPL_ENDOFTRACE, tname);
     return;
   }
 
-  DLINK_FOREACH(ptr, local_client_list.head)
+  DLINK_FOREACH(node, local_client_list.head)
   {
-    const struct Client *target_p = ptr->data;
+    const struct Client *target_p = node->data;
 
     if (wilds)
     {
@@ -157,7 +147,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
