@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_gline.c
  * \brief Includes required functions for processing the GLINE/GUNGLINE command.
- * \version $Id: m_gline.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_gline.c 5775 2015-04-04 17:31:06Z michael $
  */
 
 #include "stdinc.h"
@@ -50,11 +50,11 @@
 static void
 check_gline(struct AddressRec *arec)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, local_client_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, local_client_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
     if (IsDead(client_p))
       continue;
@@ -65,17 +65,17 @@ check_gline(struct AddressRec *arec)
     switch (arec->masktype)
     {
       case HM_IPV4:
-        if (client_p->localClient->aftype == AF_INET)
-          if (match_ipv4(&client_p->localClient->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
+        if (client_p->connection->aftype == AF_INET)
+          if (match_ipv4(&client_p->connection->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
             conf_try_ban(client_p, arec->conf);
         break;
       case HM_IPV6:
-        if (client_p->localClient->aftype == AF_INET6)
-          if (match_ipv6(&client_p->localClient->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
+        if (client_p->connection->aftype == AF_INET6)
+          if (match_ipv6(&client_p->connection->ip, &arec->Mask.ipa.addr, arec->Mask.ipa.bits))
             conf_try_ban(client_p, arec->conf);
         break;
       default:  /* HM_HOST */
-        if (!match(arec->Mask.hostname, client_p->host))
+        if (!match(arec->Mask.hostname, client_p->host) || !match(arec->Mask.hostname, client_p->sockhost))
           conf_try_ban(client_p, arec->conf);
         break;
     }
@@ -205,7 +205,7 @@ static int
 check_majority(const struct Client *source_p, const char *user,
                const char *host, const char *reason, const int type)
 {
-  dlink_node *dn_ptr = NULL;
+  dlink_node *node = NULL;
 
   cleanup_glines(NULL);
 
@@ -213,9 +213,9 @@ check_majority(const struct Client *source_p, const char *user,
   if ((type == GLINE_PENDING_ADD_TYPE) && find_is_glined(host, user))
     return GLINE_NOT_PLACED;
 
-  DLINK_FOREACH(dn_ptr, pending_glines[type].head)
+  DLINK_FOREACH(node, pending_glines[type].head)
   {
-    struct gline_pending *gp_ptr = dn_ptr->data;
+    struct gline_pending *gp_ptr = node->data;
 
     if (irccmp(gp_ptr->user, user) ||
         irccmp(gp_ptr->host, host))
@@ -307,7 +307,7 @@ ms_gline(struct Client *source_p, int parc, char *parv[])
   host   = parv[2];
   reason = parv[3];
 
-  sendto_server(source_p, CAP_GLN, NOCAPS, ":%s GLINE %s %s :%s",
+  sendto_server(source_p, CAP_GLN, 0, ":%s GLINE %s %s :%s",
                 source_p->id, user, host, reason);
 
   if (!ConfigGeneral.glines)
@@ -382,8 +382,8 @@ mo_gline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (parse_aline("GLINE", source_p, parc, parv, AWILD,
-                  &user, &host, NULL, NULL, &reason) < 0)
+  if (!parse_aline("GLINE", source_p, parc, parv, AWILD,
+                   &user, &host, NULL, NULL, &reason))
     return 0;
 
   if ((p = strchr(host, '/')))
@@ -418,8 +418,8 @@ mo_gline(struct Client *source_p, int parc, char *parv[])
   ilog(LOG_TYPE_GLINE, "G-Line for [%s@%s] [%s] requested by %s",
        user, host, reason, get_oper_name(source_p));
 
-  sendto_server(NULL, CAP_GLN, NOCAPS, ":%s GLINE %s %s :%s",
-		source_p->id, user, host, reason);
+  sendto_server(NULL, CAP_GLN, 0, ":%s GLINE %s %s :%s",
+                source_p->id, user, host, reason);
   return 0;
 }
 
@@ -440,11 +440,8 @@ do_sungline(struct Client *source_p, const char *user,
                          "oper or server has already voted");
 
   if (prop)
-  {
-    sendto_server(source_p, CAP_ENCAP, NOCAPS,
-                  ":%s ENCAP * GUNGLINE %s %s :%s",
+    sendto_server(source_p, CAP_ENCAP, 0, ":%s ENCAP * GUNGLINE %s %s :%s",
                   source_p->id, user, host, reason);
-  }
 }
 
 /*! \brief GUNGLINE command handler
@@ -499,8 +496,8 @@ mo_gungline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (parse_aline("GUNGLINE", source_p, parc, parv, 0, &user,
-                  &host, NULL, NULL, &reason) < 0)
+  if (!parse_aline("GUNGLINE", source_p, parc, parv, 0, &user,
+                   &host, NULL, NULL, &reason))
     return 0;
 
   do_sungline(source_p, user, host, reason, 1);
@@ -544,7 +541,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5775 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
