@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2011-2014 ircd-hybrid development team
+ *  Copyright (c) 2011-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_globops.c
  * \brief Includes required functions for processing the GLOBOPS command.
- * \version $Id: m_globops.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_globops.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -49,7 +49,7 @@
 static int
 mo_globops(struct Client *source_p, int parc, char *parv[])
 {
-  const char *message = parv[1];
+  const char *const message = parv[1];
 
   if (!HasOFlag(source_p, OPER_FLAG_GLOBOPS))
   {
@@ -63,7 +63,7 @@ mo_globops(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s GLOBOPS :%s",
+  sendto_server(source_p, 0, 0, ":%s GLOBOPS :%s",
                 source_p->id, message);
   sendto_realops_flags(UMODE_ALL, L_ALL, SEND_GLOBAL, "from %s: %s",
                        source_p->name, message);
@@ -84,13 +84,15 @@ mo_globops(struct Client *source_p, int parc, char *parv[])
 static int
 ms_globops(struct Client *source_p, int parc, char *parv[])
 {
-  if (EmptyString(parv[1]))
+  const char *const message = parv[1];
+
+  if (EmptyString(message))
     return 0;
 
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s GLOBOPS :%s",
-                source_p->id, parv[1]);
+  sendto_server(source_p, 0, 0, ":%s GLOBOPS :%s",
+                source_p->id, message);
   sendto_realops_flags(UMODE_ALL, L_ALL, SEND_GLOBAL, "from %s: %s",
-                       source_p->name, parv[1]);
+                       source_p->name, message);
   return 0;
 }
 
@@ -116,7 +118,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
