@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1999-2014 ircd-hybrid development team
+ *  Copyright (c) 1999-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_help.c
  * \brief Includes required functions for processing the HELP command.
- * \version $Id: m_help.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_help.c 5770 2015-04-02 19:52:15Z michael $
  */
 
 #include "stdinc.h"
@@ -41,6 +41,7 @@ static void
 sendhelpfile(struct Client *source_p, const char *path, const char *topic)
 {
   FILE *file = NULL;
+  char *p = NULL;
   char line[HELPLEN] = "";
 
   if ((file = fopen(path, "r")) == NULL)
@@ -56,12 +57,15 @@ sendhelpfile(struct Client *source_p, const char *path, const char *topic)
     return;
   }
 
-  line[strlen(line) - 1] = '\0';
+  if ((p = strpbrk(line, "\r\n")))
+    *p = '\0';
+
   sendto_one_numeric(source_p, &me, RPL_HELPSTART, topic, line);
 
   while (fgets(line, sizeof(line), file))
   {
-    line[strlen(line) - 1] = '\0';
+    if ((p = strpbrk(line, "\r\n")))
+      *p = '\0';
 
     sendto_one_numeric(source_p, &me, RPL_HELPTXT, topic, line);
   }
@@ -130,7 +134,7 @@ m_help(struct Client *source_p, int parc, char *parv[])
 
   if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
   {
-    sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+    sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "HELP");
     return 0;
   }
 
@@ -180,7 +184,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5770 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
