@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_info.c
  * \brief Includes required functions for processing the INFO command.
- * \version $Id: m_info.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_info.c 5619 2015-02-27 19:13:12Z michael $
  */
 
 #include "stdinc.h"
@@ -136,10 +136,10 @@ static const struct InfoStruct info_table[] =
     "Server is a hub"
   },
   {
-    "max_clients",
+    "default_max_clients",
     OUTPUT_DECIMAL,
-    &ConfigServerInfo.max_clients,
-    "Maximum number of clients permitted simultaneously on this server"
+    &ConfigServerInfo.default_max_clients,
+    "The default maximum number of clients permitted simultaneously on this server"
   },
   {
     "max_nick_length",
@@ -310,12 +310,6 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.kill_chase_time_limit,
     "Nick Change Tracker for KILL"
   },
-  {
-    "hide_spoof_ips",
-    OUTPUT_BOOLEAN_YN,
-    &ConfigGeneral.hide_spoof_ips,
-    "Hide spoofed IP addresses"
-  },
   {
     "ignore_bogus_ts",
     OUTPUT_BOOLEAN_YN,
@@ -376,6 +370,12 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.min_nonwildcard_simple,
     "Minimum non-wildcards in gecos bans"
   },
+  {
+    "max_watch",
+    OUTPUT_DECIMAL,
+    &ConfigGeneral.max_watch,
+    "Maximum nicknames on watch list"
+  },
   {
     "max_accept",
     OUTPUT_DECIMAL,
@@ -430,6 +430,12 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.stats_e_disabled,
     "Whether or not STATS e is disabled"
   },
+  {
+    "stats_m_oper_only",
+    OUTPUT_BOOLEAN_YN,
+    &ConfigGeneral.stats_m_oper_only,
+    "STATS m output is only shown to operators"
+  },
   {
     "stats_o_oper_only",
     OUTPUT_BOOLEAN_YN,
@@ -502,12 +508,6 @@ static const struct InfoStruct info_table[] =
     &ConfigGeneral.no_oper_flood,
     "Reduce flood control for operators"
   },
-  {
-    "true_no_oper_flood",
-    OUTPUT_BOOLEAN_YN,
-    &ConfigGeneral.true_no_oper_flood,
-    "Completely disable flood control for operators"
-  },
   {
     "oper_pass_resv",
     OUTPUT_BOOLEAN_YN,
@@ -556,7 +556,7 @@ static const struct InfoStruct info_table[] =
     NULL,
     0,
     NULL,
-    0
+    NULL
   }
 };
 
@@ -569,9 +569,9 @@ static const struct InfoStruct info_table[] =
 static void
 send_birthdate_online_time(struct Client *source_p)
 {
-  sendto_one_numeric(source_p, &me, RPL_INFO|SND_EXPLICIT,
+  sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                      ":On-line since %s",
-                     myctime(me.localClient->firsttime));
+                     myctime(me.connection->firsttime));
 }
 
 /* send_conf_options()
@@ -595,7 +595,7 @@ send_conf_options(struct Client *source_p)
       {
         const char *option = *((const char *const *)iptr->option);
 
-        sendto_one_numeric(source_p, &me, RPL_INFO|SND_EXPLICIT,
+        sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5s [%s]",
                            iptr->name, option ? option : "NONE",
                            iptr->desc ? iptr->desc : "<none>");
@@ -607,7 +607,7 @@ send_conf_options(struct Client *source_p)
       {
         const char *option = iptr->option;
 
-        sendto_one_numeric(source_p, &me, RPL_INFO|SND_EXPLICIT,
+        sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5s [%s]",
                            iptr->name, option ? option : "NONE",
                            iptr->desc ? iptr->desc : "<none>");
@@ -619,7 +619,7 @@ send_conf_options(struct Client *source_p)
       {
         const int option = *((const int *const)iptr->option);
 
-        sendto_one_numeric(source_p, &me, RPL_INFO|SND_EXPLICIT,
+        sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5d [%s]",
                            iptr->name, option, iptr->desc ? iptr->desc : "<none>");
         break;
@@ -630,7 +630,7 @@ send_conf_options(struct Client *source_p)
       {
         const int option = *((const int *const)iptr->option);
 
-        sendto_one_numeric(source_p, &me, RPL_INFO|SND_EXPLICIT,
+        sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5s [%s]",
                            iptr->name, option ? "ON" : "OFF",
                            iptr->desc ? iptr->desc : "<none>");
@@ -643,7 +643,7 @@ send_conf_options(struct Client *source_p)
       {
         const int option = *((const int *const)iptr->option);
 
-        sendto_one_numeric(source_p, &me, RPL_INFO|SND_EXPLICIT,
+        sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5s [%s]",
                            iptr->name, option ? "YES" : "NO",
                            iptr->desc ? iptr->desc : "<none>");
@@ -654,7 +654,7 @@ send_conf_options(struct Client *source_p)
       {
         const int option = *((const int *const)iptr->option);
 
-        sendto_one_numeric(source_p, &me, RPL_INFO|SND_EXPLICIT,
+        sendto_one_numeric(source_p, &me, RPL_INFO | SND_EXPLICIT,
                            ":%-30s %-5s [%s]",
                            iptr->name, option ? ((option == 1) ? "MASK" : "YES") : "NO",
                            iptr->desc ? iptr->desc : "<none>");
@@ -716,15 +716,14 @@ m_info(struct Client *source_p, int parc, char *parv[])
 
   if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
   {
-    sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+    sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "INFO");
     return 0;
   }
 
   last_used = CurrentTime;
 
   if (!ConfigServerHide.disable_remote_commands)
-    if (hunt_server(source_p, ":%s INFO :%s", 1,
-                    parc, parv) != HUNTED_ISME)
+    if (hunt_server(source_p, ":%s INFO :%s", 1, parc, parv) != HUNTED_ISME)
       return 0;
 
   send_info_text(source_p);
@@ -745,8 +744,7 @@ m_info(struct Client *source_p, int parc, char *parv[])
 static int
 ms_info(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s INFO :%s", 1,
-                  parc, parv) != HUNTED_ISME)
+  if (hunt_server(source_p, ":%s INFO :%s", 1, parc, parv) != HUNTED_ISME)
     return 0;
 
   send_info_text(source_p);
@@ -775,7 +773,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5619 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
