@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1998-2014 ircd-hybrid development team
+ *  Copyright (c) 1998-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_knock.c
  * \brief Includes required functions for processing the KNOCK command.
- * \version $Id: m_knock.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_knock.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -72,7 +72,7 @@ m_knock(struct Client *source_p, int parc, char *parv[])
   /* Normal channel, just be sure they aren't on it */
   if (IsMember(source_p, chptr))
   {
-    sendto_one_numeric(source_p, &me, ERR_KNOCKONCHAN, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_KNOCKONCHAN, chptr->name);
     return 0;
   }
 
@@ -80,7 +80,7 @@ m_knock(struct Client *source_p, int parc, char *parv[])
         (chptr->mode.limit && dlink_list_length(&chptr->members) >=
          chptr->mode.limit)))
   {
-    sendto_one_numeric(source_p, &me, ERR_CHANOPEN, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_CHANOPEN, chptr->name);
     return 0;
   }
 
@@ -91,42 +91,42 @@ m_knock(struct Client *source_p, int parc, char *parv[])
      */
     if (PrivateChannel(chptr) || is_banned(chptr, source_p))
     {
-      sendto_one_numeric(source_p, &me, ERR_CANNOTSENDTOCHAN, chptr->chname);
+      sendto_one_numeric(source_p, &me, ERR_CANNOTSENDTOCHAN, chptr->name);
       return 0;
     }
 
-    if ((source_p->localClient->knock.last_attempt + ConfigChannel.knock_client_time) < CurrentTime)
-      source_p->localClient->knock.count = 0;
+    if ((source_p->connection->knock.last_attempt + ConfigChannel.knock_client_time) < CurrentTime)
+      source_p->connection->knock.count = 0;
 
-    if (source_p->localClient->knock.count > ConfigChannel.knock_client_count)
+    if (source_p->connection->knock.count > ConfigChannel.knock_client_count)
     {
-      sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, chptr->chname, "user");
+      sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, chptr->name, "user");
       return 0;
     }
 
     if ((chptr->last_knock + ConfigChannel.knock_delay_channel) > CurrentTime)
     {
-      sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, chptr->chname, "channel");
+      sendto_one_numeric(source_p, &me, ERR_TOOMANYKNOCK, chptr->name, "channel");
       return 0;
     }
 
-    source_p->localClient->knock.last_attempt = CurrentTime;
-    source_p->localClient->knock.count++;
+    source_p->connection->knock.last_attempt = CurrentTime;
+    source_p->connection->knock.count++;
 
-    sendto_one_numeric(source_p, &me, RPL_KNOCKDLVR, chptr->chname);
+    sendto_one_numeric(source_p, &me, RPL_KNOCKDLVR, chptr->name);
   }
 
   chptr->last_knock = CurrentTime;
 
-  sendto_channel_local(CHFL_CHANOP, 0, chptr,
-                       ":%s NOTICE @%s :KNOCK: %s (%s [%s@%s] has asked for an invite)",
-                       me.name, chptr->chname, chptr->chname,
+  sendto_channel_local(CHFL_CHANOP | CHFL_HALFOP, chptr,
+                       ":%s NOTICE %%%s :KNOCK: %s (%s [%s@%s] has asked for an invite)",
+                       me.name, chptr->name, chptr->name,
                        source_p->name,
                        source_p->username,
                        source_p->host);
 
-  sendto_server(source_p, CAP_KNOCK, NOCAPS, ":%s KNOCK %s",
-                source_p->id, chptr->chname);
+  sendto_server(source_p, CAP_KNOCK, 0, ":%s KNOCK %s",
+                source_p->id, chptr->name);
   return 0;
 }
 
@@ -156,7 +156,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
