@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_locops.c
  * \brief Includes required functions for processing the LOCOPS command.
- * \version $Id: m_locops.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_locops.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -50,7 +50,7 @@
 static int
 mo_locops(struct Client *source_p, int parc, char *parv[])
 {
-  const char *message = parv[1];
+  const char *const message = parv[1];
 
   if (!HasOFlag(source_p, OPER_FLAG_LOCOPS))
   {
@@ -123,7 +123,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
