@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_lusers.c
  * \brief Includes required functions for processing the LUSERS command.
- * \version $Id: m_lusers.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_lusers.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -55,15 +55,14 @@ m_lusers(struct Client *source_p, int parc, char *parv[])
 
   if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
   {
-    sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+    sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "LUSERS");
     return 0;
   }
 
   last_used = CurrentTime;
 
-  if (parc > 2 && !ConfigServerHide.disable_remote_commands)
-    if (hunt_server(source_p, ":%s LUSERS %s :%s", 2,
-                    parc, parv) != HUNTED_ISME)
+  if (!ConfigServerHide.disable_remote_commands)
+    if (hunt_server(source_p, ":%s LUSERS %s :%s", 2, parc, parv) != HUNTED_ISME)
       return 0;
 
   show_lusers(source_p);
@@ -85,10 +84,8 @@ m_lusers(struct Client *source_p, int parc, char *parv[])
 static int
 ms_lusers(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc > 2)
-    if (hunt_server(source_p, ":%s LUSERS %s :%s", 2,
-                    parc, parv) != HUNTED_ISME)
-        return 0;
+  if (hunt_server(source_p, ":%s LUSERS %s :%s", 2, parc, parv) != HUNTED_ISME)
+    return 0;
 
   show_lusers(source_p);
   return 0;
@@ -116,7 +113,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
