@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2014 ircd-hybrid development team
+ *  Copyright (c) 2001-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_map.c
  * \brief Includes required functions for processing the MAP command.
- * \version $Id: m_map.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_map.c 5627 2015-02-27 19:43:31Z michael $
  */
 
 #include "stdinc.h"
@@ -38,10 +38,10 @@ static void dump_map(struct Client *client,
                      struct Client *server,
                      unsigned int prompt_length)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   struct Client *target_p = NULL;
   static char prompt[64];
-  static char buf[IRCD_BUFSIZE];
+  char buf[IRCD_BUFSIZE];
   char *p = prompt + prompt_length;
   unsigned int cnt = 0;
   unsigned int bufpos = 0;
@@ -56,7 +56,7 @@ static void dump_map(struct Client *client,
 
     bufpos += snprintf(buf + bufpos, sizeof(buf) - bufpos, "%s", server->name);
 
-    if (HasUMode(client, UMODE_OPER) && server->id[0])
+    if (HasUMode(client, UMODE_OPER))
       bufpos += snprintf(buf + bufpos, sizeof(buf) - bufpos, "[%s]", server->id);
 
     buf[bufpos++] = ' ';
@@ -66,7 +66,7 @@ static void dump_map(struct Client *client,
     buf[bufpos++] = ' ';
     buf[bufpos++] = '|';
 
-    bufpos += snprintf(buf + bufpos, sizeof(buf) - bufpos, " Users %5d (%1.2f%%)",
+    bufpos += snprintf(buf + bufpos, sizeof(buf) - bufpos, " Users: %5d (%1.2f%%)",
                        dlink_list_length(&server->serv->client_list), 100 *
                        (float)dlink_list_length(&server->serv->client_list) /
                        (float)Count.total);
@@ -85,9 +85,9 @@ static void dump_map(struct Client *client,
     return;
   strcpy(p, "|-");
 
-  DLINK_FOREACH(ptr, server->serv->server_list.head)
+  DLINK_FOREACH(node, server->serv->server_list.head)
   {
-    target_p = ptr->data;
+    target_p = node->data;
 
     if (IsHidden(target_p) && !HasUMode(client, UMODE_OPER))
       continue;
@@ -99,9 +99,9 @@ static void dump_map(struct Client *client,
     ++cnt;
   }
 
-  DLINK_FOREACH(ptr, server->serv->server_list.head)
+  DLINK_FOREACH(node, server->serv->server_list.head)
   {
-    target_p = ptr->data;
+    target_p = node->data;
 
     if (IsHidden(target_p) && !HasUMode(client, UMODE_OPER))
       continue;
@@ -154,7 +154,7 @@ m_map(struct Client *source_p, int parc, char *parv[])
 
   if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
   {
-    sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+    sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "MAP");
     return 0;
   }
 
@@ -205,7 +205,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5627 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
