@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_module.c
  * \brief Includes required functions for processing the MODULE command.
- * \version $Id: m_module.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_module.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -30,7 +30,6 @@
 #include "irc_string.h"
 #include "ircd.h"
 #include "numeric.h"
-#include "conf.h"
 #include "log.h"
 #include "send.h"
 #include "parse.h"
@@ -109,15 +108,15 @@ module_reload(struct Client *source_p, const char *arg)
   if (!strcmp(arg, "*"))
   {
     unsigned int modnum = 0;
-    dlink_node *ptr = NULL, *ptr_next = NULL;
+    dlink_node *node = NULL, *node_next = NULL;
 
     sendto_one_notice(source_p, &me, ":Reloading all modules");
 
     modnum = dlink_list_length(modules_get_list());
 
-    DLINK_FOREACH_SAFE(ptr, ptr_next, modules_get_list()->head)
+    DLINK_FOREACH_SAFE(node, node_next, modules_get_list()->head)
     {
-      modp = ptr->data;
+      modp = node->data;
 
       if (!(modp->flags & MODULE_FLAG_NOUNLOAD))
         unload_one_module(modp->name, 0);
@@ -174,11 +173,11 @@ module_reload(struct Client *source_p, const char *arg)
 static void
 module_list(struct Client *source_p, const char *arg)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, modules_get_list()->head)
+  DLINK_FOREACH(node, modules_get_list()->head)
   {
-    const struct module *modp = ptr->data;
+    const struct module *modp = node->data;
 
     if (!EmptyString(arg) && match(arg, modp->name))
       continue;
@@ -222,13 +221,16 @@ static const struct ModuleStruct module_cmd_table[] =
 static int
 mo_module(struct Client *source_p, int parc, char *parv[])
 {
+  const char *const subcmd = parv[1];
+  const char *const module = parv[2];
+
   if (!HasOFlag(source_p, OPER_FLAG_MODULE))
   {
     sendto_one_numeric(source_p, &me, ERR_NOPRIVS, "module");
     return 0;
   }
 
-  if (EmptyString(parv[1]))
+  if (EmptyString(subcmd))
   {
     sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "MODULE");
     return 0;
@@ -236,22 +238,22 @@ mo_module(struct Client *source_p, int parc, char *parv[])
 
   for (const struct ModuleStruct *tab = module_cmd_table; tab->handler; ++tab)
   {
-    if (irccmp(tab->cmd, parv[1]))
+    if (irccmp(tab->cmd, subcmd))
       continue;
 
-    if (tab->arg_required && EmptyString(parv[2]))
+    if (tab->arg_required && EmptyString(module))
     {
       sendto_one_numeric(source_p, &me, ERR_NEEDMOREPARAMS, "MODULE");
       return 0;
     }
 
-    tab->handler(source_p, parv[2]);
+    tab->handler(source_p, module);
     return 0;
   }
 
   sendto_one_notice(source_p, &me, ":%s is not a valid option. "
                     "Choose from LOAD, UNLOAD, RELOAD, LIST",
-                    parv[1]);
+                    subcmd);
   return 0;
 }
 
@@ -277,7 +279,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
