@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_names.c
  * \brief Includes required functions for processing the NAMES command.
- * \version $Id: m_names.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_names.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -52,17 +52,10 @@ static int
 m_names(struct Client *source_p, int parc, char *parv[])
 {
   struct Channel *chptr = NULL;
-  char *s = NULL;
-  char *para = parc > 1 ? parv[1] : NULL;
+  const char *const para = parc > 1 ? parv[1] : NULL;
 
   if (!EmptyString(para))
   {
-    if ((s = strchr(para, ',')))
-      *s = '\0';
-
-    if (*para == '\0')
-      return 0;
-
     if ((chptr = hash_find_channel(para)))
       channel_member_names(source_p, chptr, 1);
     else
@@ -96,7 +89,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
