@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_rehash.c
  * \brief Includes required functions for processing the REHASH command.
- * \version $Id: m_rehash.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_rehash.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -54,6 +54,7 @@ static int
 mo_rehash(struct Client *source_p, int parc, char *parv[])
 {
   int found = 0;
+  const char *const option = parv[1];
 
   if (!HasOFlag(source_p, OPER_FLAG_REHASH))
   {
@@ -61,9 +62,9 @@ mo_rehash(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (!EmptyString(parv[1]))
+  if (!EmptyString(option))
   {
-    if (!irccmp(parv[1], "DNS"))
+    if (!irccmp(option, "DNS"))
     {
       sendto_one_numeric(source_p, &me, RPL_REHASHING, "DNS");
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
@@ -72,7 +73,7 @@ mo_rehash(struct Client *source_p, int parc, char *parv[])
       restart_resolver();
       found = 1;
     }
-    else if (!irccmp(parv[1], "MOTD"))
+    else if (!irccmp(option, "MOTD"))
     {
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
                            "%s is forcing re-reading of MOTD files",
@@ -83,10 +84,10 @@ mo_rehash(struct Client *source_p, int parc, char *parv[])
 
     if (found)
       ilog(LOG_TYPE_IRCD, "REHASH %s From %s",
-           parv[1], get_oper_name(source_p));
+           option, get_oper_name(source_p));
     else
       sendto_one_notice(source_p, &me, ":%s is not a valid option. "
-                        "Choose from DNS, MOTD", parv[1]);
+                        "Choose from DNS, MOTD", option);
   }
   else
   {
@@ -96,7 +97,7 @@ mo_rehash(struct Client *source_p, int parc, char *parv[])
                          get_oper_name(source_p));
     ilog(LOG_TYPE_IRCD, "REHASH From %s",
          get_oper_name(source_p));
-    rehash(0);
+    conf_rehash(0);
   }
 
   return 0;
@@ -124,7 +125,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
