@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_restart.c
  * \brief Includes required functions for processing the RESTART command.
- * \version $Id: m_restart.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_restart.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -33,7 +33,6 @@
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
-#include "conf.h"
 
 
 /*! \brief RESTART command handler
@@ -51,6 +50,7 @@ static int
 mo_restart(struct Client *source_p, int parc, char *parv[])
 {
   char buf[IRCD_BUFSIZE] = "";
+  const char *const name = parv[1];
 
   if (!HasOFlag(source_p, OPER_FLAG_RESTART))
   {
@@ -58,13 +58,13 @@ mo_restart(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (EmptyString(parv[1]))
+  if (EmptyString(name))
   {
     sendto_one_notice(source_p, &me, ":Need server name /restart %s", me.name);
     return 0;
   }
 
-  if (irccmp(parv[1], me.name))
+  if (irccmp(name, me.name))
   {
     sendto_one_notice(source_p, &me, ":Mismatch on /restart %s", me.name);
     return 0;
@@ -98,7 +98,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
