@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2013-2014 ircd-hybrid development team
+ *  Copyright (c) 2013-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svskill.c
  * \brief Includes required functions for processing the SVSKILL command.
- * \version $Id: m_svskill.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_svskill.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -54,7 +54,7 @@ ms_svskill(struct Client *source_p, int parc, char *parv[])
 {
   struct Client *target_p = NULL;
   const char *comment = NULL;
-  char reason[KICKLEN + 1] = "SVSKilled: ";
+  char reason[KILLLEN + 1] = "SVSKilled: ";
   time_t ts = 0;
 
   if (!HasFlag(source_p, FLAGS_SERVICE))
@@ -125,7 +125,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
