@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2014 ircd-hybrid development team
+ *  Copyright (c) 2011-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,13 +22,12 @@
 
 /*! \file m_svsmode.c
  * \brief Includes required functions for processing the SVSMODE command.
- * \version $Id: m_svsmode.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_svsmode.c 5549 2015-02-12 15:51:14Z michael $
  */
 
 #include "stdinc.h"
 #include "client.h"
 #include "ircd.h"
-#include "server.h"
 #include "send.h"
 #include "channel_mode.h"
 #include "parse.h"
@@ -50,14 +49,15 @@
  *      - parv[1] = nickname
  *      - parv[2] = TS
  *      - parv[3] = mode
- *      - parv[4] = optional argument (services id, vhost)
+ *      - parv[4] = optional argument (services account, vhost)
  */
 static int
 ms_svsmode(struct Client *source_p, int parc, char *parv[])
 {
+  const struct user_modes *tab = NULL;
   struct Client *target_p = NULL;
   int what = MODE_ADD;
-  unsigned int flag = 0, setmodes = 0;
+  unsigned int setmodes = 0;
   const char *modes = NULL, *extarg = NULL;
   time_t ts = 0;
 
@@ -89,7 +89,7 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
 
       case 'd':
         if (!EmptyString(extarg))
-          strlcpy(target_p->svid, extarg, sizeof(target_p->svid));
+          strlcpy(target_p->account, extarg, sizeof(target_p->account));
         break;
 
       case 'x':
@@ -105,14 +105,14 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
 
           if (MyConnect(target_p))
           {
-            dlink_node *dm = NULL;
+            dlink_node *node = NULL;
 
             detach_conf(target_p, CONF_OPER);
             ClrOFlag(target_p);
             DelUMode(target_p, ConfigGeneral.oper_only_umodes);
 
-            if ((dm = dlinkFindDelete(&oper_list, target_p)))
-              free_dlink_node(dm);
+            if ((node = dlinkFindDelete(&oper_list, target_p)))
+              free_dlink_node(node);
           }
         }
 
@@ -138,12 +138,12 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
         break;
 
       default:
-        if ((flag = user_modes[(unsigned char)*m]))
+        if ((tab = umode_map[(unsigned char)*m]))
         {
           if (what == MODE_ADD)
-            AddUMode(target_p, flag);
+            AddUMode(target_p, tab->flag);
           else
-            DelUMode(target_p, flag);
+            DelUMode(target_p, tab->flag);
         }
 
         break;
@@ -151,11 +151,11 @@ ms_svsmode(struct Client *source_p, int parc, char *parv[])
   }
 
   if (extarg)
-    sendto_server(source_p, NOCAPS, NOCAPS, ":%s SVSMODE %s %lu %s %s",
+    sendto_server(source_p, 0, 0, ":%s SVSMODE %s %lu %s %s",
                   source_p->id,
                   target_p->id, (unsigned long)target_p->tsinfo, modes, extarg);
   else
-    sendto_server(source_p, NOCAPS, NOCAPS, ":%s SVSMODE %s %lu %s",
+    sendto_server(source_p, 0, 0, ":%s SVSMODE %s %lu %s",
                   source_p->id,
                   target_p->id, (unsigned long)target_p->tsinfo, modes);
 
@@ -191,7 +191,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5549 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
