@@ -2,7 +2,7 @@
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
  *  Copyright (c) 1999 Bahamut development team.
- *  Copyright (c) 2011-2014 ircd-hybrid development team
+ *  Copyright (c) 2011-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 
 /*! \file m_svsnick.c
  * \brief Includes required functions for processing the SVSNICK command.
- * \version $Id: m_svsnick.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_svsnick.c 5547 2015-02-12 14:25:58Z michael $
  */
 
 
@@ -30,8 +30,6 @@
 #include "client.h"
 #include "ircd.h"
 #include "channel_mode.h"
-#include "numeric.h"
-#include "server.h"
 #include "send.h"
 #include "parse.h"
 #include "modules.h"
@@ -105,7 +103,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
 
   if (HasUMode(target_p, UMODE_REGISTERED))
   {
-    unsigned int oldmodes = target_p->umodes;
+    const unsigned int oldmodes = target_p->umodes;
     char modebuf[IRCD_BUFSIZE] = "";
 
     DelUMode(target_p, UMODE_REGISTERED);
@@ -118,7 +116,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
 
   whowas_add_history(target_p, 1);
 
-  sendto_server(NULL, NOCAPS, NOCAPS, ":%s NICK %s :%lu",
+  sendto_server(NULL, 0, 0, ":%s NICK %s :%lu",
                 target_p->id, parv[2], (unsigned long)target_p->tsinfo);
   hash_del_client(target_p);
   strlcpy(target_p->name, parv[2], sizeof(target_p->name));
@@ -126,7 +124,7 @@ ms_svsnick(struct Client *source_p, int parc, char *parv[])
 
   watch_check_hash(target_p, RPL_LOGON);
 
-  fd_note(&target_p->localClient->fd, "Nick: %s", parv[2]);
+  fd_note(&target_p->connection->fd, "Nick: %s", parv[2]);
   return 0;
 }
 
@@ -152,7 +150,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5547 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
