@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_time.c
  * \brief Includes required functions for processing the TIME command.
- * \version $Id: m_time.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_time.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -78,9 +78,10 @@ m_time(struct Client *source_p, int parc, char *parv[])
 static int
 ms_time(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s TIME :%s", 1, parc, parv) == HUNTED_ISME)
-    sendto_one_numeric(source_p, &me, RPL_TIME, me.name, date(0));
+  if (hunt_server(source_p, ":%s TIME :%s", 1, parc, parv) != HUNTED_ISME)
+    return 0;
 
+  sendto_one_numeric(source_p, &me, RPL_TIME, me.name, date(0));
   return 0;
 }
 
@@ -106,7 +107,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
