@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_unkline.c
  * \brief Includes required functions for processing the UNKLINE command.
- * \version $Id: m_unkline.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_unkline.c 5775 2015-04-04 17:31:06Z michael $
  */
 
 #include "stdinc.h"
@@ -35,7 +35,6 @@
 #include "log.h"
 #include "misc.h"
 #include "send.h"
-#include "hash.h"
 #include "server.h"
 #include "parse.h"
 #include "modules.h"
@@ -62,6 +61,7 @@ remove_kline_match(const char *host, const char *user)
       aftype = AF_INET6;
     else
       aftype = AF_INET;
+
     piphost = &iphost;
   }
   else
@@ -110,8 +110,8 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
     return 0;
   }
 
-  if (parse_aline("UNKLINE", source_p, parc, parv, 0, &user,
-                  &host, NULL, &target_server, NULL) < 0)
+  if (!parse_aline("UNKLINE", source_p, parc, parv, 0, &user,
+                   &host, NULL, &target_server, NULL))
     return 0;
 
   if (target_server)
@@ -138,58 +138,7 @@ mo_unkline(struct Client *source_p, int parc, char *parv[])
          get_oper_name(source_p), user, host);
   }
   else
-    sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found",
-	              user, host);
-  return 0;
-}
-
-/*! \brief UNKLINE command handler
- *
- * \param source_p Pointer to allocated Client struct from which the message
- *                 originally comes from.  This can be a local or remote client.
- * \param parc     Integer holding the number of supplied arguments.
- * \param parv     Argument vector where parv[0] .. parv[parc-1] are non-NULL
- *                 pointers.
- * \note Valid arguments for this command are:
- *      - parv[0] = command
- *      - parv[1] = target server
- *      - parv[2] = user mask
- *      - parv[3] = host mask
- */
-static int
-me_unkline(struct Client *source_p, int parc, char *parv[])
-{
-  const char *kuser, *khost;
-
-  if (parc != 4)
-    return 0;
-
-  kuser = parv[2];
-  khost = parv[3];
-
-  if (!IsClient(source_p) || match(parv[1], me.name))
-    return 0;
-
-  if (HasFlag(source_p, FLAGS_SERVICE) ||
-      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
-                              source_p->username, source_p->host,
-                              SHARED_UNKLINE))
-  {
-    if (remove_kline_match(khost, kuser))
-    {
-      sendto_one_notice(source_p, &me, ":K-Line for [%s@%s] is removed",
-                        kuser, khost);
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "%s has removed the K-Line for: [%s@%s]",
-                           get_oper_name(source_p), kuser, khost);
-      ilog(LOG_TYPE_KLINE, "%s removed K-Line for [%s@%s]",
-           get_oper_name(source_p), kuser, khost);
-    }
-    else
-      sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found",
-                        kuser, khost);
-  }
-
+    sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found", user, host);
   return 0;
 }
 
@@ -209,20 +158,47 @@ me_unkline(struct Client *source_p, int parc, char *parv[])
 static int
 ms_unkline(struct Client *source_p, int parc, char *parv[])
 {
-  if (parc != 4)
+  const char *kuser, *khost;
+
+  if (parc != 4 || EmptyString(parv[3]))
     return 0;
 
-  sendto_match_servs(source_p, parv[1], CAP_UNKLN,
-                     "UNKLINE %s %s %s",
+  sendto_match_servs(source_p, parv[1], CAP_UNKLN, "UNKLINE %s %s %s",
                      parv[1], parv[2], parv[3]);
 
-  return me_unkline(source_p, parc, parv);
+  kuser = parv[2];
+  khost = parv[3];
+
+  if (match(parv[1], me.name))
+    return 0;
+
+  if (HasFlag(source_p, FLAGS_SERVICE) ||
+      find_matching_name_conf(CONF_ULINE, source_p->servptr->name,
+                              source_p->username, source_p->host,
+                              SHARED_UNKLINE))
+  {
+    if (remove_kline_match(khost, kuser))
+    {
+      if (IsClient(source_p))
+        sendto_one_notice(source_p, &me, ":K-Line for [%s@%s] is removed", kuser, khost);
+
+      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
+                           "%s has removed the K-Line for: [%s@%s]",
+                           get_oper_name(source_p), kuser, khost);
+      ilog(LOG_TYPE_KLINE, "%s removed K-Line for [%s@%s]",
+           get_oper_name(source_p), kuser, khost);
+    }
+    else if (IsClient(source_p))
+      sendto_one_notice(source_p, &me, ":No K-Line for [%s@%s] found", kuser, khost);
+  }
+
+  return 0;
 }
 
 static struct Message unkline_msgtab =
 {
   "UNKLINE", NULL, 0, 0, 2, MAXPARA, MFLG_SLOW, 0,
-  { m_unregistered, m_not_oper, ms_unkline, me_unkline, mo_unkline, m_ignore }
+  { m_unregistered, m_not_oper, ms_unkline, m_ignore, mo_unkline, m_ignore }
 };
 
 static void
@@ -243,7 +219,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5775 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
