@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_version.c
  * \brief Includes required functions for processing the VERSION command.
- * \version $Id: m_version.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_version.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -69,15 +69,14 @@ m_version(struct Client *source_p, int parc, char *parv[])
 
   if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
   {
-    sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+    sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "VERSION");
     return 0;
   }
 
   last_used = CurrentTime;
 
   if (!ConfigServerHide.disable_remote_commands)
-    if (hunt_server(source_p, ":%s VERSION :%s",
-                    1, parc, parv) != HUNTED_ISME)
+    if (hunt_server(source_p, ":%s VERSION :%s", 1, parc, parv) != HUNTED_ISME)
       return 0;
 
   sendto_one_numeric(source_p, &me, RPL_VERSION, ircd_version, serno,
@@ -100,8 +99,7 @@ m_version(struct Client *source_p, int parc, char *parv[])
 static int
 ms_version(struct Client *source_p, int parc, char *parv[])
 {
-  if (hunt_server(source_p, ":%s VERSION :%s",
-                  1, parc, parv) != HUNTED_ISME)
+  if (hunt_server(source_p, ":%s VERSION :%s", 1, parc, parv) != HUNTED_ISME)
     return 0;
 
   sendto_one_numeric(source_p, &me, RPL_VERSION, ircd_version, serno,
@@ -132,7 +130,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
