@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_wallops.c
  * \brief Includes required functions for processing the WALLOPS command.
- * \version $Id: m_wallops.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_wallops.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -49,7 +49,7 @@
 static int
 mo_wallops(struct Client *source_p, int parc, char *parv[])
 {
-  const char *message = parv[1];
+  const char *const message = parv[1];
 
   if (!HasOFlag(source_p, OPER_FLAG_WALLOPS))
   {
@@ -64,7 +64,7 @@ mo_wallops(struct Client *source_p, int parc, char *parv[])
   }
 
   sendto_wallops_flags(UMODE_WALLOP, source_p, "%s", message);
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s WALLOPS :%s",
+  sendto_server(source_p, 0, 0, ":%s WALLOPS :%s",
                 source_p->id, message);
   return 0;
 }
@@ -83,13 +83,13 @@ mo_wallops(struct Client *source_p, int parc, char *parv[])
 static int
 ms_wallops(struct Client *source_p, int parc, char *parv[])
 {
-  const char *message = parv[1];
+  const char *const message = parv[1];
 
   if (EmptyString(message))
     return 0;
 
   sendto_wallops_flags(UMODE_WALLOP, source_p, "%s", message);
-  sendto_server(source_p, NOCAPS, NOCAPS, ":%s WALLOPS :%s",
+  sendto_server(source_p, 0, 0, ":%s WALLOPS :%s",
                 source_p->id, message);
   return 0;
 }
@@ -116,7 +116,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5346 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
