@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_who.c
  * \brief Includes required functions for processing the WHO command.
- * \version $Id: m_who.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_who.c 5640 2015-03-01 16:15:37Z michael $
  */
 
 #include "stdinc.h"
@@ -40,7 +40,7 @@
 #include "modules.h"
 
 
-#define WHO_MAXREPLIES 500
+#define WHO_MAX_REPLIES 500
 
 
 /* do_who()
@@ -54,7 +54,7 @@
  */
 static void
 do_who(struct Client *source_p, struct Client *target_p,
-       const char *chname, const char *op_flags)
+       const char *name, const char *op_flags)
 {
   char status[IRCD_BUFSIZE] = "";
 
@@ -70,14 +70,14 @@ do_who(struct Client *source_p, struct Client *target_p,
 
   if (ConfigServerHide.hide_servers || IsHidden(target_p->servptr))
     sendto_one_numeric(source_p, &me, RPL_WHOREPLY,
-               (chname) ? (chname) : "*",
+               (name) ? (name) : "*",
                target_p->username, target_p->host,
                HasUMode(source_p, UMODE_OPER) ? target_p->servptr->name : "*",
                target_p->name, status,
                HasUMode(source_p, UMODE_OPER) ? target_p->hopcount : 0, target_p->info);
   else
     sendto_one_numeric(source_p, &me, RPL_WHOREPLY,
-               (chname) ? (chname) : "*", target_p->username,
+               (name) ? (name) : "*", target_p->username,
                target_p->host, target_p->servptr->name, target_p->name,
                status, target_p->hopcount, target_p->info);
 }
@@ -97,11 +97,11 @@ static void
 who_common_channel(struct Client *source_p, struct Channel *chptr, char *mask,
                    int server_oper, unsigned int *maxmatches)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, chptr->members.head)
+  DLINK_FOREACH(node, chptr->members.head)
   {
-    struct Client *target_p = ((struct Membership *)ptr->data)->client_p;
+    struct Client *target_p = ((struct Membership *)node->data)->client_p;
 
     if (!HasUMode(target_p, UMODE_INVISIBLE) || HasFlag(target_p, FLAGS_MARK))
       continue;
@@ -126,7 +126,7 @@ who_common_channel(struct Client *source_p, struct Channel *chptr, char *mask,
       {
         if (--(*maxmatches) == 0)
         {
-          sendto_one_numeric(source_p, &me, ERR_WHOLIMEXCEED, WHO_MAXREPLIES, "WHO");
+          sendto_one_numeric(source_p, &me, ERR_WHOLIMEXCEED, WHO_MAX_REPLIES, "WHO");
           return;
         }
       }
@@ -146,15 +146,15 @@ who_common_channel(struct Client *source_p, struct Channel *chptr, char *mask,
 static void
 who_global(struct Client *source_p, char *mask, int server_oper)
 {
-  dlink_node *ptr = NULL;
-  unsigned int maxmatches = WHO_MAXREPLIES;
+  dlink_node *node = NULL;
+  unsigned int maxmatches = WHO_MAX_REPLIES;
   static time_t last_used = 0;
 
   if (!HasUMode(source_p, UMODE_OPER))
   {
     if ((last_used + ConfigGeneral.pace_wait) > CurrentTime)
     {
-      sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+      sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "WHO");
       return;
     }
 
@@ -162,16 +162,16 @@ who_global(struct Client *source_p, char *mask, int server_oper)
   }
 
   /* First, list all matching invisible clients on common channels */
-  DLINK_FOREACH(ptr, source_p->channel.head)
+  DLINK_FOREACH(node, source_p->channel.head)
   {
-    struct Channel *chptr = ((struct Membership *)ptr->data)->chptr;
+    struct Channel *chptr = ((struct Membership *)node->data)->chptr;
     who_common_channel(source_p, chptr, mask, server_oper, &maxmatches);
   }
 
   /* Second, list all matching visible clients */
-  DLINK_FOREACH(ptr, global_client_list.head)
+  DLINK_FOREACH(node, global_client_list.head)
   {
-    struct Client *target_p = ptr->data;
+    struct Client *target_p = node->data;
 
     if (!IsClient(target_p))
       continue;
@@ -198,7 +198,7 @@ who_global(struct Client *source_p, char *mask, int server_oper)
       {
         if (--maxmatches == 0)
         {
-          sendto_one_numeric(source_p, &me, ERR_WHOLIMEXCEED, WHO_MAXREPLIES, "WHO");
+          sendto_one_numeric(source_p, &me, ERR_WHOLIMEXCEED, WHO_MAX_REPLIES, "WHO");
           return;
         }
       }
@@ -219,22 +219,22 @@ who_global(struct Client *source_p, char *mask, int server_oper)
  */
 static void
 do_who_on_channel(struct Client *source_p, struct Channel *chptr,
-                  int member, int server_oper)
+                  int is_member, int server_oper)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, chptr->members.head)
+  DLINK_FOREACH(node, chptr->members.head)
   {
-    struct Membership *ms = ptr->data;
-    struct Client *target_p = ms->client_p;
+    struct Membership *member = node->data;
+    struct Client *target_p = member->client_p;
 
-    if (member || !HasUMode(target_p, UMODE_INVISIBLE))
+    if (is_member || !HasUMode(target_p, UMODE_INVISIBLE))
     {
       if (server_oper)
         if (!HasUMode(target_p, UMODE_OPER) ||
             (HasUMode(target_p, UMODE_HIDDEN) && !HasUMode(source_p, UMODE_OPER)))
           continue;
-      do_who(source_p, target_p, chptr->chname, get_member_status(ms, !!HasCap(source_p, CAP_MULTI_PREFIX)));
+      do_who(source_p, target_p, chptr->name, get_member_status(member, !!HasCap(source_p, CAP_MULTI_PREFIX)));
     }
   }
 }
@@ -257,8 +257,8 @@ m_who(struct Client *source_p, int parc, char *parv[])
   struct Client *target_p = NULL;
   struct Channel *chptr = NULL;
   char *mask = parv[1];
-  dlink_node *ptr = NULL;
-  int server_oper = parc > 2 ? (*parv[2] == 'o') : 0; /* Show OPERS only */
+  dlink_node *node = NULL;
+  const int server_oper = parc > 2 ? (*parv[2] == 'o') : 0; /* Show OPERS only */
 
   /* See if mask is there, collapse it or return if not there */
   if (EmptyString(mask))
@@ -288,19 +288,19 @@ m_who(struct Client *source_p, int parc, char *parv[])
   }
 
   /* '/who nick' */
-  if (((target_p = hash_find_client(mask))) &&
-      IsClient(target_p) && (!server_oper || HasUMode(target_p, UMODE_OPER)))
+  if ((target_p = find_person(source_p, mask)) &&
+      (!server_oper || HasUMode(target_p, UMODE_OPER)))
   {
-    DLINK_FOREACH(ptr, target_p->channel.head)
+    DLINK_FOREACH(node, target_p->channel.head)
     {
-      chptr = ((struct Membership *)ptr->data)->chptr;
+      chptr = ((struct Membership *)node->data)->chptr;
       if (PubChannel(chptr) || IsMember(source_p, chptr))
         break;
     }
 
-    if (ptr)
-      do_who(source_p, target_p, chptr->chname,
-             get_member_status(ptr->data, !!HasCap(source_p, CAP_MULTI_PREFIX)));
+    if (node)
+      do_who(source_p, target_p, chptr->name,
+             get_member_status(node->data, !!HasCap(source_p, CAP_MULTI_PREFIX)));
     else
       do_who(source_p, target_p, NULL, "");
 
@@ -311,9 +311,9 @@ m_who(struct Client *source_p, int parc, char *parv[])
   /* '/who *' */
   if (!strcmp(mask, "*"))
   {
-    if ((ptr = source_p->channel.head))
+    if ((node = source_p->channel.head))
     {
-      chptr = ((struct Membership *)ptr->data)->chptr;
+      chptr = ((struct Membership *)node->data)->chptr;
       do_who_on_channel(source_p, chptr, 1, server_oper);
     }
 
@@ -354,7 +354,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5640 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
