@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file m_whois.c
  * \brief Includes required functions for processing the WHOIS command.
- * \version $Id: m_whois.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: m_whois.c 5630 2015-03-01 12:18:47Z michael $
  */
 
 #include "stdinc.h"
@@ -53,7 +53,7 @@ whois_can_see_channels(struct Channel *chptr,
   if (source_p == target_p || IsMember(source_p, chptr))
     return 1;
 
-  if (HasUMode(source_p, UMODE_ADMIN))
+  if (HasUMode(source_p, UMODE_OPER))
     return 2;
   return 0;
 }
@@ -69,10 +69,10 @@ static void
 whois_person(struct Client *source_p, struct Client *target_p)
 {
   char buf[IRCD_BUFSIZE] = "";
-  const dlink_node *lp = NULL;
+  const dlink_node *node = NULL;
+  const struct ServicesTag *svstag = NULL;
   char *t = NULL;
   int cur_len = 0;
-  int show_ip = 0;
   int mlen = 0;
   int tlen = 0;
   int reply_to_send = 0;
@@ -85,14 +85,14 @@ whois_person(struct Client *source_p, struct Client *target_p)
                             me.name, source_p->name, target_p->name, "");
   t = buf + mlen;
 
-  DLINK_FOREACH(lp, target_p->channel.head)
+  DLINK_FOREACH(node, target_p->channel.head)
   {
-    const struct Membership *ms = lp->data;
-    int show = whois_can_see_channels(ms->chptr, source_p, target_p);
+    const struct Membership *member = node->data;
+    int show = whois_can_see_channels(member->chptr, source_p, target_p);
 
     if (show)
     {
-      if ((cur_len + 4 + strlen(ms->chptr->chname) + 1) > (IRCD_BUFSIZE - 2))
+      if ((cur_len + 4 + strlen(member->chptr->name) + 1) > (IRCD_BUFSIZE - 2))
       {
         *(t - 1) = '\0';
         sendto_one(source_p, "%s", buf);
@@ -100,8 +100,8 @@ whois_person(struct Client *source_p, struct Client *target_p)
         t = buf + mlen;
       }
 
-      tlen = sprintf(t, "%s%s%s ", show == 2 ? "~" : "", get_member_status(ms, 1),
-                     ms->chptr->chname);
+      tlen = sprintf(t, "%s%s%s ", show == 2 ? "~" : "", get_member_status(member, 1),
+                     member->chptr->name);
       t += tlen;
       cur_len += tlen;
       reply_to_send = 1;
@@ -126,17 +126,17 @@ whois_person(struct Client *source_p, struct Client *target_p)
   if (HasUMode(target_p, UMODE_REGISTERED))
     sendto_one_numeric(source_p, &me, RPL_WHOISREGNICK, target_p->name);
 
-  if (!IsDigit(target_p->svid[0]))
+  if (!IsDigit(target_p->account[0]) && target_p->account[0] != '*')
     sendto_one_numeric(source_p, &me, RPL_WHOISACCOUNT, target_p->name,
-                       target_p->svid);
+                       target_p->account, "is");
 
   if (target_p->away[0])
     sendto_one_numeric(source_p, &me, RPL_AWAY, target_p->name,
                        target_p->away);
 
-  if (HasUMode(target_p, UMODE_CALLERID|UMODE_SOFTCALLERID))
+  if (HasUMode(target_p, UMODE_CALLERID | UMODE_SOFTCALLERID))
   {
-    int callerid = !!HasUMode(target_p, UMODE_CALLERID);
+    const int callerid = !!HasUMode(target_p, UMODE_CALLERID);
 
     sendto_one_numeric(source_p, &me, RPL_TARGUMODEG, target_p->name,
                        callerid ? "+g" : "+G",
@@ -144,56 +144,65 @@ whois_person(struct Client *source_p, struct Client *target_p)
                                   "server side ignore with the exception of common channels");
   }
 
+  if (target_p->svstags.head)
+    svstag = target_p->svstags.head->data;
+
   if (HasUMode(target_p, UMODE_OPER))
     if (!HasUMode(target_p, UMODE_HIDDEN) || HasUMode(source_p, UMODE_OPER))
-      sendto_one_numeric(source_p, &me, RPL_WHOISOPERATOR, target_p->name,
-                 HasUMode(target_p, UMODE_ADMIN) ? "is a Server Administrator" :
+      if (!svstag || svstag->numeric != RPL_WHOISOPERATOR)
+        sendto_one_numeric(source_p, &me, RPL_WHOISOPERATOR, target_p->name,
+                   HasUMode(target_p, UMODE_ADMIN) ? "is a Server Administrator" :
                                                    "is an IRC Operator");
 
+  DLINK_FOREACH(node, target_p->svstags.head)
+  {
+    svstag = node->data;
+
+    if (svstag->numeric == RPL_WHOISOPERATOR)
+      if (HasUMode(target_p, UMODE_HIDDEN) && !HasUMode(source_p, UMODE_OPER))
+        continue;
+
+    if (!svstag->umodes || HasUMode(source_p, svstag->umodes))
+      sendto_one_numeric(source_p, &me, svstag->numeric | SND_EXPLICIT, "%s :%s",
+                         target_p->name, svstag->tag);
+  }
+
   if (HasUMode(target_p, UMODE_WEBIRC))
     sendto_one_numeric(source_p, &me, RPL_WHOISTEXT, target_p->name,
                        "User connected using a webirc gateway");
 
-  if (HasUMode(source_p, UMODE_ADMIN) || source_p == target_p)
+  if (HasUMode(source_p, UMODE_OPER) || source_p == target_p)
   {
     char *m = buf;
     *m++ = '+';
 
-    for (unsigned int i = 0; i < 128; ++i)
-      if (HasUMode(target_p, user_modes[i]))
-        *m++ = (char)i;
+    for (const struct user_modes *tab = umode_tab; tab->c; ++tab)
+      if (HasUMode(target_p, tab->flag))
+        *m++ = tab->c;
     *m = '\0';
 
     sendto_one_numeric(source_p, &me, RPL_WHOISMODES, target_p->name, buf);
   }
 
-  if (target_p->sockhost[0] && strcmp(target_p->sockhost, "0"))
-  {
-    if (HasUMode(source_p, UMODE_ADMIN) || source_p == target_p)
-      show_ip = 1;
-    else if (IsIPSpoof(target_p))
-      show_ip = (HasUMode(source_p, UMODE_OPER) && !ConfigGeneral.hide_spoof_ips);
-    else
-      show_ip = 1;
-
-
-    sendto_one_numeric(source_p, &me, RPL_WHOISACTUALLY, target_p->name,
-                       show_ip ? target_p->sockhost : "255.255.255.255");
-  }
+  if (HasUMode(source_p, UMODE_OPER) || source_p == target_p)
+    if (strcmp(target_p->sockhost, "0")) /* XXX: TBR */
+      sendto_one_numeric(source_p, &me, RPL_WHOISACTUALLY, target_p->name,
+                         target_p->username, target_p->host,
+                         target_p->sockhost);
 
   if (HasUMode(target_p, UMODE_SSL))
     sendto_one_numeric(source_p, &me, RPL_WHOISSECURE, target_p->name);
 
   if (!EmptyString(target_p->certfp))
-    if (target_p == source_p || HasUMode(source_p, UMODE_ADMIN))
+    if (target_p == source_p || HasUMode(source_p, UMODE_OPER))
       sendto_one_numeric(source_p, &me, RPL_WHOISCERTFP, target_p->name, target_p->certfp);
 
   if (MyConnect(target_p))
     if (!HasUMode(target_p, UMODE_HIDEIDLE) || HasUMode(source_p, UMODE_OPER) ||
         source_p == target_p)
       sendto_one_numeric(source_p, &me, RPL_WHOISIDLE, target_p->name,
-                         idle_time_get(source_p, target_p),
-                         target_p->localClient->firsttime);
+                         client_get_idle_time(source_p, target_p),
+                         target_p->connection->firsttime);
 }
 
 /* do_whois()
@@ -245,7 +254,7 @@ m_whois(struct Client *source_p, int parc, char *parv[])
     /* seeing as this is going across servers, we should limit it */
     if ((last_used + ConfigGeneral.pace_wait_simple) > CurrentTime)
     {
-      sendto_one_numeric(source_p, &me, RPL_LOAD2HI);
+      sendto_one_numeric(source_p, &me, RPL_LOAD2HI, "WHOIS");
       return 0;
     }
 
@@ -326,7 +335,7 @@ struct module module_entry =
 {
   .node    = { NULL, NULL, NULL },
   .name    = NULL,
-  .version = "$Revision: 4564 $",
+  .version = "$Revision: 5630 $",
   .handle  = NULL,
   .modinit = module_init,
   .modexit = module_exit,
