@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel.c
  * \brief Responsible for managing channels, members, bans and topics
- * \version $Id: channel.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: channel.c 5758 2015-04-02 18:26:29Z michael $
  */
 
 #include "stdinc.h"
@@ -81,7 +81,9 @@ void
 add_user_to_channel(struct Channel *chptr, struct Client *who,
                     unsigned int flags, int flood_ctrl)
 {
-  struct Membership *ms = NULL;
+  struct Membership *member = NULL;
+
+  assert(IsClient(who));
 
   if (GlobalSetOptions.joinfloodtime > 0)
   {
@@ -107,24 +109,24 @@ add_user_to_channel(struct Channel *chptr, struct Client *who,
         sendto_realops_flags(UMODE_BOTS, L_ALL, SEND_NOTICE,
                              "Possible Join Flooder %s on %s target: %s",
                              get_client_name(who, HIDE_IP),
-                             who->servptr->name, chptr->chname);
+                             who->servptr->name, chptr->name);
       }
     }
 
     chptr->last_join_time = CurrentTime;
   }
 
-  ms = mp_pool_get(member_pool);
-  ms->client_p = who;
-  ms->chptr = chptr;
-  ms->flags = flags;
+  member = mp_pool_get(member_pool);
+  member->client_p = who;
+  member->chptr = chptr;
+  member->flags = flags;
 
-  dlinkAdd(ms, &ms->channode, &chptr->members);
+  dlinkAdd(member, &member->channode, &chptr->members);
 
   if (MyConnect(who))
-    dlinkAdd(ms, &ms->locchannode, &chptr->locmembers);
+    dlinkAdd(member, &member->locchannode, &chptr->locmembers);
 
-  dlinkAdd(ms, &ms->usernode, &who->channel);
+  dlinkAdd(member, &member->usernode, &who->channel);
 }
 
 /*! \brief Deletes an user from a channel by removing a link in the
@@ -134,8 +136,8 @@ add_user_to_channel(struct Channel *chptr, struct Client *who,
 void
 remove_user_from_channel(struct Membership *member)
 {
-  struct Client *client_p = member->client_p;
-  struct Channel *chptr = member->chptr;
+  struct Client *const client_p = member->client_p;
+  struct Channel *const chptr = member->chptr;
 
   dlinkDelete(&member->channode, &chptr->members);
 
@@ -157,29 +159,29 @@ remove_user_from_channel(struct Membership *member)
  * side effects -
  */
 static void
-send_members(struct Client *client_p, struct Channel *chptr,
+send_members(struct Client *client_p, const struct Channel *chptr,
              char *modebuf, char *parabuf)
 {
   char buf[IRCD_BUFSIZE] = "";
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
   int tlen;              /* length of text to append */
   char *t, *start;       /* temp char pointer */
 
   start = t = buf + snprintf(buf, sizeof(buf), ":%s SJOIN %lu %s %s %s:",
-                             me.id, (unsigned long)chptr->channelts,
-                             chptr->chname, modebuf, parabuf);
+                             me.id, (unsigned long)chptr->creationtime,
+                             chptr->name, modebuf, parabuf);
 
-  DLINK_FOREACH(ptr, chptr->members.head)
+  DLINK_FOREACH(node, chptr->members.head)
   {
-    const struct Membership *ms = ptr->data;
+    const struct Membership *member = node->data;
 
-    tlen = strlen(ms->client_p->id) + 1;  /* +1 for space */
+    tlen = strlen(member->client_p->id) + 1;  /* +1 for space */
 
-    if (ms->flags & CHFL_CHANOP)
+    if (member->flags & CHFL_CHANOP)
       ++tlen;
-    if (ms->flags & CHFL_HALFOP)
+    if (member->flags & CHFL_HALFOP)
       ++tlen;
-    if (ms->flags & CHFL_VOICE)
+    if (member->flags & CHFL_VOICE)
       ++tlen;
 
     /*
@@ -193,14 +195,14 @@ send_members(struct Client *client_p, struct Channel *chptr,
       t = start;
     }
 
-    if (ms->flags & CHFL_CHANOP)
+    if (member->flags & CHFL_CHANOP)
       *t++ = '@';
-    if (ms->flags & CHFL_HALFOP)
+    if (member->flags & CHFL_HALFOP)
       *t++ = '%';
-    if (ms->flags & CHFL_VOICE)
+    if (member->flags & CHFL_VOICE)
       *t++ = '+';
 
-    strcpy(t, ms->client_p->id);
+    strcpy(t, member->client_p->id);
 
     t += strlen(t);
     *t++ = ' ';
@@ -220,27 +222,27 @@ send_members(struct Client *client_p, struct Channel *chptr,
  * \param flag     Char flag flagging type of mode. Currently this can be 'b', e' or 'I'
  */
 static void
-send_mode_list(struct Client *client_p, struct Channel *chptr,
+send_mode_list(struct Client *client_p, const struct Channel *chptr,
                const dlink_list *list, const char flag)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
   char mbuf[IRCD_BUFSIZE] = "";
   char pbuf[IRCD_BUFSIZE] = "";
   int tlen, mlen, cur_len;
   char *pp = pbuf;
 
-  if (list->length == 0)
+  if (!list->length)
     return;
 
   mlen = snprintf(mbuf, sizeof(mbuf), ":%s BMASK %lu %s %c :", me.id,
-                  (unsigned long)chptr->channelts, chptr->chname, flag);
+                  (unsigned long)chptr->creationtime, chptr->name, flag);
   cur_len = mlen;
 
-  DLINK_FOREACH(ptr, list->head)
+  DLINK_FOREACH(node, list->head)
   {
-    const struct Ban *banptr = ptr->data;
+    const struct Ban *ban = node->data;
 
-    tlen = banptr->len + 3;  /* +3 for ! + @ + space */
+    tlen = ban->len + 3;  /* +3 for ! + @ + space */
 
     /*
      * Send buffer and start over if we cannot fit another ban
@@ -254,8 +256,7 @@ send_mode_list(struct Client *client_p, struct Channel *chptr,
       pp = pbuf;
     }
 
-    pp += sprintf(pp, "%s!%s@%s ", banptr->name, banptr->user,
-                  banptr->host);
+    pp += sprintf(pp, "%s!%s@%s ", ban->name, ban->user, ban->host);
     cur_len += tlen;
   }
 
@@ -291,7 +292,7 @@ check_channel_name(const char *name, const int local)
 {
   const char *p = name;
 
-  assert(name != NULL);
+  assert(!EmptyString(p));
 
   if (!IsChanPrefix(*p))
     return 0;
@@ -313,16 +314,10 @@ check_channel_name(const char *name, const int local)
 }
 
 void
-remove_ban(struct Ban *bptr, dlink_list *list)
+remove_ban(struct Ban *ban, dlink_list *list)
 {
-  dlinkDelete(&bptr->node, list);
-
-  MyFree(bptr->name);
-  MyFree(bptr->user);
-  MyFree(bptr->host);
-  MyFree(bptr->who);
-
-  mp_pool_release(bptr);
+  dlinkDelete(&ban->node, list);
+  mp_pool_release(ban);
 }
 
 /* free_channel_list()
@@ -334,33 +329,31 @@ remove_ban(struct Ban *bptr, dlink_list *list)
 void
 free_channel_list(dlink_list *list)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, list->head)
-    remove_ban(ptr->data, list);
-
-  assert(list->tail == NULL && list->head == NULL);
+  DLINK_FOREACH_SAFE(node, node_next, list->head)
+    remove_ban(node->data, list);
 }
 
-/*! \brief Get Channel block for chname (and allocate a new channel
+/*! \brief Get Channel block for name (and allocate a new channel
  *         block, if it didn't exist before)
- * \param chname Channel name
+ * \param name Channel name
  * \return Channel block
  */
 struct Channel *
-make_channel(const char *chname)
+make_channel(const char *name)
 {
   struct Channel *chptr = NULL;
 
-  assert(!EmptyString(chname));
+  assert(!EmptyString(name));
 
   chptr = mp_pool_get(channel_pool);
 
   /* Doesn't hurt to set it here */
-  chptr->channelts = CurrentTime;
+  chptr->creationtime = CurrentTime;
   chptr->last_join_time = CurrentTime;
 
-  strlcpy(chptr->chname, chname, sizeof(chptr->chname));
+  strlcpy(chptr->name, name, sizeof(chptr->name));
   dlinkAdd(chptr, &chptr->node, &channel_list);
 
   hash_add_channel(chptr);
@@ -374,10 +367,7 @@ make_channel(const char *chname)
 void
 destroy_channel(struct Channel *chptr)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
-
-  DLINK_FOREACH_SAFE(ptr, ptr_next, chptr->invites.head)
-    del_invite(chptr, ptr->data);
+  clear_invites(chptr);
 
   /* Free ban/exception/invex lists */
   free_channel_list(&chptr->banlist);
@@ -414,46 +404,48 @@ void
 channel_member_names(struct Client *source_p, struct Channel *chptr,
                      int show_eon)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
   char buf[IRCD_BUFSIZE + 1] = "";
   char *t = NULL, *start = NULL;
   int tlen = 0;
-  int is_member = IsMember(source_p, chptr);
-  int multi_prefix = HasCap(source_p, CAP_MULTI_PREFIX) != 0;
-  int uhnames = HasCap(source_p, CAP_UHNAMES) != 0;
+  const int is_member = IsMember(source_p, chptr);
+  const int multi_prefix = HasCap(source_p, CAP_MULTI_PREFIX) != 0;
+  const int uhnames = HasCap(source_p, CAP_UHNAMES) != 0;
+
+  assert(IsClient(source_p));
 
   if (PubChannel(chptr) || is_member)
   {
     t = buf + snprintf(buf, sizeof(buf), numeric_form(RPL_NAMREPLY),
                        me.name, source_p->name,
-                       channel_pub_or_secret(chptr), chptr->chname);
+                       channel_pub_or_secret(chptr), chptr->name);
     start = t;
 
-    DLINK_FOREACH(ptr, chptr->members.head)
+    DLINK_FOREACH(node, chptr->members.head)
     {
-      const struct Membership *ms = ptr->data;
+      const struct Membership *member = node->data;
 
-      if (HasUMode(ms->client_p, UMODE_INVISIBLE) && !is_member)
+      if (HasUMode(member->client_p, UMODE_INVISIBLE) && !is_member)
         continue;
 
       if (!uhnames)
-        tlen = strlen(ms->client_p->name) + 1;  /* +1 for space */
+        tlen = strlen(member->client_p->name) + 1;  /* +1 for space */
       else
-        tlen = strlen(ms->client_p->name) + strlen(ms->client_p->username) +
-               strlen(ms->client_p->host) + 3;  /* +3 for ! + @ + space */
+        tlen = strlen(member->client_p->name) + strlen(member->client_p->username) +
+               strlen(member->client_p->host) + 3;  /* +3 for ! + @ + space */
 
       if (!multi_prefix)
       {
-        if (ms->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE))
+        if (member->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE))
           ++tlen;
       }
       else
       {
-        if (ms->flags & CHFL_CHANOP)
+        if (member->flags & CHFL_CHANOP)
           ++tlen;
-        if (ms->flags & CHFL_HALFOP)
+        if (member->flags & CHFL_HALFOP)
           ++tlen;
-        if (ms->flags & CHFL_VOICE)
+        if (member->flags & CHFL_VOICE)
           ++tlen;
       }
 
@@ -465,12 +457,12 @@ channel_member_names(struct Client *source_p, struct Channel *chptr,
       }
 
       if (!uhnames)
-        t += sprintf(t, "%s%s ", get_member_status(ms, multi_prefix),
-                     ms->client_p->name);
+        t += sprintf(t, "%s%s ", get_member_status(member, multi_prefix),
+                     member->client_p->name);
       else
-        t += sprintf(t, "%s%s!%s@%s ", get_member_status(ms, multi_prefix),
-                     ms->client_p->name, ms->client_p->username,
-                     ms->client_p->host);
+        t += sprintf(t, "%s%s!%s@%s ", get_member_status(member, multi_prefix),
+                     member->client_p->name, member->client_p->username,
+                     member->client_p->host);
     }
 
     if (tlen)
@@ -481,7 +473,7 @@ channel_member_names(struct Client *source_p, struct Channel *chptr,
   }
 
   if (show_eon)
-    sendto_one_numeric(source_p, &me, RPL_ENDOFNAMES, chptr->chname);
+    sendto_one_numeric(source_p, &me, RPL_ENDOFNAMES, chptr->name);
 }
 
 /*! \brief Adds client to invite list
@@ -491,20 +483,22 @@ channel_member_names(struct Client *source_p, struct Channel *chptr,
 void
 add_invite(struct Channel *chptr, struct Client *who)
 {
+  assert(IsClient(who));
+
   del_invite(chptr, who);
 
   /*
    * Delete last link in chain if the list is max length
    */
-  if (dlink_list_length(&who->localClient->invited) >=
+  if (dlink_list_length(&who->connection->invited) >=
       ConfigChannel.max_channels)
-    del_invite(who->localClient->invited.tail->data, who);
+    del_invite(who->connection->invited.tail->data, who);
 
   /* Add client to channel invite list */
   dlinkAdd(who, make_dlink_node(), &chptr->invites);
 
   /* Add channel to the end of the client invite list */
-  dlinkAdd(chptr, make_dlink_node(), &who->localClient->invited);
+  dlinkAdd(chptr, make_dlink_node(), &who->connection->invited);
 }
 
 /*! \brief Delete Invite block from channel invite list
@@ -515,13 +509,25 @@ add_invite(struct Channel *chptr, struct Client *who)
 void
 del_invite(struct Channel *chptr, struct Client *who)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  if ((ptr = dlinkFindDelete(&who->localClient->invited, chptr)))
-    free_dlink_node(ptr);
+  if ((node = dlinkFindDelete(&who->connection->invited, chptr)))
+    free_dlink_node(node);
 
-  if ((ptr = dlinkFindDelete(&chptr->invites, who)))
-    free_dlink_node(ptr);
+  if ((node = dlinkFindDelete(&chptr->invites, who)))
+    free_dlink_node(node);
+}
+
+/*! \brief Removes all invites of a specific channel
+ * \param chptr Pointer to Channel struct
+ */
+void
+clear_invites(struct Channel *chptr)
+{
+  dlink_node *node = NULL, *node_next = NULL;
+
+  DLINK_FOREACH_SAFE(node, node_next, chptr->invites.head)
+    del_invite(chptr, node->data);
 }
 
 /* get_member_status()
@@ -536,26 +542,26 @@ del_invite(struct Channel *chptr, struct Client *who)
  * (like in get_client_name)
  */
 const char *
-get_member_status(const struct Membership *ms, const int combine)
+get_member_status(const struct Membership *member, const int combine)
 {
   static char buffer[4];  /* 4 for @%+\0 */
   char *p = buffer;
 
-  if (ms->flags & CHFL_CHANOP)
+  if (member->flags & CHFL_CHANOP)
   {
     if (!combine)
       return "@";
     *p++ = '@';
   }
 
-  if (ms->flags & CHFL_HALFOP)
+  if (member->flags & CHFL_HALFOP)
   {
     if (!combine)
       return "%";
     *p++ = '%';
   }
 
-  if (ms->flags & CHFL_VOICE)
+  if (member->flags & CHFL_VOICE)
     *p++ = '+';
   *p = '\0';
 
@@ -566,33 +572,32 @@ get_member_status(const struct Membership *ms, const int combine)
  * \param who  Pointer to Client to check
  * \param list Pointer to ban list to search
  * \return 1 if ban found for given n!u\@h mask, 0 otherwise
- *
  */
 static int
 find_bmask(const struct Client *who, const dlink_list *const list)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, list->head)
+  DLINK_FOREACH(node, list->head)
   {
-    const struct Ban *bp = ptr->data;
+    const struct Ban *ban = node->data;
 
-    if (!match(bp->name, who->name) && !match(bp->user, who->username))
+    if (!match(ban->name, who->name) && !match(ban->user, who->username))
     {
-      switch (bp->type)
+      switch (ban->type)
       {
         case HM_HOST:
-          if (!match(bp->host, who->host) || !match(bp->host, who->sockhost))
+          if (!match(ban->host, who->host) || !match(ban->host, who->sockhost))
             return 1;
           break;
         case HM_IPV4:
-          if (who->localClient->aftype == AF_INET)
-            if (match_ipv4(&who->localClient->ip, &bp->addr, bp->bits))
+          if (who->connection->aftype == AF_INET)
+            if (match_ipv4(&who->connection->ip, &ban->addr, ban->bits))
               return 1;
           break;
         case HM_IPV6:
-          if (who->localClient->aftype == AF_INET6)
-            if (match_ipv6(&who->localClient->ip, &bp->addr, bp->bits))
+          if (who->connection->aftype == AF_INET6)
+            if (match_ipv6(&who->connection->ip, &ban->addr, ban->bits))
               return 1;
           break;
         default:
@@ -627,7 +632,7 @@ is_banned(const struct Channel *chptr, const struct Client *who)
  *         or 0 if allowed to join.
  */
 int
-can_join(struct Client *source_p, struct Channel *chptr, const char *key)
+can_join(struct Client *source_p, const struct Channel *chptr, const char *key)
 {
   if ((chptr->mode.mode & MODE_SSLONLY) && !HasUMode(source_p, UMODE_SSL))
     return ERR_SSLONLYCHAN;
@@ -639,7 +644,7 @@ can_join(struct Client *source_p, struct Channel *chptr, const char *key)
     return ERR_OPERONLYCHAN;
 
   if (chptr->mode.mode & MODE_INVITEONLY)
-    if (!dlinkFind(&source_p->localClient->invited, chptr))
+    if (!dlinkFind(&source_p->connection->invited, chptr))
       if (!find_bmask(source_p, &chptr->invexlist))
         return ERR_INVITEONLYCHAN;
 
@@ -657,36 +662,36 @@ can_join(struct Client *source_p, struct Channel *chptr, const char *key)
 }
 
 int
-has_member_flags(const struct Membership *ms, const unsigned int flags)
+has_member_flags(const struct Membership *member, const unsigned int flags)
 {
-  return ms && (ms->flags & flags);
+  return member && (member->flags & flags);
 }
 
 struct Membership *
 find_channel_link(struct Client *client_p, struct Channel *chptr)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   if (!IsClient(client_p))
     return NULL;
 
   if (dlink_list_length(&chptr->members) < dlink_list_length(&client_p->channel))
   {
-    DLINK_FOREACH(ptr, chptr->members.head)
-      if (((struct Membership *)ptr->data)->client_p == client_p)
-        return ptr->data;
+    DLINK_FOREACH(node, chptr->members.head)
+      if (((struct Membership *)node->data)->client_p == client_p)
+        return node->data;
   }
   else
   {
-    DLINK_FOREACH(ptr, client_p->channel.head)
-      if (((struct Membership *)ptr->data)->chptr == chptr)
-        return ptr->data;
+    DLINK_FOREACH(node, client_p->channel.head)
+      if (((struct Membership *)node->data)->chptr == chptr)
+        return node->data;
   }
 
   return NULL;
 }
 
-/*! Tests if a client can send to a channel
+/*! Checks if a message contains control codes
  * \param message The actual message string the client wants to send
  * \return 1 if the message does contain any control codes, 0 otherwise
  */
@@ -714,13 +719,13 @@ msg_has_ctrls(const char *message)
     return 1;  /* Control code */
   }
 
-  return 0;
+  return 0;  /* No control code found */
 }
 
 /*! Tests if a client can send to a channel
  * \param chptr    Pointer to Channel struct
  * \param source_p Pointer to Client struct
- * \param ms       Pointer to Membership struct (can be NULL)
+ * \param member   Pointer to Membership struct (can be NULL)
  * \param message  The actual message string the client wants to send
  * \return CAN_SEND_OPV if op or voiced on channel\n
  *         CAN_SEND_NONOP if can send to channel but is not an op\n
@@ -728,47 +733,55 @@ msg_has_ctrls(const char *message)
  */
 int
 can_send(struct Channel *chptr, struct Client *source_p,
-         struct Membership *ms, const char *message)
+         struct Membership *member, const char *message)
 {
-  struct MaskItem *conf = NULL;
+  const struct MaskItem *conf = NULL;
 
   if (IsServer(source_p) || HasFlag(source_p, FLAGS_SERVICE))
     return CAN_SEND_OPV;
 
   if (MyClient(source_p) && !IsExemptResv(source_p))
     if (!(HasUMode(source_p, UMODE_OPER) && ConfigGeneral.oper_pass_resv))
-      if ((conf = match_find_resv(chptr->chname)) && !resv_find_exempt(source_p, conf))
+      if ((conf = match_find_resv(chptr->name)) && !resv_find_exempt(source_p, conf))
         return ERR_CANNOTSENDTOCHAN;
 
   if ((chptr->mode.mode & MODE_NOCTRL) && msg_has_ctrls(message))
     return ERR_NOCTRLSONCHAN;
-  if (ms || (ms = find_channel_link(source_p, chptr)))
-    if (ms->flags & (CHFL_CHANOP|CHFL_HALFOP|CHFL_VOICE))
+
+  if (chptr->mode.mode & MODE_NOCTCP)
+    if (*message == '\001' && strncmp(message + 1, "ACTION ", 7))
+      return ERR_NOCTCP;
+
+  if (member || (member = find_channel_link(source_p, chptr)))
+    if (member->flags & (CHFL_CHANOP | CHFL_HALFOP | CHFL_VOICE))
       return CAN_SEND_OPV;
-  if (!ms && (chptr->mode.mode & MODE_NOPRIVMSGS))
+
+  if (!member && (chptr->mode.mode & MODE_NOPRIVMSGS))
     return ERR_CANNOTSENDTOCHAN;
+
   if (chptr->mode.mode & MODE_MODERATED)
     return ERR_CANNOTSENDTOCHAN;
+
   if ((chptr->mode.mode & MODE_MODREG) && !HasUMode(source_p, UMODE_REGISTERED))
     return ERR_NEEDREGGEDNICK;
 
   /* Cache can send if banned */
   if (MyClient(source_p))
   {
-    if (ms)
+    if (member)
     {
-      if (ms->flags & CHFL_BAN_SILENCED)
+      if (member->flags & CHFL_BAN_SILENCED)
         return ERR_CANNOTSENDTOCHAN;
 
-      if (!(ms->flags & CHFL_BAN_CHECKED))
+      if (!(member->flags & CHFL_BAN_CHECKED))
       {
         if (is_banned(chptr, source_p))
         {
-          ms->flags |= (CHFL_BAN_CHECKED|CHFL_BAN_SILENCED);
+          member->flags |= (CHFL_BAN_CHECKED | CHFL_BAN_SILENCED);
           return ERR_CANNOTSENDTOCHAN;
         }
 
-        ms->flags |= CHFL_BAN_CHECKED;
+        member->flags |= CHFL_BAN_CHECKED;
       }
     }
     else if (is_banned(chptr, source_p))
@@ -791,15 +804,15 @@ check_spambot_warning(struct Client *source_p, const char *name)
   int decrement_count = 0;
 
   if ((GlobalSetOptions.spam_num &&
-       (source_p->localClient->join_leave_count >=
+       (source_p->connection->join_leave_count >=
         GlobalSetOptions.spam_num)))
   {
-    if (source_p->localClient->oper_warn_count_down > 0)
-      source_p->localClient->oper_warn_count_down--;
+    if (source_p->connection->oper_warn_count_down > 0)
+      source_p->connection->oper_warn_count_down--;
     else
-      source_p->localClient->oper_warn_count_down = 0;
+      source_p->connection->oper_warn_count_down = 0;
 
-    if (source_p->localClient->oper_warn_count_down == 0)
+    if (source_p->connection->oper_warn_count_down == 0)
     {
       /* It's already known as a possible spambot */
       if (name)
@@ -812,31 +825,32 @@ check_spambot_warning(struct Client *source_p, const char *name)
                              "User %s (%s@%s) is a possible spambot",
                              source_p->name, source_p->username,
                              source_p->host);
-      source_p->localClient->oper_warn_count_down = OPER_SPAM_COUNTDOWN;
+      source_p->connection->oper_warn_count_down = OPER_SPAM_COUNTDOWN;
     }
   }
   else
   {
-    if ((t_delta = (CurrentTime - source_p->localClient->last_leave_time)) >
+    if ((t_delta = (CurrentTime - source_p->connection->last_leave_time)) >
          JOIN_LEAVE_COUNT_EXPIRE_TIME)
     {
       decrement_count = (t_delta / JOIN_LEAVE_COUNT_EXPIRE_TIME);
-      if (decrement_count > source_p->localClient->join_leave_count)
-        source_p->localClient->join_leave_count = 0;
+
+      if (decrement_count > source_p->connection->join_leave_count)
+        source_p->connection->join_leave_count = 0;
       else
-        source_p->localClient->join_leave_count -= decrement_count;
+        source_p->connection->join_leave_count -= decrement_count;
     }
     else
     {
-      if ((CurrentTime - (source_p->localClient->last_join_time)) <
+      if ((CurrentTime - (source_p->connection->last_join_time)) <
           GlobalSetOptions.spam_time)
-        source_p->localClient->join_leave_count++;  /* It's a possible spambot */
+        source_p->connection->join_leave_count++;  /* It's a possible spambot */
     }
 
     if (name)
-      source_p->localClient->last_join_time = CurrentTime;
+      source_p->connection->last_join_time = CurrentTime;
     else
-      source_p->localClient->last_leave_time = CurrentTime;
+      source_p->connection->last_leave_time = CurrentTime;
   }
 }
 
@@ -903,23 +917,23 @@ channel_set_topic(struct Channel *chptr, const char *topic,
 void
 channel_do_join_0(struct Client *source_p)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
   if (source_p->channel.head)
     if (MyConnect(source_p) && !HasUMode(source_p, UMODE_OPER))
       check_spambot_warning(source_p, NULL);
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, source_p->channel.head)
+  DLINK_FOREACH_SAFE(node, node_next, source_p->channel.head)
   {
-    struct Channel *chptr = ((struct Membership *)ptr->data)->chptr;
+    struct Channel *chptr = ((struct Membership *)node->data)->chptr;
 
-    sendto_server(source_p, NOCAPS, NOCAPS, ":%s PART %s",
-                  source_p->id, chptr->chname);
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s PART %s",
+    sendto_server(source_p, 0, 0, ":%s PART %s",
+                  source_p->id, chptr->name);
+    sendto_channel_local(0, chptr, ":%s!%s@%s PART %s",
                          source_p->name, source_p->username,
-                         source_p->host, chptr->chname);
+                         source_p->host, chptr->name);
 
-    remove_user_from_channel(ptr->data);
+    remove_user_from_channel(node->data);
   }
 }
 
@@ -932,7 +946,7 @@ channel_find_last0(struct Client *source_p, char *chanlist)
   {
     if (*p == '0' && (*(p + 1) == ',' || *(p + 1) == '\0'))
     {
-      if ((*p + 1) == ',')
+      if (*(p + 1) == ',')
         ++p;
 
       chanlist = p + 1;
@@ -962,10 +976,12 @@ channel_do_join(struct Client *source_p, char *channel, char *key_list)
   char *chan_list = NULL;
   struct Channel *chptr = NULL;
   struct MaskItem *conf = NULL;
-  const struct ClassItem *class = get_class_ptr(&source_p->localClient->confs);
+  const struct ClassItem *const class = get_class_ptr(&source_p->connection->confs);
   int i = 0;
   unsigned int flags = 0;
 
+  assert(IsClient(source_p));
+
   chan_list = channel_find_last0(source_p, channel);
 
   for (chan = strtoken(&p, chan_list, ","); chan;
@@ -1015,7 +1031,7 @@ channel_do_join(struct Client *source_p, char *channel, char *key_list)
       if (splitmode && !HasUMode(source_p, UMODE_OPER) &&
           ConfigChannel.no_join_on_split)
       {
-        sendto_one_numeric(source_p, &me, ERR_UNAVAILRESOURCE, chptr->chname);
+        sendto_one_numeric(source_p, &me, ERR_UNAVAILRESOURCE, chptr->name);
         continue;
       }
 
@@ -1024,7 +1040,7 @@ channel_do_join(struct Client *source_p, char *channel, char *key_list)
        */
       if ((i = can_join(source_p, chptr, key)))
       {
-        sendto_one_numeric(source_p, &me, i, chptr->chname);
+        sendto_one_numeric(source_p, &me, i, chptr->name);
         continue;
       }
 
@@ -1032,7 +1048,7 @@ channel_do_join(struct Client *source_p, char *channel, char *key_list)
        * This should never be the case unless there is some sort of
        * persistant channels.
        */
-      if (dlink_list_length(&chptr->members) == 0)
+      if (!dlink_list_length(&chptr->members))
         flags = CHFL_CHANOP;
       else
         flags = 0;
@@ -1051,49 +1067,60 @@ channel_do_join(struct Client *source_p, char *channel, char *key_list)
     }
 
     if (!HasUMode(source_p, UMODE_OPER))
-      check_spambot_warning(source_p, chptr->chname);
+      check_spambot_warning(source_p, chptr->name);
 
     add_user_to_channel(chptr, source_p, flags, 1);
 
     /*
-     *  Set timestamp if appropriate, and propagate
+     * Set timestamp if appropriate, and propagate
      */
     if (flags == CHFL_CHANOP)
     {
-      chptr->channelts = CurrentTime;
+      chptr->creationtime = CurrentTime;
       chptr->mode.mode |= MODE_TOPICLIMIT;
       chptr->mode.mode |= MODE_NOPRIVMSGS;
 
-      sendto_server(source_p, NOCAPS, NOCAPS, ":%s SJOIN %lu %s +nt :@%s",
-                    me.id, (unsigned long)chptr->channelts,
-                    chptr->chname, source_p->id);
+      sendto_server(source_p, 0, 0, ":%s SJOIN %lu %s +nt :@%s",
+                    me.id, (unsigned long)chptr->creationtime,
+                    chptr->name, source_p->id);
 
       /*
        * Notify all other users on the new channel
        */
-      sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s JOIN :%s",
-                           source_p->name, source_p->username,
-                           source_p->host, chptr->chname);
-      sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s MODE %s +nt",
-                           me.name, chptr->chname);
+      sendto_channel_local_butone(NULL, CAP_EXTENDED_JOIN, 0, chptr, ":%s!%s@%s JOIN %s %s :%s",
+                                  source_p->name, source_p->username,
+                                  source_p->host, chptr->name,
+                                  (!IsDigit(source_p->account[0]) && source_p->account[0] != '*') ? source_p->account : "*",
+                                  source_p->info);
+      sendto_channel_local_butone(NULL, 0, CAP_EXTENDED_JOIN, chptr, ":%s!%s@%s JOIN :%s",
+                                  source_p->name, source_p->username,
+                                  source_p->host, chptr->name);
+      sendto_channel_local(0, chptr, ":%s MODE %s +nt",
+                           me.name, chptr->name);
 
       if (source_p->away[0])
-        sendto_channel_local_butone(source_p, 0, CAP_AWAY_NOTIFY, chptr,
+        sendto_channel_local_butone(source_p, CAP_AWAY_NOTIFY, 0, chptr,
                                     ":%s!%s@%s AWAY :%s",
                                     source_p->name, source_p->username,
                                     source_p->host, source_p->away);
     }
     else
     {
-      sendto_server(source_p, NOCAPS, NOCAPS, ":%s JOIN %lu %s +",
-                    source_p->id, (unsigned long)chptr->channelts,
-                    chptr->chname);
-      sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s JOIN :%s",
-                           source_p->name, source_p->username,
-                           source_p->host, chptr->chname);
+      sendto_server(source_p, 0, 0, ":%s JOIN %lu %s +",
+                    source_p->id, (unsigned long)chptr->creationtime,
+                    chptr->name);
+
+      sendto_channel_local_butone(NULL, CAP_EXTENDED_JOIN, 0, chptr, ":%s!%s@%s JOIN %s %s :%s",
+                                  source_p->name, source_p->username,
+                                  source_p->host, chptr->name,
+                                  (!IsDigit(source_p->account[0]) && source_p->account[0] != '*') ? source_p->account : "*",
+                                  source_p->info);
+      sendto_channel_local_butone(NULL, 0, CAP_EXTENDED_JOIN, chptr, ":%s!%s@%s JOIN :%s",
+                                  source_p->name, source_p->username,
+                                  source_p->host, chptr->name);
 
       if (source_p->away[0])
-        sendto_channel_local_butone(source_p, 0, CAP_AWAY_NOTIFY, chptr,
+        sendto_channel_local_butone(source_p, CAP_AWAY_NOTIFY, 0, chptr,
                                     ":%s!%s@%s AWAY :%s",
                                     source_p->name, source_p->username,
                                     source_p->host, source_p->away);
@@ -1103,14 +1130,14 @@ channel_do_join(struct Client *source_p, char *channel, char *key_list)
 
     if (chptr->topic[0])
     {
-      sendto_one_numeric(source_p, &me, RPL_TOPIC, chptr->chname, chptr->topic);
-      sendto_one_numeric(source_p, &me, RPL_TOPICWHOTIME, chptr->chname,
+      sendto_one_numeric(source_p, &me, RPL_TOPIC, chptr->name, chptr->topic);
+      sendto_one_numeric(source_p, &me, RPL_TOPICWHOTIME, chptr->name,
                          chptr->topic_info, chptr->topic_time);
     }
 
     channel_member_names(source_p, chptr, 1);
 
-    source_p->localClient->last_join_time = CurrentTime;
+    source_p->connection->last_join_time = CurrentTime;
   }
 }
 
@@ -1123,7 +1150,7 @@ static void
 channel_part_one_client(struct Client *source_p, const char *name, const char *reason)
 {
   struct Channel *chptr = NULL;
-  struct Membership *ms = NULL;
+  struct Membership *member = NULL;
 
   if ((chptr = hash_find_channel(name)) == NULL)
   {
@@ -1131,9 +1158,9 @@ channel_part_one_client(struct Client *source_p, const char *name, const char *r
     return;
   }
 
-  if ((ms = find_channel_link(source_p, chptr)) == NULL)
+  if ((member = find_channel_link(source_p, chptr)) == NULL)
   {
-    sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->chname);
+    sendto_one_numeric(source_p, &me, ERR_NOTONCHANNEL, chptr->name);
     return;
   }
 
@@ -1145,38 +1172,40 @@ channel_part_one_client(struct Client *source_p, const char *name, const char *r
    * only allow /part reasons in -m chans
    */
   if (*reason && (!MyConnect(source_p) ||
-      ((can_send(chptr, source_p, ms, reason) &&
-       (source_p->localClient->firsttime + ConfigGeneral.anti_spam_exit_message_time)
+      ((can_send(chptr, source_p, member, reason) &&
+       (source_p->connection->firsttime + ConfigGeneral.anti_spam_exit_message_time)
         < CurrentTime))))
   {
-    sendto_server(source_p, NOCAPS, NOCAPS, ":%s PART %s :%s",
-                  source_p->id, chptr->chname, reason);
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s PART %s :%s",
+    sendto_server(source_p, 0, 0, ":%s PART %s :%s",
+                  source_p->id, chptr->name, reason);
+    sendto_channel_local(0, chptr, ":%s!%s@%s PART %s :%s",
                          source_p->name, source_p->username,
-                         source_p->host, chptr->chname, reason);
+                         source_p->host, chptr->name, reason);
   }
   else
   {
-    sendto_server(source_p, NOCAPS, NOCAPS, ":%s PART %s",
-                  source_p->id, chptr->chname);
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, ":%s!%s@%s PART %s",
+    sendto_server(source_p, 0, 0, ":%s PART %s",
+                  source_p->id, chptr->name);
+    sendto_channel_local(0, chptr, ":%s!%s@%s PART %s",
                          source_p->name, source_p->username,
-                         source_p->host, chptr->chname);
+                         source_p->host, chptr->name);
   }
 
-  remove_user_from_channel(ms);
+  remove_user_from_channel(member);
 }
 
 void
-channel_do_part(struct Client *source_p, char *channel, char *reason)
+channel_do_part(struct Client *source_p, char *channel, const char *reason)
 {
   char *p = NULL, *name = NULL;
-  char reasonbuf[KICKLEN + 1] = "";
+  char buf[KICKLEN + 1] = "";
+
+  assert(IsClient(source_p));
 
   if (!EmptyString(reason))
-    strlcpy(reasonbuf, reason, sizeof(reasonbuf));
+    strlcpy(buf, reason, sizeof(buf));
 
   for (name = strtoken(&p, channel, ","); name;
        name = strtoken(&p,    NULL, ","))
-    channel_part_one_client(source_p, name, reasonbuf);
+    channel_part_one_client(source_p, name, buf);
 }
