@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file channel_mode.c
  * \brief Controls modes on channels.
- * \version $Id: channel_mode.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: channel_mode.c 5758 2015-04-02 18:26:29Z michael $
  */
 
 #include "stdinc.h"
@@ -63,6 +63,7 @@ const struct mode_letter chan_modes[] =
   { MODE_REGISTERED, 'r' },
   { MODE_SECRET,     's' },
   { MODE_TOPICLIMIT, 't' },
+  { MODE_NOCTCP,     'C' },
   { MODE_MODREG,     'M' },
   { MODE_OPERONLY,   'O' },
   { MODE_REGONLY,    'R' },
@@ -83,7 +84,7 @@ const struct mode_letter chan_modes[] =
 static char *
 check_string(char *s)
 {
-  char *str = s;
+  char *const str = s;
   static char star[] = "*";
 
   if (EmptyString(str))
@@ -102,7 +103,7 @@ check_string(char *s)
 }
 
 /*
- * Ban functions to work with mode +b/e/d/I
+ * Ban functions to work with mode +b/e/I
  */
 /* add the specified ID to the channel.
  *   -is 8/9/00
@@ -112,8 +113,8 @@ int
 add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int type)
 {
   dlink_list *list = NULL;
-  dlink_node *ptr = NULL;
-  struct Ban *banptr = NULL;
+  dlink_node *node = NULL;
+  struct Ban *ban = NULL;
   size_t len = 0;
   char name[NICKLEN + 1] = "";
   char user[USERLEN + 1] = "";
@@ -129,7 +130,7 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
 
     if (num_mask >= ConfigChannel.max_bans)
     {
-      sendto_one_numeric(client_p, &me, ERR_BANLISTFULL, chptr->chname, banid);
+      sendto_one_numeric(client_p, &me, ERR_BANLISTFULL, chptr->name, banid);
       return 0;
     }
 
@@ -151,17 +152,17 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
    * Re-assemble a new n!u@h and print it back to banid for sending
    * the mode to the channel.
    */
-  len = sprintf(banid, "%s!%s@%s", name, user, host);
+  len = snprintf(banid, IRCD_BUFSIZE, "%s!%s@%s", name, user, host);
 
   switch (type)
   {
     case CHFL_BAN:
       list = &chptr->banlist;
-      clear_ban_cache(chptr);
+      clear_ban_cache_channel(chptr);
       break;
     case CHFL_EXCEPTION:
       list = &chptr->exceptlist;
-      clear_ban_cache(chptr);
+      clear_ban_cache_channel(chptr);
       break;
     case CHFL_INVEX:
       list = &chptr->invexlist;
@@ -171,38 +172,33 @@ add_id(struct Client *client_p, struct Channel *chptr, char *banid, unsigned int
       return 0;
   }
 
-  DLINK_FOREACH(ptr, list->head)
+  DLINK_FOREACH(node, list->head)
   {
-    banptr = ptr->data;
+    ban = node->data;
 
-    if (!irccmp(banptr->name, name) &&
-        !irccmp(banptr->user, user) &&
-        !irccmp(banptr->host, host))
+    if (!irccmp(ban->name, name) &&
+        !irccmp(ban->user, user) &&
+        !irccmp(ban->host, host))
       return 0;
   }
 
-  banptr = mp_pool_get(ban_pool);
-  banptr->name = xstrdup(name);
-  banptr->user = xstrdup(user);
-  banptr->host = xstrdup(host);
-  banptr->when = CurrentTime;
-  banptr->len = len - 2;  /* -2 for ! + @ */
-  banptr->type = parse_netmask(host, &banptr->addr, &banptr->bits);
+  ban = mp_pool_get(ban_pool);
+  ban->when = CurrentTime;
+  ban->len = len - 2;  /* -2 for ! + @ */
+  ban->type = parse_netmask(host, &ban->addr, &ban->bits);
+  strlcpy(ban->name, name, sizeof(ban->name));
+  strlcpy(ban->user, user, sizeof(ban->user));
+  strlcpy(ban->host, host, sizeof(ban->host));
 
   if (IsClient(client_p))
-  {
-    banptr->who = MyCalloc(strlen(client_p->name) +
-                           strlen(client_p->username) +
-                           strlen(client_p->host) + 3);
-    sprintf(banptr->who, "%s!%s@%s", client_p->name,
-            client_p->username, client_p->host);
-  }
-  else if (IsHidden(client_p) || (IsServer(client_p) && ConfigServerHide.hide_servers))
-    banptr->who = xstrdup(me.name);
+    snprintf(ban->who, sizeof(ban->who), "%s!%s@%s", client_p->name,
+             client_p->username, client_p->host);
+  else if (IsHidden(client_p) || ConfigServerHide.hide_servers)
+    strlcpy(ban->who, me.name, sizeof(ban->who));
   else
-    banptr->who = xstrdup(client_p->name);
+    strlcpy(ban->who, client_p->name, sizeof(ban->who));
 
-  dlinkAdd(banptr, &banptr->node, list);
+  dlinkAdd(ban, &ban->node, list);
 
   return 1;
 }
@@ -218,7 +214,7 @@ static int
 del_id(struct Channel *chptr, char *banid, unsigned int type)
 {
   dlink_list *list = NULL;
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   char name[NICKLEN + 1] = "";
   char user[USERLEN + 1] = "";
   char host[HOSTLEN + 1] = "";
@@ -241,17 +237,17 @@ del_id(struct Channel *chptr, char *banid, unsigned int type)
    * Re-assemble a new n!u@h and print it back to banid for sending
    * the mode to the channel.
    */
-  sprintf(banid, "%s!%s@%s", name, user, host);
+  snprintf(banid, IRCD_BUFSIZE, "%s!%s@%s", name, user, host);
 
   switch (type)
   {
     case CHFL_BAN:
       list = &chptr->banlist;
-      clear_ban_cache(chptr);
+      clear_ban_cache_channel(chptr);
       break;
     case CHFL_EXCEPTION:
       list = &chptr->exceptlist;
-      clear_ban_cache(chptr);
+      clear_ban_cache_channel(chptr);
       break;
     case CHFL_INVEX:
       list = &chptr->invexlist;
@@ -261,15 +257,15 @@ del_id(struct Channel *chptr, char *banid, unsigned int type)
       return 0;
   }
 
-  DLINK_FOREACH(ptr, list->head)
+  DLINK_FOREACH(node, list->head)
   {
-    struct Ban *banptr = ptr->data;
+    struct Ban *ban = node->data;
 
-    if (!irccmp(name, banptr->name) &&
-        !irccmp(user, banptr->user) &&
-        !irccmp(host, banptr->host))
+    if (!irccmp(name, ban->name) &&
+        !irccmp(user, ban->user) &&
+        !irccmp(host, ban->host))
     {
-      remove_ban(banptr, list);
+      remove_ban(ban, list);
       return 1;
     }
   }
@@ -347,26 +343,26 @@ fix_key(char *arg)
  * side effects - clear ban cache
  */
 void
-clear_ban_cache(struct Channel *chptr)
+clear_ban_cache_channel(struct Channel *chptr)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, chptr->locmembers.head)
+  DLINK_FOREACH(node, chptr->locmembers.head)
   {
-    struct Membership *ms = ptr->data;
-    ms->flags &= ~(CHFL_BAN_SILENCED|CHFL_BAN_CHECKED);
+    struct Membership *member = node->data;
+    member->flags &= ~(CHFL_BAN_SILENCED | CHFL_BAN_CHECKED);
   }
 }
 
 void
 clear_ban_cache_client(struct Client *client_p)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, client_p->channel.head)
+  DLINK_FOREACH(node, client_p->channel.head)
   {
-    struct Membership *ms = ptr->data;
-    ms->flags &= ~(CHFL_BAN_SILENCED|CHFL_BAN_CHECKED);
+    struct Membership *member = node->data;
+    member->flags &= ~(CHFL_BAN_SILENCED | CHFL_BAN_CHECKED);
   }
 }
 
@@ -407,7 +403,8 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
+
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -433,8 +430,7 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
   else if (dir == MODE_DEL) /* && (chptr->mode.mode & d)) */
   {
@@ -445,8 +441,7 @@ chm_simple(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
 }
 
@@ -459,7 +454,8 @@ chm_registered(struct Client *source_p, struct Channel *chptr, int parc, int *pa
     if (!(*errors & SM_ERR_ONLYSERVER))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_ONLYSERVERSCANCHANGE, chptr->chname);
+                         ERR_ONLYSERVERSCANCHANGE, chptr->name);
+
     *errors |= SM_ERR_ONLYSERVER;
     return;
   }
@@ -485,8 +481,7 @@ chm_registered(struct Client *source_p, struct Channel *chptr, int parc, int *pa
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
   else if (dir == MODE_DEL) /* && (chptr->mode.mode & d)) */
   {
@@ -497,8 +492,7 @@ chm_registered(struct Client *source_p, struct Channel *chptr, int parc, int *pa
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
 }
 
@@ -506,12 +500,12 @@ static void
 chm_operonly(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
              char **parv, int *errors, int alev, int dir, char c, unsigned int d)
 {
-  if (alev < CHACCESS_CHANOP)
+  if (alev < CHACCESS_HALFOP)
   {
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
 
     *errors |= SM_ERR_NOOPS;
     return;
@@ -539,8 +533,7 @@ chm_operonly(struct Client *source_p, struct Channel *chptr, int parc, int *parn
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
   else if (dir == MODE_DEL) /* && (chptr->mode.mode & d)) */
   {
@@ -551,8 +544,7 @@ chm_operonly(struct Client *source_p, struct Channel *chptr, int parc, int *parn
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
 }
 
@@ -564,22 +556,22 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 
   if (dir == MODE_QUERY || parc <= *parn)
   {
-    dlink_node *ptr = NULL;
+    dlink_node *node = NULL;
 
     if (*errors & SM_ERR_RPL_B)
       return;
 
     *errors |= SM_ERR_RPL_B;
 
-    DLINK_FOREACH(ptr, chptr->banlist.head)
+    DLINK_FOREACH(node, chptr->banlist.head)
     {
-      const struct Ban *banptr = ptr->data;
-      sendto_one_numeric(source_p, &me, RPL_BANLIST, chptr->chname,
-                         banptr->name, banptr->user, banptr->host,
-                         banptr->who, banptr->when);
+      const struct Ban *ban = node->data;
+      sendto_one_numeric(source_p, &me, RPL_BANLIST, chptr->name,
+                         ban->name, ban->user, ban->host,
+                         ban->who, ban->when);
     }
 
-    sendto_one_numeric(source_p, &me, RPL_ENDOFBANLIST, chptr->chname);
+    sendto_one_numeric(source_p, &me, RPL_ENDOFBANLIST, chptr->name);
     return;
   }
 
@@ -588,7 +580,8 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
+
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -597,12 +590,11 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     return;
 
   mask = nuh_mask[*parn];
-  memcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
-  ++*parn;
+  strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
+  ++(*parn);
 
-  if (!MyConnect(source_p))
-    if (strchr(mask, ' '))
-      return;
+  if (*mask == ':' || (!MyConnect(source_p) && strchr(mask, ' ')))
+    return;
 
   switch (dir)
   {
@@ -621,8 +613,7 @@ chm_ban(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = mask;
   mode_changes[mode_count].id = NULL;
-  mode_changes[mode_count].dir = dir;
-  mode_changes[mode_count++].mems = ALL_MEMBERS;
+  mode_changes[mode_count++].dir = dir;
 }
 
 static void
@@ -633,23 +624,23 @@ chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 
   if (dir == MODE_QUERY || parc <= *parn)
   {
-    dlink_node *ptr = NULL;
+    dlink_node *node = NULL;
 
     if (*errors & SM_ERR_RPL_E)
       return;
 
     *errors |= SM_ERR_RPL_E;
 
-    DLINK_FOREACH(ptr, chptr->exceptlist.head)
+    DLINK_FOREACH(node, chptr->exceptlist.head)
     {
-      const struct Ban *banptr = ptr->data;
+      const struct Ban *ban = node->data;
 
-      sendto_one_numeric(source_p, &me, RPL_EXCEPTLIST, chptr->chname,
-                         banptr->name, banptr->user, banptr->host,
-                         banptr->who, banptr->when);
+      sendto_one_numeric(source_p, &me, RPL_EXCEPTLIST, chptr->name,
+                         ban->name, ban->user, ban->host,
+                         ban->who, ban->when);
     }
 
-    sendto_one_numeric(source_p, &me, RPL_ENDOFEXCEPTLIST, chptr->chname);
+    sendto_one_numeric(source_p, &me, RPL_ENDOFEXCEPTLIST, chptr->name);
     return;
   }
 
@@ -658,7 +649,8 @@ chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
+
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -667,12 +659,11 @@ chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     return;
 
   mask = nuh_mask[*parn];
-  memcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
-  ++*parn;
+  strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
+  ++(*parn);
 
-  if (!MyConnect(source_p))
-    if (strchr(mask, ' '))
-      return;
+  if (*mask == ':' || (!MyConnect(source_p) && strchr(mask, ' ')))
+    return;
 
   switch (dir)
   {
@@ -691,8 +682,7 @@ chm_except(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = mask;
   mode_changes[mode_count].id = NULL;
-  mode_changes[mode_count].dir = dir;
-  mode_changes[mode_count++].mems = ALL_MEMBERS;
+  mode_changes[mode_count++].dir = dir;
 }
 
 static void
@@ -703,23 +693,23 @@ chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 
   if (dir == MODE_QUERY || parc <= *parn)
   {
-    dlink_node *ptr = NULL;
+    dlink_node *node = NULL;
 
     if (*errors & SM_ERR_RPL_I)
       return;
 
     *errors |= SM_ERR_RPL_I;
 
-    DLINK_FOREACH(ptr, chptr->invexlist.head)
+    DLINK_FOREACH(node, chptr->invexlist.head)
     {
-      const struct Ban *banptr = ptr->data;
+      const struct Ban *ban = node->data;
 
-      sendto_one_numeric(source_p, &me, RPL_INVEXLIST, chptr->chname,
-                         banptr->name, banptr->user, banptr->host,
-                         banptr->who, banptr->when);
+      sendto_one_numeric(source_p, &me, RPL_INVEXLIST, chptr->name,
+                         ban->name, ban->user, ban->host,
+                         ban->who, ban->when);
     }
 
-    sendto_one_numeric(source_p, &me, RPL_ENDOFINVEXLIST, chptr->chname);
+    sendto_one_numeric(source_p, &me, RPL_ENDOFINVEXLIST, chptr->name);
     return;
   }
 
@@ -728,7 +718,8 @@ chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
+
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -737,12 +728,11 @@ chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     return;
 
   mask = nuh_mask[*parn];
-  memcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
-  ++*parn;
+  strlcpy(mask, parv[*parn], sizeof(nuh_mask[*parn]));
+  ++(*parn);
 
-  if (!MyConnect(source_p))
-    if (strchr(mask, ' '))
-      return;
+  if (*mask == ':' || (!MyConnect(source_p) && strchr(mask, ' ')))
+    return;
 
   switch (dir)
   {
@@ -761,8 +751,7 @@ chm_invex(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = mask;
   mode_changes[mode_count].id = NULL;
-  mode_changes[mode_count].dir = dir;
-  mode_changes[mode_count++].mems = ALL_MEMBERS;
+  mode_changes[mode_count++].dir = dir;
 }
 
 static void
@@ -777,7 +766,8 @@ chm_voice(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
+
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -791,7 +781,8 @@ chm_voice(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if ((member = find_channel_link(target_p, chptr)) == NULL)
   {
     if (!(*errors & SM_ERR_NOTONCHANNEL))
-      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->chname);
+      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->name);
+
     *errors |= SM_ERR_NOTONCHANNEL;
     return;
   }
@@ -802,14 +793,14 @@ chm_voice(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   /* no redundant mode changes */
   if (dir == MODE_ADD &&  has_member_flags(member, CHFL_VOICE))
     return;
+
   if (dir == MODE_DEL && !has_member_flags(member, CHFL_VOICE))
     return;
 
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
-  mode_changes[mode_count].dir = dir;
-  mode_changes[mode_count++].mems = ALL_MEMBERS;
+  mode_changes[mode_count++].dir = dir;
 
   if (dir == MODE_ADD)
     AddMemberFlag(member, CHFL_VOICE);
@@ -829,7 +820,8 @@ chm_hop(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
+
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -843,7 +835,8 @@ chm_hop(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if ((member = find_channel_link(target_p, chptr)) == NULL)
   {
     if (!(*errors & SM_ERR_NOTONCHANNEL))
-      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->chname);
+      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->name);
+
     *errors |= SM_ERR_NOTONCHANNEL;
     return;
   }
@@ -854,14 +847,14 @@ chm_hop(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   /* no redundant mode changes */
   if (dir == MODE_ADD &&  has_member_flags(member, CHFL_HALFOP))
     return;
+
   if (dir == MODE_DEL && !has_member_flags(member, CHFL_HALFOP))
     return;
 
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
-  mode_changes[mode_count].dir = dir;
-  mode_changes[mode_count++].mems = ALL_MEMBERS;
+  mode_changes[mode_count++].dir = dir;
 
   if (dir == MODE_ADD)
     AddMemberFlag(member, CHFL_HALFOP);
@@ -881,7 +874,8 @@ chm_op(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
+
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -895,7 +889,8 @@ chm_op(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   if ((member = find_channel_link(target_p, chptr)) == NULL)
   {
     if (!(*errors & SM_ERR_NOTONCHANNEL))
-      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->chname);
+      sendto_one_numeric(source_p, &me, ERR_USERNOTINCHANNEL, target_p->name, chptr->name);
+
     *errors |= SM_ERR_NOTONCHANNEL;
     return;
   }
@@ -906,14 +901,14 @@ chm_op(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
   /* no redundant mode changes */
   if (dir == MODE_ADD &&  has_member_flags(member, CHFL_CHANOP))
     return;
+
   if (dir == MODE_DEL && !has_member_flags(member, CHFL_CHANOP))
     return;
 
   mode_changes[mode_count].letter = c;
   mode_changes[mode_count].arg = target_p->name;
   mode_changes[mode_count].id = target_p->id;
-  mode_changes[mode_count].dir = dir;
-  mode_changes[mode_count++].mems = ALL_MEMBERS;
+  mode_changes[mode_count++].dir = dir;
 
   if (dir == MODE_ADD)
     AddMemberFlag(member, CHFL_CHANOP);
@@ -932,7 +927,7 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -942,7 +937,7 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 
   if (dir == MODE_ADD && parc > *parn)
   {
-    char *lstr = parv[(*parn)++];
+    char *const lstr = parv[(*parn)++];
 
     if (EmptyString(lstr) || (limit = atoi(lstr)) <= 0)
       return;
@@ -957,8 +952,7 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = lstr;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
 
     chptr->mode.limit = limit;
   }
@@ -972,8 +966,7 @@ chm_limit(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = NULL;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
 }
 
@@ -986,7 +979,7 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     if (!(*errors & SM_ERR_NOOPS))
       sendto_one_numeric(source_p, &me,
                          alev == CHACCESS_NOTONCHAN ? ERR_NOTONCHANNEL :
-                         ERR_CHANOPRIVSNEEDED, chptr->chname);
+                         ERR_CHANOPRIVSNEEDED, chptr->name);
     *errors |= SM_ERR_NOOPS;
     return;
   }
@@ -996,7 +989,7 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
 
   if (dir == MODE_ADD && parc > *parn)
   {
-    char *key = fix_key(parv[(*parn)++]);
+    char *const key = fix_key(parv[(*parn)++]);
 
     if (EmptyString(key))
       return;
@@ -1012,13 +1005,12 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = chptr->mode.key;
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
   else if (dir == MODE_DEL)
   {
     if (parc > *parn)
-      (*parn)++;
+      ++(*parn);
 
     if (chptr->mode.key[0] == '\0')
       return;
@@ -1028,8 +1020,7 @@ chm_key(struct Client *source_p, struct Channel *chptr, int parc, int *parn,
     mode_changes[mode_count].letter = c;
     mode_changes[mode_count].arg = "*";
     mode_changes[mode_count].id = NULL;
-    mode_changes[mode_count].dir = dir;
-    mode_changes[mode_count++].mems = ALL_MEMBERS;
+    mode_changes[mode_count++].dir = dir;
   }
 }
 
@@ -1102,7 +1093,7 @@ const struct ChannelMode ModeTable[256] =
   { chm_nosuch,  0 },                   /* @ */
   { chm_nosuch,  0 },                   /* A */
   { chm_nosuch,  0 },                   /* B */
-  { chm_nosuch,  0 },                   /* C */
+  { chm_simple,  MODE_NOCTCP },         /* C */
   { chm_nosuch,  0 },                   /* D */
   { chm_nosuch,  0 },                   /* E */
   { chm_nosuch,  0 },                   /* F */
@@ -1344,10 +1335,10 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
   parptr = parabuf;
 
   mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %lu %s ", source_p->id,
-                 (unsigned long)chptr->channelts, chptr->chname);
+                 (unsigned long)chptr->creationtime, chptr->name);
 
   /* Loop the list of modes we have */
-  for (unsigned i = 0; i < mode_count; ++i)
+  for (unsigned int i = 0; i < mode_count; ++i)
   {
     if (mode_changes[i].letter == 0)
       continue;
@@ -1371,13 +1362,13 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
         (pbl + arglen + BAN_FUDGE) >= MODEBUFLEN)
     {
       if (nc)
-        sendto_server(source_p, NOCAPS, NOCAPS, "%s %s", modebuf, parabuf);
+        sendto_server(source_p, 0, 0, "%s %s", modebuf, parabuf);
 
       nc = 0;
       mc = 0;
 
       mbl = snprintf(modebuf, sizeof(modebuf), ":%s TMODE %lu %s ", source_p->id,
-                     (unsigned long)chptr->channelts, chptr->chname);
+                     (unsigned long)chptr->creationtime, chptr->name);
 
       pbl = 0;
       parabuf[0] = '\0';
@@ -1393,14 +1384,14 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
 
     modebuf[mbl++] = mode_changes[i].letter;
     modebuf[mbl] = '\0';
-    nc++;
+    ++nc;
 
     if (arg)
     {
       len = sprintf(parptr, "%s ", arg);
       pbl += len;
       parptr += len;
-      mc++;
+      ++mc;
     }
   }
 
@@ -1408,7 +1399,7 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
     parabuf[pbl - 1] = '\0';
 
   if (nc)
-    sendto_server(source_p, NOCAPS, NOCAPS, "%s %s", modebuf, parabuf);
+    sendto_server(source_p, 0, 0, "%s %s", modebuf, parabuf);
 }
 
 /* void send_mode_changes(struct Client *client_p,
@@ -1423,7 +1414,7 @@ send_mode_changes_server(struct Client *source_p, struct Channel *chptr)
  */
 /* ensure parabuf < MODEBUFLEN -db */
 static void
-send_mode_changes(struct Client *source_p, struct Channel *chptr)
+send_mode_changes_client(struct Client *source_p, struct Channel *chptr)
 {
   int mbl = 0, pbl = 0, arglen = 0, nc = 0, mc = 0;
   int len = 0;
@@ -1431,25 +1422,20 @@ send_mode_changes(struct Client *source_p, struct Channel *chptr)
   const char *arg = NULL;
   char *parptr = NULL;
 
-  /* Bail out if we have nothing to do... */
-  if (!mode_count)
-    return;
-
   if (IsServer(source_p))
     mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(source_p) ||
                    ConfigServerHide.hide_servers) ?
-                   me.name : source_p->name, chptr->chname);
+                   me.name : source_p->name, chptr->name);
   else
     mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", source_p->name,
-                   source_p->username, source_p->host, chptr->chname);
+                   source_p->username, source_p->host, chptr->name);
 
   parabuf[0] = '\0';
   parptr = parabuf;
 
   for (unsigned int i = 0; i < mode_count; ++i)
   {
-    if (mode_changes[i].letter == 0 ||
-        mode_changes[i].mems == ONLY_SERVERS)
+    if (mode_changes[i].letter == 0)
       continue;
 
     arg = mode_changes[i].arg;
@@ -1458,7 +1444,7 @@ send_mode_changes(struct Client *source_p, struct Channel *chptr)
     else
       arglen = 0;
 
-    if ((mc == MAXMODEPARAMS)  ||
+    if ((mc == MAXMODEPARAMS) ||
         ((arglen + mbl + pbl + 2) > IRCD_BUFSIZE) ||
         ((arglen + pbl + BAN_FUDGE) >= MODEBUFLEN))
     {
@@ -1466,7 +1452,7 @@ send_mode_changes(struct Client *source_p, struct Channel *chptr)
         modebuf[mbl - 1] = '\0';
 
       if (nc)
-        sendto_channel_local(ALL_MEMBERS, 0, chptr, "%s %s", modebuf, parabuf);
+        sendto_channel_local(0, chptr, "%s %s", modebuf, parabuf);
 
       nc = 0;
       mc = 0;
@@ -1474,10 +1460,10 @@ send_mode_changes(struct Client *source_p, struct Channel *chptr)
       if (IsServer(source_p))
         mbl = snprintf(modebuf, sizeof(modebuf), ":%s MODE %s ", (IsHidden(source_p) ||
                        ConfigServerHide.hide_servers) ?
-                       me.name : source_p->name, chptr->chname);
+                       me.name : source_p->name, chptr->name);
       else
         mbl = snprintf(modebuf, sizeof(modebuf), ":%s!%s@%s MODE %s ", source_p->name,
-                       source_p->username, source_p->host, chptr->chname);
+                       source_p->username, source_p->host, chptr->name);
 
       pbl = 0;
       parabuf[0] = '\0';
@@ -1493,14 +1479,14 @@ send_mode_changes(struct Client *source_p, struct Channel *chptr)
 
     modebuf[mbl++] = mode_changes[i].letter;
     modebuf[mbl] = '\0';
-    nc++;
+    ++nc;
 
     if (arg)
     {
       len = sprintf(parptr, "%s ", arg);
       pbl += len;
       parptr += len;
-      mc++;
+      ++mc;
     }
   }
 
@@ -1508,9 +1494,7 @@ send_mode_changes(struct Client *source_p, struct Channel *chptr)
     parabuf[pbl - 1] = '\0';
 
   if (nc)
-    sendto_channel_local(ALL_MEMBERS, 0, chptr, "%s %s", modebuf, parabuf);
-
-  send_mode_changes_server(source_p, chptr);
+    sendto_channel_local(0, chptr, "%s %s", modebuf, parabuf);
 }
 
 /*
@@ -1560,5 +1544,10 @@ set_channel_mode(struct Client *source_p, struct Channel *chptr,
     }
   }
 
-  send_mode_changes(source_p, chptr);
+  /* Bail out if we have nothing to do... */
+  if (!mode_count)
+    return;
+
+  send_mode_changes_client(source_p, chptr);
+  send_mode_changes_server(source_p, chptr);
 }
