@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file client.c
  * \brief Controls clients.
- * \version $Id: client.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: client.c 5751 2015-04-02 17:27:13Z michael $
  */
 
 #include "stdinc.h"
@@ -60,7 +60,7 @@ dlink_list global_client_list;
 dlink_list global_server_list;
 dlink_list oper_list;
 
-static mp_pool_t *client_pool, *lclient_pool;
+static mp_pool_t *client_pool, *connection_pool;
 static dlink_list dead_list, abort_list;
 static dlink_node *eac_next;  /* next aborted client to exit */
 
@@ -83,28 +83,28 @@ static dlink_node *eac_next;  /* next aborted client to exit */
 struct Client *
 make_client(struct Client *from)
 {
-  struct Client *client_p = mp_pool_get(client_pool);
+  struct Client *const client_p = mp_pool_get(client_pool);
 
   if (!from)
   {
-    client_p->from                      = client_p; /* 'from' of local client is self! */
-    client_p->localClient               = mp_pool_get(lclient_pool);
-    client_p->localClient->since        = CurrentTime;
-    client_p->localClient->lasttime     = CurrentTime;
-    client_p->localClient->firsttime    = CurrentTime;
-    client_p->localClient->registration = REG_INIT;
+    client_p->from = client_p;  /* 'from' of local client is self! */
+    client_p->connection = mp_pool_get(connection_pool);
+    client_p->connection->since = CurrentTime;
+    client_p->connection->lasttime = CurrentTime;
+    client_p->connection->firsttime = CurrentTime;
+    client_p->connection->registration = REG_INIT;
 
     /* as good a place as any... */
-    dlinkAdd(client_p, &client_p->localClient->lclient_node, &unknown_list);
+    dlinkAdd(client_p, &client_p->connection->lclient_node, &unknown_list);
   }
   else
-    client_p->from = from; /* 'from' of local client is self! */
+    client_p->from = from;
 
   client_p->idhnext = client_p;
-  client_p->hnext  = client_p;
+  client_p->hnext = client_p;
   SetUnknown(client_p);
   strcpy(client_p->username, "unknown");
-  strcpy(client_p->svid, "0");
+  strcpy(client_p->account, "*");
 
   return client_p;
 }
@@ -119,48 +119,86 @@ make_client(struct Client *from)
 static void
 free_client(struct Client *client_p)
 {
-  assert(client_p);
   assert(client_p != &me);
   assert(client_p->hnext == client_p);
   assert(client_p->idhnext == client_p);
   assert(client_p->channel.head == NULL);
   assert(dlink_list_length(&client_p->channel) == 0);
   assert(dlink_list_length(&client_p->whowas) == 0);
-  assert(!IsServer(client_p) || client_p->serv);
+  assert(dlink_list_length(&client_p->svstags) == 0);
 
   MyFree(client_p->serv);
   MyFree(client_p->certfp);
 
   if (MyConnect(client_p))
   {
-    assert(client_p->localClient->invited.head == NULL);
-    assert(dlink_list_length(&client_p->localClient->invited) == 0);
-    assert(dlink_list_length(&client_p->localClient->watches) == 0);
+    assert(client_p->connection->invited.head == NULL);
+    assert(dlink_list_length(&client_p->connection->invited) == 0);
+    assert(dlink_list_length(&client_p->connection->watches) == 0);
     assert(IsClosing(client_p) && IsDead(client_p));
 
-    MyFree(client_p->localClient->challenge_response);
-    MyFree(client_p->localClient->challenge_operator);
-    client_p->localClient->challenge_response = NULL;
-    client_p->localClient->challenge_operator = NULL;
+    MyFree(client_p->connection->challenge_response);
+    client_p->connection->challenge_response = NULL;
+    MyFree(client_p->connection->challenge_operator);
+    client_p->connection->challenge_operator = NULL;
 
     /*
-     * clean up extra sockets from P-lines which have been discarded.
+     * Clean up extra sockets from listen {} blocks which have been discarded.
      */
-    if (client_p->localClient->listener)
+    if (client_p->connection->listener)
     {
-      listener_release(client_p->localClient->listener);
-      client_p->localClient->listener = NULL;
+      listener_release(client_p->connection->listener);
+      client_p->connection->listener = NULL;
     }
 
-    dbuf_clear(&client_p->localClient->buf_recvq);
-    dbuf_clear(&client_p->localClient->buf_sendq);
+    dbuf_clear(&client_p->connection->buf_recvq);
+    dbuf_clear(&client_p->connection->buf_sendq);
 
-    mp_pool_release(client_p->localClient);
+    mp_pool_release(client_p->connection);
   }
 
   mp_pool_release(client_p);
 }
 
+void
+client_attach_svstag(struct Client *client_p, unsigned int numeric,
+                     const char *umodes, const char *const tag)
+{
+  struct ServicesTag *svstag = NULL;
+  const struct user_modes *tab = NULL;
+
+  if (numeric >= ERR_LAST_ERR_MSG || *umodes != '+')
+    return;
+
+  svstag = MyCalloc(sizeof(*svstag));
+  svstag->numeric = numeric;
+  svstag->tag = xstrdup(tag);
+
+  for (const char *m = umodes + 1; *m; ++m)
+    if ((tab = umode_map[(unsigned char)*m]))
+      svstag->umodes |= tab->flag;
+
+  if (numeric != RPL_WHOISOPERATOR)
+    dlinkAddTail(svstag, &svstag->node, &client_p->svstags);
+  else
+    dlinkAdd(svstag, &svstag->node, &client_p->svstags);
+}
+
+void
+client_clear_svstags(struct Client *client_p)
+{
+  dlink_node *node = NULL, *node_next = NULL;
+
+  DLINK_FOREACH_SAFE(node, node_next, client_p->svstags.head)
+  {
+    struct ServicesTag *svstag = node->data;
+
+    dlinkDelete(&svstag->node, &client_p->svstags);
+    MyFree(svstag->tag);
+    MyFree(svstag);
+  }
+}
+
 /* check_pings_list()
  *
  * inputs	- pointer to list to check
@@ -172,11 +210,11 @@ check_pings_list(dlink_list *list)
 {
   char buf[IRCD_BUFSIZE] = "";
   int ping = 0;      /* ping time value from client */
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, list->head)
+  DLINK_FOREACH_SAFE(node, node_next, list->head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
     if (IsDead(client_p))
       continue;  /* Ignore it, its been exited already */
@@ -184,9 +222,9 @@ check_pings_list(dlink_list *list)
     if (!IsRegistered(client_p))
       ping = CONNECTTIMEOUT;
     else
-      ping = get_client_ping(&client_p->localClient->confs);
+      ping = get_client_ping(&client_p->connection->confs);
 
-    if (ping < CurrentTime - client_p->localClient->lasttime)
+    if (ping < CurrentTime - client_p->connection->lasttime)
     {
       if (!IsPingSent(client_p))
       {
@@ -196,12 +234,12 @@ check_pings_list(dlink_list *list)
          * it is still alive.
          */
         SetPingSent(client_p);
-        client_p->localClient->lasttime = CurrentTime - ping;
+        client_p->connection->lasttime = CurrentTime - ping;
         sendto_one(client_p, "PING :%s", ID_or_name(&me, client_p));
       }
       else
       {
-        if (CurrentTime - client_p->localClient->lasttime >= 2 * ping)
+        if (CurrentTime - client_p->connection->lasttime >= 2 * ping)
         {
           /*
            * If the client/server hasn't talked to us in 2*ping seconds
@@ -220,7 +258,7 @@ check_pings_list(dlink_list *list)
           }
 
           snprintf(buf, sizeof(buf), "Ping timeout: %d seconds",
-                   (int)(CurrentTime - client_p->localClient->lasttime));
+                   (int)(CurrentTime - client_p->connection->lasttime));
           exit_client(client_p, buf);
         }
       }
@@ -237,17 +275,17 @@ check_pings_list(dlink_list *list)
 static void
 check_unknowns_list(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, unknown_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, unknown_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
     /*
      * Check UNKNOWN connections - if they have been in this state
      * for > 30s, close them.
      */
-    if (IsAuthFinished(client_p) && (CurrentTime - client_p->localClient->firsttime) > 30)
+    if (IsAuthFinished(client_p) && (CurrentTime - client_p->connection->firsttime) > 30)
       exit_client(client_p, "Registration timed out");
   }
 }
@@ -297,62 +335,60 @@ void
 check_conf_klines(void)
 {
   struct MaskItem *conf = NULL;
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, local_client_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, local_client_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
-    /* If a client is already being exited
-     */
-    if (IsDead(client_p) || !IsClient(client_p))
+    /* If a client is already being exited */
+    if (IsDead(client_p))
       continue;
 
-    if ((conf = find_conf_by_address(NULL, &client_p->localClient->ip, CONF_DLINE,
-                                     client_p->localClient->aftype, NULL, NULL, 1)))
+    if ((conf = find_conf_by_address(NULL, &client_p->connection->ip, CONF_DLINE,
+                                     client_p->connection->aftype, NULL, NULL, 1)))
     {
       conf_try_ban(client_p, conf);
-      continue; /* and go examine next fd/client_p */
+      continue;  /* and go examine next Client */
     }
 
     if (ConfigGeneral.glines)
     {
-      if ((conf = find_conf_by_address(client_p->host, &client_p->localClient->ip,
-                                       CONF_GLINE, client_p->localClient->aftype,
+      if ((conf = find_conf_by_address(client_p->host, &client_p->connection->ip,
+                                       CONF_GLINE, client_p->connection->aftype,
                                        client_p->username, NULL, 1)))
       {
         conf_try_ban(client_p, conf);
-        /* and go examine next fd/client_p */
-        continue;
+        continue;  /* and go examine next Client */
       }
     }
 
-    if ((conf = find_conf_by_address(client_p->host, &client_p->localClient->ip,
-                                     CONF_KLINE, client_p->localClient->aftype,
+    if ((conf = find_conf_by_address(client_p->host, &client_p->connection->ip,
+                                     CONF_KLINE, client_p->connection->aftype,
                                      client_p->username, NULL, 1)))
     {
       conf_try_ban(client_p, conf);
-      continue;
+      continue;  /* and go examine next Client */
     }
 
-    if ((conf = find_matching_name_conf(CONF_XLINE,  client_p->info,
+    if ((conf = find_matching_name_conf(CONF_XLINE, client_p->info,
                                         NULL, NULL, 0)))
     {
       conf_try_ban(client_p, conf);
-      continue;
+      continue;  /* and go examine next Client */
     }
   }
 
-  /* also check the unknowns list for new dlines */
-  DLINK_FOREACH_SAFE(ptr, ptr_next, unknown_list.head)
+  /* Also check the unknowns list for new dlines */
+  DLINK_FOREACH_SAFE(node, node_next, unknown_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
-    if ((conf = find_conf_by_address(NULL, &client_p->localClient->ip, CONF_DLINE,
-                                     client_p->localClient->aftype, NULL, NULL, 1)))
+    if ((conf = find_conf_by_address(NULL, &client_p->connection->ip, CONF_DLINE,
+                                     client_p->connection->aftype, NULL, NULL, 1)))
     {
       conf_try_ban(client_p, conf);
-      continue; /* and go examine next fd/client_p */
+      continue;  /* and go examine next Client */
     }
   }
 }
@@ -389,8 +425,8 @@ conf_try_ban(struct Client *client_p, struct MaskItem *conf)
       type_string = kline_string;
       break;
     case CONF_DLINE:
-      if (find_conf_by_address(NULL, &client_p->localClient->ip, CONF_EXEMPT,
-                               client_p->localClient->aftype, NULL, NULL, 1))
+      if (find_conf_by_address(NULL, &client_p->connection->ip, CONF_EXEMPT,
+                               client_p->connection->aftype, NULL, NULL, 1))
         return;
       type_string = dline_string;
       break;
@@ -438,6 +474,7 @@ update_client_exit_stats(struct Client *client_p)
   if (IsClient(client_p))
   {
     assert(Count.total > 0);
+
     --Count.total;
     if (HasUMode(client_p, UMODE_OPER))
       --Count.oper;
@@ -483,23 +520,23 @@ find_person(const struct Client *const source_p, const char *name)
 struct Client *
 find_chasing(struct Client *source_p, const char *name)
 {
-  struct Client *who = find_person(source_p, name);
+  struct Client *target_p = find_person(source_p, name);
 
-  if (who)
-    return who;
+  if (target_p)
+    return target_p;
 
   if (IsDigit(*name))
     return NULL;
 
-  if ((who = whowas_get_history(name,
-                         (time_t)ConfigGeneral.kill_chase_time_limit))
-                         == NULL)
+  target_p = whowas_get_history(name, (time_t)ConfigGeneral.kill_chase_time_limit);
+
+  if (!target_p)
   {
     sendto_one_numeric(source_p, &me, ERR_NOSUCHNICK, name);
     return NULL;
   }
 
-  return who;
+  return target_p;
 }
 
 /*
@@ -525,8 +562,6 @@ get_client_name(const struct Client *client_p, enum addr_mask_type type)
 {
   static char buf[HOSTLEN * 2 + USERLEN + 5];
 
-  assert(client_p);
-
   if (!MyConnect(client_p))
     return client_p->name;
 
@@ -538,10 +573,6 @@ get_client_name(const struct Client *client_p, enum addr_mask_type type)
       type = MASK_IP;
   }
 
-  if (ConfigGeneral.hide_spoof_ips)
-    if (IsIPSpoof(client_p) && type == SHOW_IP)
-      type = MASK_IP;
-
   /* And finally, let's get the host information, ip or name */
   switch (type)
   {
@@ -551,7 +582,7 @@ get_client_name(const struct Client *client_p, enum addr_mask_type type)
                client_p->username, client_p->sockhost);
       break;
     case MASK_IP:
-      if (client_p->localClient->aftype == AF_INET)
+      if (client_p->connection->aftype == AF_INET)
         snprintf(buf, sizeof(buf), "%s[%s@255.255.255.255]",
                  client_p->name, client_p->username);
       else
@@ -570,13 +601,13 @@ get_client_name(const struct Client *client_p, enum addr_mask_type type)
 void
 free_exited_clients(void)
 {
-  dlink_node *ptr = NULL, *next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, next, dead_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, dead_list.head)
   {
-    free_client(ptr->data);
-    dlinkDelete(ptr, &dead_list);
-    free_dlink_node(ptr);
+    free_client(node->data);
+    dlinkDelete(node, &dead_list);
+    free_dlink_node(node);
   }
 }
 
@@ -589,7 +620,7 @@ free_exited_clients(void)
 static void
 exit_one_client(struct Client *source_p, const char *comment)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
   assert(!IsMe(source_p));
   assert(source_p != &me);
@@ -608,8 +639,9 @@ exit_one_client(struct Client *source_p, const char *comment)
     sendto_common_channels_local(source_p, 0, 0, ":%s!%s@%s QUIT :%s",
                                  source_p->name, source_p->username,
                                  source_p->host, comment);
-    DLINK_FOREACH_SAFE(ptr, ptr_next, source_p->channel.head)
-      remove_user_from_channel(ptr->data);
+
+    DLINK_FOREACH_SAFE(node, node_next, source_p->channel.head)
+      remove_user_from_channel(node->data);
 
     whowas_add_history(source_p, 0);
     whowas_off_history(source_p);
@@ -619,8 +651,8 @@ exit_one_client(struct Client *source_p, const char *comment)
     if (MyConnect(source_p))
     {
       /* Clean up invitefield */
-      DLINK_FOREACH_SAFE(ptr, ptr_next, source_p->localClient->invited.head)
-        del_invite(ptr->data, source_p);
+      DLINK_FOREACH_SAFE(node, node_next, source_p->connection->invited.head)
+        del_invite(node->data, source_p);
 
       del_all_accepts(source_p);
     }
@@ -630,13 +662,14 @@ exit_one_client(struct Client *source_p, const char *comment)
     dlinkDelete(&source_p->lnode, &source_p->servptr->serv->server_list);
     dlinkDelete(&source_p->node, &global_client_list);
 
-    if ((ptr = dlinkFindDelete(&global_server_list, source_p)))
-      free_dlink_node(ptr);
+    if ((node = dlinkFindDelete(&global_server_list, source_p)))
+      free_dlink_node(node);
   }
 
   /* Remove source_p from the client lists */
   if (source_p->id[0])
     hash_del_id(source_p);
+
   if (source_p->name[0])
     hash_del_client(source_p);
 
@@ -662,15 +695,15 @@ exit_one_client(struct Client *source_p, const char *comment)
 static void
 recurse_remove_clients(struct Client *source_p, const char *comment)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, source_p->serv->client_list.head)
-    exit_one_client(ptr->data, comment);
+  DLINK_FOREACH_SAFE(node, node_next, source_p->serv->client_list.head)
+    exit_one_client(node->data, comment);
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, source_p->serv->server_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, source_p->serv->server_list.head)
   {
-    recurse_remove_clients(ptr->data, comment);
-    exit_one_client(ptr->data, comment);
+    recurse_remove_clients(node->data, comment);
+    exit_one_client(node->data, comment);
   }
 }
 
@@ -694,7 +727,7 @@ recurse_remove_clients(struct Client *source_p, const char *comment)
 void
 exit_client(struct Client *source_p, const char *comment)
 {
-  dlink_node *m = NULL;
+  dlink_node *node = NULL;
 
   assert(!IsMe(source_p));
   assert(source_p != &me);
@@ -712,10 +745,10 @@ exit_client(struct Client *source_p, const char *comment)
     if (HasFlag(source_p, FLAGS_IPHASH))
     {
       DelFlag(source_p, FLAGS_IPHASH);
-      ipcache_remove_address(&source_p->localClient->ip);
+      ipcache_remove_address(&source_p->connection->ip);
     }
 
-    delete_auth(&source_p->localClient->auth);
+    delete_auth(&source_p->connection->auth);
 
     /*
      * This source_p could have status of one of STAT_UNKNOWN, STAT_CONNECTING
@@ -728,44 +761,49 @@ exit_client(struct Client *source_p, const char *comment)
     {
       assert(dlinkFind(&unknown_list, source_p));
 
-      dlinkDelete(&source_p->localClient->lclient_node, &unknown_list);
+      dlinkDelete(&source_p->connection->lclient_node, &unknown_list);
     }
     else if (IsClient(source_p))
     {
-      time_t on_for = CurrentTime - source_p->localClient->firsttime;
+      time_t on_for = CurrentTime - source_p->connection->firsttime;
+
       assert(Count.local > 0);
-      Count.local--;
+
+      --Count.local;
 
       if (HasUMode(source_p, UMODE_OPER))
-        if ((m = dlinkFindDelete(&oper_list, source_p)))
-          free_dlink_node(m);
+        if ((node = dlinkFindDelete(&oper_list, source_p)))
+          free_dlink_node(node);
 
       assert(dlinkFind(&local_client_list, source_p));
-      dlinkDelete(&source_p->localClient->lclient_node, &local_client_list);
+      dlinkDelete(&source_p->connection->lclient_node, &local_client_list);
 
-      if (source_p->localClient->list_task)
+      if (source_p->connection->list_task)
         free_list_task(source_p);
 
       watch_del_watch_list(source_p);
+      client_clear_svstags(source_p);
+
       sendto_realops_flags(UMODE_CCONN, L_ALL, SEND_NOTICE,
                            "Client exiting: %s (%s@%s) [%s] [%s]",
                            source_p->name, source_p->username, source_p->host, comment,
-                           ConfigGeneral.hide_spoof_ips && IsIPSpoof(source_p) ?
-                           "255.255.255.255" : source_p->sockhost);
+                           source_p->sockhost);
+
       ilog(LOG_TYPE_USER, "%s (%3u:%02u:%02u): %s!%s@%s %llu/%llu",
-           myctime(source_p->localClient->firsttime), (unsigned int)(on_for / 3600),
+           myctime(source_p->connection->firsttime), (unsigned int)(on_for / 3600),
            (unsigned int)((on_for % 3600)/60), (unsigned int)(on_for % 60),
            source_p->name, source_p->username, source_p->host,
-           source_p->localClient->send.bytes>>10,
-           source_p->localClient->recv.bytes>>10);
+           source_p->connection->send.bytes>>10,
+           source_p->connection->recv.bytes>>10);
     }
     else if (IsServer(source_p))
     {
       assert(Count.myserver > 0);
+
       --Count.myserver;
 
       assert(dlinkFind(&local_server_list, source_p));
-      dlinkDelete(&source_p->localClient->lclient_node, &local_server_list);
+      dlinkDelete(&source_p->connection->lclient_node, &local_server_list);
     }
 
     if (!IsDead(source_p))
@@ -796,8 +834,8 @@ exit_client(struct Client *source_p, const char *comment)
   {
     char splitstr[HOSTLEN + HOSTLEN + 2] = "";
 
-    /* This shouldn't ever happen */
-    assert(source_p->serv && source_p->servptr);
+    assert(source_p->serv);
+    assert(source_p->servptr);
 
     if (ConfigServerHide.hide_servers)
       /*
@@ -811,26 +849,29 @@ exit_client(struct Client *source_p, const char *comment)
 
     /* Send SQUIT for source_p in every direction. source_p is already off of local_server_list here */
     if (!HasFlag(source_p, FLAGS_SQUIT))
-      sendto_server(NULL, NOCAPS, NOCAPS, "SQUIT %s :%s", source_p->id, comment);
+      sendto_server(NULL, 0, 0, "SQUIT %s :%s", source_p->id, comment);
 
     /* Now exit the clients internally */
     recurse_remove_clients(source_p, splitstr);
 
     if (MyConnect(source_p))
     {
+      int connected = CurrentTime - source_p->connection->firsttime;
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "%s was connected for %d seconds.  %llu/%llu sendK/recvK.",
-                           source_p->name, (int)(CurrentTime - source_p->localClient->firsttime),
-                           source_p->localClient->send.bytes >> 10,
-                           source_p->localClient->recv.bytes >> 10);
-      ilog(LOG_TYPE_IRCD, "%s was connected for %d seconds.  %llu/%llu sendK/recvK.",
-           source_p->name, (int)(CurrentTime - source_p->localClient->firsttime),
-           source_p->localClient->send.bytes >> 10,
-           source_p->localClient->recv.bytes >> 10);
+                           "%s was connected for %d day%s, %2d:%02d:%02d. %llu/%llu sendK/recvK.",
+                           source_p->name, connected/86400, (connected/86400 == 1) ? "" : "s",
+                           (connected % 86400) / 3600, (connected % 3600) / 60, connected % 60,
+                           source_p->connection->send.bytes >> 10,
+                           source_p->connection->recv.bytes >> 10);
+      ilog(LOG_TYPE_IRCD, "%s was connected for %d day%s, %2d:%02d:%02d. %llu/%llu sendK/recvK.",
+           source_p->name, connected/86400, (connected/86400 == 1) ? "" : "s",
+           (connected % 86400) / 3600, (connected % 3600) / 60, connected % 60,
+           source_p->connection->send.bytes >> 10,
+           source_p->connection->recv.bytes >> 10);
     }
   }
   else if (IsClient(source_p) && !HasFlag(source_p, FLAGS_KILLED))
-    sendto_server(source_p->from, NOCAPS, NOCAPS, ":%s QUIT :%s",
+    sendto_server(source_p->from, 0, 0, ":%s QUIT :%s",
                   source_p->id, comment);
 
   /* The client *better* be off all of the lists */
@@ -849,21 +890,21 @@ exit_client(struct Client *source_p, const char *comment)
 void
 dead_link_on_write(struct Client *client_p, int ierrno)
 {
-  dlink_node *ptr;
+  dlink_node *node;
 
   if (IsDefunct(client_p))
     return;
 
-  dbuf_clear(&client_p->localClient->buf_recvq);
-  dbuf_clear(&client_p->localClient->buf_sendq);
+  dbuf_clear(&client_p->connection->buf_recvq);
+  dbuf_clear(&client_p->connection->buf_sendq);
 
   assert(dlinkFind(&abort_list, client_p) == NULL);
-  ptr = make_dlink_node();
+  node = make_dlink_node();
   /* don't let exit_aborted_clients() finish yet */
-  dlinkAddTail(client_p, ptr, &abort_list);
+  dlinkAddTail(client_p, node, &abort_list);
 
   if (eac_next == NULL)
-    eac_next = ptr;
+    eac_next = node;
 
   SetDead(client_p); /* You are dead my friend */
 }
@@ -881,14 +922,14 @@ dead_link_on_read(struct Client *client_p, int error)
   if (IsDefunct(client_p))
     return;
 
-  dbuf_clear(&client_p->localClient->buf_recvq);
-  dbuf_clear(&client_p->localClient->buf_sendq);
+  dbuf_clear(&client_p->connection->buf_recvq);
+  dbuf_clear(&client_p->connection->buf_sendq);
 
-  current_error = get_sockerr(client_p->localClient->fd.fd);
+  current_error = get_sockerr(client_p->connection->fd.fd);
 
   if (IsServer(client_p) || IsHandshake(client_p))
   {
-    int connected = CurrentTime - client_p->localClient->firsttime;
+    int connected = CurrentTime - client_p->connection->firsttime;
 
     if (error == 0)
     {
@@ -914,7 +955,7 @@ dead_link_on_read(struct Client *client_p, int error)
     }
 
     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "%s had been connected for %d day%s, %2d:%02d:%02d",
+                         "%s was connected for %d day%s, %2d:%02d:%02d",
                          client_p->name, connected/86400,
                          (connected/86400 == 1) ? "" : "s",
                          (connected % 86400) / 3600, (connected % 3600) / 60,
@@ -977,7 +1018,7 @@ exit_aborted_clients(void)
 void
 del_accept(struct split_nuh_item *accept_p, struct Client *client_p)
 {
-  dlinkDelete(&accept_p->node, &client_p->localClient->acceptlist);
+  dlinkDelete(&accept_p->node, &client_p->connection->acceptlist);
 
   MyFree(accept_p->nickptr);
   MyFree(accept_p->userptr);
@@ -990,11 +1031,11 @@ find_accept(const char *nick, const char *user,
             const char *host, struct Client *client_p,
             int (*cmpfunc)(const char *, const char *))
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, client_p->localClient->acceptlist.head)
+  DLINK_FOREACH(node, client_p->connection->acceptlist.head)
   {
-    struct split_nuh_item *accept_p = ptr->data;
+    struct split_nuh_item *accept_p = node->data;
 
     if (!cmpfunc(accept_p->nickptr, nick) &&
         !cmpfunc(accept_p->userptr, user) &&
@@ -1016,15 +1057,19 @@ int
 accept_message(struct Client *source,
                struct Client *target)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
+
+  if (HasFlag(source, FLAGS_SERVICE) ||
+      (HasUMode(source, UMODE_OPER) && ConfigGeneral.opers_bypass_callerid))
+    return 1;
 
   if (source == target || find_accept(source->name, source->username,
                                       source->host, target, match))
     return 1;
 
-  if (HasUMode(target, UMODE_SOFTCALLERID))
-    DLINK_FOREACH(ptr, target->channel.head)
-      if (IsMember(source, ((struct Membership *)ptr->data)->chptr))
+  if (!HasUMode(target, UMODE_CALLERID) && HasUMode(target, UMODE_SOFTCALLERID))
+    DLINK_FOREACH(node, target->channel.head)
+      if (IsMember(source, ((struct Membership *)node->data)->chptr))
         return 1;
 
   return 0;
@@ -1039,25 +1084,27 @@ accept_message(struct Client *source,
 void
 del_all_accepts(struct Client *client_p)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, client_p->localClient->acceptlist.head)
-    del_accept(ptr->data, client_p);
+  DLINK_FOREACH_SAFE(node, node_next, client_p->connection->acceptlist.head)
+    del_accept(node->data, client_p);
 }
 
 unsigned int
-idle_time_get(const struct Client *source_p, const struct Client *target_p)
+client_get_idle_time(const struct Client *source_p,
+                     const struct Client *target_p)
 {
   unsigned int idle = 0;
   unsigned int min_idle = 0;
   unsigned int max_idle = 0;
-  const struct ClassItem *class = get_class_ptr(&target_p->localClient->confs);
+  const struct ClassItem *const class = get_class_ptr(&target_p->connection->confs);
 
   if (!(class->flags & CLASS_FLAGS_FAKE_IDLE) || target_p == source_p)
-    return CurrentTime - target_p->localClient->last_privmsg;
+    return CurrentTime - target_p->connection->last_privmsg;
+
   if (HasUMode(source_p, UMODE_OPER) &&
       !(class->flags & CLASS_FLAGS_HIDE_IDLE_FROM_OPERS))
-    return CurrentTime - target_p->localClient->last_privmsg;
+    return CurrentTime - target_p->connection->last_privmsg;
 
   min_idle = class->min_idle;
   max_idle = class->max_idle;
@@ -1068,7 +1115,7 @@ idle_time_get(const struct Client *source_p, const struct Client *target_p)
   if (class->flags & CLASS_FLAGS_RANDOM_IDLE)
     idle = genrand_int32();
   else
-    idle = CurrentTime - target_p->localClient->last_privmsg;
+    idle = CurrentTime - target_p->connection->last_privmsg;
 
   if (!max_idle)
     idle = 0;
@@ -1098,6 +1145,6 @@ client_init(void)
   };
 
   client_pool = mp_pool_new(sizeof(struct Client), MP_CHUNK_SIZE_CLIENT);
-  lclient_pool = mp_pool_new(sizeof(struct LocalUser), MP_CHUNK_SIZE_LCLIENT);
+  connection_pool = mp_pool_new(sizeof(struct Connection), MP_CHUNK_SIZE_CONNECTION);
   event_add(&event_ping, NULL);
 }
