@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file conf_class.c
  * \brief Configuration managment for class{} blocks
- * \version $Id: conf_class.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: conf_class.c 5410 2015-01-24 19:12:28Z michael $
  */
 
 #include "stdinc.h"
@@ -47,7 +47,7 @@ class_get_list(void)
 struct ClassItem *
 class_make(void)
 {
-  struct ClassItem *class = MyCalloc(sizeof(*class));
+  struct ClassItem *const class = MyCalloc(sizeof(*class));
 
   class->active    = 1;
   class->con_freq  = DEFAULT_CONNECTFREQUENCY;
@@ -62,7 +62,7 @@ class_make(void)
 }
 
 void
-class_free(struct ClassItem *class)
+class_free(struct ClassItem *const class)
 {
   assert(class != class_default);
   assert(class->active    == 0);
@@ -79,14 +79,14 @@ class_init(void)
   (class_default = class_make())->name = xstrdup("default");
 }
 
-struct ClassItem *
+const struct ClassItem *
 get_class_ptr(const dlink_list *const list)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *const node = list->head;
 
-  if ((ptr = list->head))
+  if (node)
   {
-    const struct MaskItem *conf = ptr->data;
+    const struct MaskItem *const conf = node->data;
 
     assert(conf->class);
     assert(conf->type & (CONF_OPER | CONF_CLIENT | CONF_SERVER));
@@ -100,73 +100,25 @@ get_class_ptr(const dlink_list *const list)
 const char *
 get_client_class(const dlink_list *const list)
 {
-  const dlink_node *ptr = NULL;
-
-  if ((ptr = list->head))
-  {
-    const struct MaskItem *conf = ptr->data;
-
-    assert(conf->class);
-    assert(conf->type & (CONF_OPER | CONF_CLIENT | CONF_SERVER));
-
-    return conf->class->name;
-  }
-
-  return class_default->name;
+  return get_class_ptr(list)->name;
 }
 
 unsigned int
 get_client_ping(const dlink_list *const list)
 {
-  const dlink_node *ptr = NULL;
-
-  if ((ptr = list->head))
-  {
-    const struct MaskItem *conf = ptr->data;
-
-    assert(conf->class);
-    assert(conf->type & (CONF_OPER | CONF_CLIENT | CONF_SERVER));
-
-    return conf->class->ping_freq;
-  }
-
-  return class_default->ping_freq;
+  return get_class_ptr(list)->ping_freq;
 }
 
 unsigned int
 get_sendq(const dlink_list *const list)
 {
-  const dlink_node *ptr = NULL;
-
-  if ((ptr = list->head))
-  {
-    const struct MaskItem *conf = ptr->data;
-
-    assert(conf->class);
-    assert(conf->type & (CONF_OPER | CONF_CLIENT | CONF_SERVER));
-
-    return conf->class->max_sendq;
-  }
-
-  return class_default->max_sendq;
+  return get_class_ptr(list)->max_sendq;
 }
 
 unsigned int
 get_recvq(const dlink_list *const list)
 {
-  const dlink_node *ptr = NULL;
-
-  if ((ptr = list->head))
-  {
-    const struct MaskItem *conf = ptr->data;
-
-    assert(conf->class);
-    assert(conf->type & (CONF_OPER | CONF_CLIENT | CONF_SERVER));
-
-    return conf->class->max_recvq;
-  }
-
-  return class_default->max_recvq;
+  return get_class_ptr(list)->max_recvq;
 }
 
 /*
@@ -177,11 +129,11 @@ get_recvq(const dlink_list *const list)
 struct ClassItem *
 class_find(const char *name, int active)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, class_list.head)
+  DLINK_FOREACH(node, class_list.head)
   {
-    struct ClassItem *class = ptr->data;
+    struct ClassItem *class = node->data;
 
     if (!irccmp(class->name, name))
       return active && !class->active ? NULL : class;
@@ -197,20 +149,20 @@ class_find(const char *name, int active)
 void
 class_mark_for_deletion(void)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH_PREV(ptr, class_list.tail->prev)
-    ((struct ClassItem *)ptr->data)->active = 0;
+  DLINK_FOREACH_PREV(node, class_list.tail->prev)
+    ((struct ClassItem *)node->data)->active = 0;
 }
 
 void
 class_delete_marked(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, class_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, class_list.head)
   {
-    struct ClassItem *class = ptr->data;
+    struct ClassItem *class = node->data;
 
     if (!class->active && !class->ref_count)
     {
@@ -233,7 +185,7 @@ class_delete_marked(void)
 int
 cidr_limit_reached(int over_rule, struct irc_ssaddr *ip, struct ClassItem *class)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   struct CidrItem *cidr = NULL;
 
   if (class->number_per_cidr == 0)
@@ -244,9 +196,9 @@ cidr_limit_reached(int over_rule, struct irc_ssaddr *ip, struct ClassItem *class
     if (class->cidr_bitlen_ipv4 == 0)
       return 0;
 
-    DLINK_FOREACH(ptr, class->list_ipv4.head)
+    DLINK_FOREACH(node, class->list_ipv4.head)
     {
-      cidr = ptr->data;
+      cidr = node->data;
 
       if (match_ipv4(ip, &cidr->mask, class->cidr_bitlen_ipv4))
       {
@@ -266,9 +218,9 @@ cidr_limit_reached(int over_rule, struct irc_ssaddr *ip, struct ClassItem *class
   }
   else if (class->cidr_bitlen_ipv6 > 0)
   {
-    DLINK_FOREACH(ptr, class->list_ipv6.head)
+    DLINK_FOREACH(node, class->list_ipv6.head)
     {
-      cidr = ptr->data;
+      cidr = node->data;
 
       if (match_ipv6(ip, &cidr->mask, class->cidr_bitlen_ipv6))
       {
@@ -301,9 +253,7 @@ cidr_limit_reached(int over_rule, struct irc_ssaddr *ip, struct ClassItem *class
 void
 remove_from_cidr_check(struct irc_ssaddr *ip, struct ClassItem *aclass)
 {
-  dlink_node *ptr = NULL;
-  dlink_node *next_ptr = NULL;
-  struct CidrItem *cidr;
+  dlink_node *node = NULL, *node_next = NULL;
 
   if (aclass->number_per_cidr == 0)
     return;
@@ -313,9 +263,9 @@ remove_from_cidr_check(struct irc_ssaddr *ip, struct ClassItem *aclass)
     if (aclass->cidr_bitlen_ipv4 == 0)
       return;
 
-    DLINK_FOREACH_SAFE(ptr, next_ptr, aclass->list_ipv4.head)
+    DLINK_FOREACH_SAFE(node, node_next, aclass->list_ipv4.head)
     {
-      cidr = ptr->data;
+      struct CidrItem *cidr = node->data;
 
       if (match_ipv4(ip, &cidr->mask, aclass->cidr_bitlen_ipv4))
       {
@@ -323,7 +273,7 @@ remove_from_cidr_check(struct irc_ssaddr *ip, struct ClassItem *aclass)
 
         if (cidr->number_on_this_cidr == 0)
         {
-          dlinkDelete(ptr, &aclass->list_ipv4);
+          dlinkDelete(node, &aclass->list_ipv4);
           MyFree(cidr);
           return;
         }
@@ -332,9 +282,9 @@ remove_from_cidr_check(struct irc_ssaddr *ip, struct ClassItem *aclass)
   }
   else if (aclass->cidr_bitlen_ipv6 > 0)
   {
-    DLINK_FOREACH_SAFE(ptr, next_ptr, aclass->list_ipv6.head)
+    DLINK_FOREACH_SAFE(node, node_next, aclass->list_ipv6.head)
     {
-      cidr = ptr->data;
+      struct CidrItem *cidr = node->data;
 
       if (match_ipv6(ip, &cidr->mask, aclass->cidr_bitlen_ipv6))
       {
@@ -342,7 +292,7 @@ remove_from_cidr_check(struct irc_ssaddr *ip, struct ClassItem *aclass)
 
         if (cidr->number_on_this_cidr == 0)
         {
-          dlinkDelete(ptr, &aclass->list_ipv6);
+          dlinkDelete(node, &aclass->list_ipv6);
           MyFree(cidr);
           return;
         }
@@ -354,18 +304,18 @@ remove_from_cidr_check(struct irc_ssaddr *ip, struct ClassItem *aclass)
 void
 rebuild_cidr_list(struct ClassItem *class)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   destroy_cidr_class(class);
 
-  DLINK_FOREACH(ptr, local_client_list.head)
+  DLINK_FOREACH(node, local_client_list.head)
   {
-    struct Client *client_p = ptr->data;
-    struct MaskItem *conf = client_p->localClient->confs.tail->data;
+    struct Client *client_p = node->data;
+    struct MaskItem *conf = client_p->connection->confs.tail->data;
 
     if (conf && (conf->type == CONF_CLIENT))
       if (conf->class == class)
-        cidr_limit_reached(1, &client_p->localClient->ip, class);
+        cidr_limit_reached(1, &client_p->connection->ip, class);
   }
 }
 
@@ -379,12 +329,12 @@ rebuild_cidr_list(struct ClassItem *class)
 static void
 destroy_cidr_list(dlink_list *list)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, list->head)
+  DLINK_FOREACH_SAFE(node, node_next, list->head)
   {
-    dlinkDelete(ptr, list);
-    MyFree(ptr->data);
+    dlinkDelete(node, list);
+    MyFree(node->data);
   }
 }
 
