@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -55,7 +55,7 @@ static int
 m_pseudo(struct Client *source_p, int parc, char *parv[])
 {
   char buffer[IRCD_BUFSIZE] = "";
-  const struct pseudo_cmd *pseudo = (const struct pseudo_cmd *)parv[1];
+  const struct pseudo_cmd *const pseudo = (const struct pseudo_cmd *)parv[1];
   struct Client *target_p = NULL;
   struct Client *server_p = NULL;
   const char *msg = parv[parc - 1];
@@ -105,7 +105,7 @@ pseudo_register(const char *name, const char *nick,
 
   cmd->msg.cmd = cmd->command;
   cmd->msg.args_max = 2;
-  cmd->msg.flags = MFLG_EXTRA|MFLG_SLOW;
+  cmd->msg.flags = MFLG_EXTRA | MFLG_SLOW;
   cmd->msg.extra = cmd;
   cmd->msg.handlers[UNREGISTERED_HANDLER] = m_unregistered;
   cmd->msg.handlers[CLIENT_HANDLER] = m_pseudo;
@@ -121,11 +121,11 @@ pseudo_register(const char *name, const char *nick,
 void
 pseudo_clear(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, pseudo_cmd_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, pseudo_cmd_list.head)
   {
-    struct pseudo_cmd *cmd = ptr->data;
+    struct pseudo_cmd *cmd = node->data;
     assert(find_command(cmd->msg.cmd));
 
     mod_del_cmd(&cmd->msg);
