@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2014 ircd-hybrid development team
+ *  Copyright (c) 2001-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file hostmask.c
  * \brief Code to efficiently find IP & hostmask based configs.
- * \version $Id: hostmask.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: hostmask.c 5459 2015-02-03 22:24:23Z michael $
  */
 
 #include "stdinc.h"
@@ -44,6 +44,9 @@
                          ch = ch - 'a' + 10; \
                        } while (0);
 
+/* Hashtable stuff...now external as it's used in m_stats.c */
+dlink_list atable[ATABLE_SIZE];
+
 /* The mask parser/type determination code... */
 
 /* int try_parse_v6_netmask(const char *, struct irc_ssaddr *, int *);
@@ -68,7 +71,7 @@ try_parse_v6_netmask(const char *text, struct irc_ssaddr *addr, int *b)
   int bits = 128;
   int deficit = 0;
   short dc[8];
-  struct sockaddr_in6 *v6 = (struct sockaddr_in6 *)addr;
+  struct sockaddr_in6 *const v6 = (struct sockaddr_in6 *)addr;
 
   for (const char *p = text; (c = *p); ++p)
   {
@@ -175,7 +178,7 @@ try_parse_v4_netmask(const char *text, struct irc_ssaddr *addr, int *b)
   unsigned char addb[4];
   int n = 0, bits = 0;
   char c;
-  struct sockaddr_in *v4 = (struct sockaddr_in *)addr;
+  struct sockaddr_in *const v4 = (struct sockaddr_in *)addr;
 
   digits[n++] = text;
 
@@ -267,8 +270,8 @@ int
 match_ipv6(const struct irc_ssaddr *addr, const struct irc_ssaddr *mask, int bits)
 {
   int i, m, n = bits / 8;
-  const struct sockaddr_in6 *v6 = (const struct sockaddr_in6 *)addr;
-  const struct sockaddr_in6 *v6mask = (const struct sockaddr_in6 *)mask;
+  const struct sockaddr_in6 *const v6 = (const struct sockaddr_in6 *)addr;
+  const struct sockaddr_in6 *const v6mask = (const struct sockaddr_in6 *)mask;
 
   for (i = 0; i < n; ++i)
     if (v6->sin6_addr.s6_addr[i] != v6mask->sin6_addr.s6_addr[i])
@@ -290,8 +293,8 @@ match_ipv6(const struct irc_ssaddr *addr, const struct irc_ssaddr *mask, int bit
 int
 match_ipv4(const struct irc_ssaddr *addr, const struct irc_ssaddr *mask, int bits)
 {
-  const struct sockaddr_in *v4 = (const struct sockaddr_in *)addr;
-  const struct sockaddr_in *v4mask = (const struct sockaddr_in *)mask;
+  const struct sockaddr_in *const v4 = (const struct sockaddr_in *)addr;
+  const struct sockaddr_in *const v4mask = (const struct sockaddr_in *)mask;
 
   if ((ntohl(v4->sin_addr.s_addr) & ~((1 << (32 - bits)) - 1)) !=
       ntohl(v4mask->sin_addr.s_addr))
@@ -330,7 +333,7 @@ mask_addr(struct irc_ssaddr *ip, int bits)
     m = bits % 8;
     v6_base_ip = (struct sockaddr_in6 *)ip;
 
-    mask = ~((1 << (8 - m)) -1 );
+    mask = ~((1 << (8 - m)) - 1);
     v6_base_ip->sin6_addr.s6_addr[n] = v6_base_ip->sin6_addr.s6_addr[n] & mask;
 
     for (i = n + 1; i < 16; i++)
@@ -338,15 +341,6 @@ mask_addr(struct irc_ssaddr *ip, int bits)
   }
 }
 
-/* Hashtable stuff...now external as it's used in m_stats.c */
-dlink_list atable[ATABLE_SIZE];
-
-void
-init_host_hash(void)
-{
-  memset(&atable, 0, sizeof(atable));
-}
-
 /* unsigned long hash_ipv4(struct irc_ssaddr*)
  * Input: An IP address.
  * Output: A hash value of the IP address.
@@ -357,7 +351,7 @@ hash_ipv4(const struct irc_ssaddr *addr, int bits)
 {
   if (bits != 0)
   {
-    const struct sockaddr_in *v4 = (const struct sockaddr_in *)addr;
+    const struct sockaddr_in *const v4 = (const struct sockaddr_in *)addr;
     uint32_t av = ntohl(v4->sin_addr.s_addr) & ~((1 << (32 - bits)) - 1);
 
     return (av ^ (av >> 12) ^ (av >> 24)) & (ATABLE_SIZE - 1);
@@ -375,7 +369,7 @@ static uint32_t
 hash_ipv6(const struct irc_ssaddr *addr, int bits)
 {
   uint32_t v = 0, n;
-  const struct sockaddr_in6 *v6 = (const struct sockaddr_in6 *)addr;
+  const struct sockaddr_in6 *const v6 = (const struct sockaddr_in6 *)addr;
 
   for (n = 0; n < 16; ++n)
   {
@@ -446,7 +440,7 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
                      int fam, const char *username, const char *password, int do_match)
 {
   unsigned int hprecv = 0;
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   struct MaskItem *hprec = NULL;
   struct AddressRec *arec = NULL;
   int b;
@@ -459,9 +453,9 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
     {
       for (b = 128; b >= 0; b -= 16)
       {
-        DLINK_FOREACH(ptr, atable[hash_ipv6(addr, b)].head)
+        DLINK_FOREACH(node, atable[hash_ipv6(addr, b)].head)
         {
-          arec = ptr->data;
+          arec = node->data;
 
           if ((arec->type == type) &&
               arec->precedence > hprecv &&
@@ -482,9 +476,9 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
     {
       for (b = 32; b >= 0; b -= 8)
       {
-        DLINK_FOREACH(ptr, atable[hash_ipv4(addr, b)].head)
+        DLINK_FOREACH(node, atable[hash_ipv4(addr, b)].head)
         {
-          arec = ptr->data;
+          arec = node->data;
 
           if ((arec->type == type) &&
               arec->precedence > hprecv &&
@@ -509,9 +503,9 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
 
     while (1)
     {
-        DLINK_FOREACH(ptr, atable[hash_text(p)].head)
+        DLINK_FOREACH(node, atable[hash_text(p)].head)
         {
-          arec = ptr->data;
+          arec = node->data;
           if ((arec->type == type) &&
             arec->precedence > hprecv &&
             (arec->masktype == HM_HOST) &&
@@ -530,9 +524,9 @@ find_conf_by_address(const char *name, struct irc_ssaddr *addr, unsigned int typ
       ++p;
     }
 
-    DLINK_FOREACH(ptr, atable[0].head)
+    DLINK_FOREACH(node, atable[0].head)
     {
-      arec = ptr->data;
+      arec = node->data;
 
       if (arec->type == type &&
           arec->precedence > hprecv &&
@@ -618,11 +612,11 @@ find_dline_conf(struct irc_ssaddr *addr, int aftype)
 struct AddressRec *
 add_conf_by_address(const unsigned int type, struct MaskItem *conf)
 {
-  const char *hostname = conf->host;
-  const char *username = conf->user;
+  struct AddressRec *arec = NULL;
+  const char *const hostname = conf->host;
+  const char *const username = conf->user;
   static unsigned int prec_value = 0xFFFFFFFF;
   int bits = 0;
-  struct AddressRec *arec = NULL;
 
   assert(type && !EmptyString(hostname));
 
@@ -666,7 +660,7 @@ delete_one_address_conf(const char *address, struct MaskItem *conf)
 {
   int bits = 0;
   uint32_t hv = 0;
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   struct irc_ssaddr addr;
 
   switch (parse_netmask(address, &addr, &bits))
@@ -686,9 +680,9 @@ delete_one_address_conf(const char *address, struct MaskItem *conf)
       break;
   }
 
-  DLINK_FOREACH(ptr, atable[hv].head)
+  DLINK_FOREACH(node, atable[hv].head)
   {
-    struct AddressRec *arec = ptr->data;
+    struct AddressRec *arec = node->data;
 
     if (arec->conf == conf)
     {
@@ -713,13 +707,13 @@ delete_one_address_conf(const char *address, struct MaskItem *conf)
 void
 clear_out_address_conf(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
-    DLINK_FOREACH_SAFE(ptr, ptr_next, atable[i].head)
+    DLINK_FOREACH_SAFE(node, node_next, atable[i].head)
     {
-      struct AddressRec *arec = ptr->data;
+      struct AddressRec *arec = node->data;
 
       /*
        * We keep the temporary K-lines and destroy the permanent ones,
@@ -739,7 +733,7 @@ clear_out_address_conf(void)
 }
 
 static void
-hostmask_send_expiration(struct AddressRec *arec)
+hostmask_send_expiration(const struct AddressRec *const arec)
 {
   char ban_type = '\0';
 
@@ -769,13 +763,13 @@ hostmask_send_expiration(struct AddressRec *arec)
 void
 hostmask_expire_temporary(void)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
   for (unsigned int i = 0; i < ATABLE_SIZE; ++i)
   {
-    DLINK_FOREACH_SAFE(ptr, ptr_next, atable[i].head)
+    DLINK_FOREACH_SAFE(node, node_next, atable[i].head)
     {
-      struct AddressRec *arec = ptr->data;
+      struct AddressRec *arec = node->data;
 
       if (!arec->conf->until || arec->conf->until > CurrentTime)
         continue;
