@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file irc_string.c
  * \brief IRC string functions.
- * \version $Id: irc_string.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: irc_string.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "config.h"
@@ -76,7 +76,7 @@ strip_tabs(char *dest, const char *src, size_t len)
  */
 #ifndef HAVE_STRTOK_R
 char *
-strtoken(char** save, char* str, const char* fs)
+strtoken(char **save, char *str, const char *fs)
 {
   char *pos = *save;  /* keep last position across calls */
   char *tmp = NULL;
@@ -88,7 +88,7 @@ strtoken(char** save, char* str, const char* fs)
     ++pos;        /* skip leading separators */
 
   if (!pos || !*pos)
-    return (pos = *save = NULL);   /* string contains only sep's */
+    return pos = *save = NULL;   /* string contains only sep's */
 
   tmp = pos;       /* now, keep position of the token */
 
@@ -138,6 +138,7 @@ token_vector(char *names, char token, char *vector[], int size)
     if (*start)
     {
       vector[count++] = start;
+
       if (count < size)
         continue;
     }
