@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file list.c
  * \brief Maintains doubly-linked lists.
- * \version $Id: list.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: list.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -53,9 +53,9 @@ init_dlink_nodes(void)
 dlink_node *
 make_dlink_node(void)
 {
-  dlink_node *ptr = mp_pool_get(dnode_pool);
+  dlink_node *node = mp_pool_get(dnode_pool);
 
-  return ptr;
+  return node;
 }
 
 /* free_dlink_node()
@@ -65,9 +65,9 @@ make_dlink_node(void)
  * side effects	- free given dlink_node
  */
 void
-free_dlink_node(dlink_node *ptr)
+free_dlink_node(dlink_node *node)
 {
-  mp_pool_release(ptr);
+  mp_pool_release(node);
 }
 
 /*
@@ -164,13 +164,13 @@ dlinkDelete(dlink_node *m, dlink_list *list)
  * side effects - Look for ptr in the linked listed pointed to by link.
  */
 dlink_node *
-dlinkFind(dlink_list *list, void *data)
+dlinkFind(dlink_list *list, const void *data)
 {
-  dlink_node *ptr;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, list->head)
-    if (ptr->data == data)
-      return ptr;
+  DLINK_FOREACH(node, list->head)
+    if (node->data == data)
+      return node;
 
   return NULL;
 }
@@ -233,7 +233,7 @@ dlink_move_node(dlink_node *m, dlink_list *list_del, dlink_list *list_add)
   m->next = list_add->head;
 
   /* Assumption: If list_add->tail != NULL, list_add->head != NULL */
-  if (list_add->head != NULL)
+  if (list_add->head)
     list_add->head->prev = m;
   else if (list_add->tail == NULL)
     list_add->tail = m;
