@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file packet.c
  * \brief Packet handlers.
- * \version $Id: packet.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: packet.c 5546 2015-02-12 14:13:48Z michael $
  */
 
 #include "stdinc.h"
@@ -42,7 +42,33 @@
 #define READBUF_SIZE 16384
 
 static char readBuf[READBUF_SIZE];
-static void client_dopacket(struct Client *, char *, size_t);
+
+
+/*
+ * client_dopacket - copy packet to client buf and parse it
+ *      client_p - pointer to client structure for which the buffer data
+ *             applies.
+ *      buffer - pointr to the buffer containing the newly read data
+ *      length - number of valid bytes of data in the buffer
+ *
+ * Note:
+ *      It is implicitly assumed that client_dopacket() is called only
+ *      with client_p of "local" variation, which contains all the
+ *      necessary fields (buffer etc..)
+ */
+static void
+client_dopacket(struct Client *client_p, char *buffer, unsigned int length)
+{
+  /* Update messages received */
+  ++me.connection->recv.messages;
+  ++client_p->connection->recv.messages;
+
+  /* Update bytes received */
+  client_p->connection->recv.bytes += length;
+  me.connection->recv.bytes += length;
+
+  parse(client_p, buffer, buffer + length);
+}
 
 /* extract_one_line()
  *
@@ -51,30 +77,18 @@ static void client_dopacket(struct Client *, char *, size_t);
  * output       - length of <buffer>
  * side effects - one line is copied and removed from the dbuf
  */
-static int
+static unsigned int
 extract_one_line(struct dbuf_queue *qptr, char *buffer)
 {
-  int line_bytes = 0, empty_bytes = 0, phase = 0;
-  unsigned int idx = 0;
-  dlink_node *ptr = NULL;
+  unsigned int line_bytes = 0, eol_bytes = 0;
+  dlink_node *node;
 
-  /*
-   * Phase 0: "empty" characters before the line
-   * Phase 1: copying the line
-   * Phase 2: "empty" characters after the line
-   *          (delete them as well and free some space in the dbuf)
-   *
-   * Empty characters are CR, LF and space (but, of course, not
-   * in the middle of a line). We try to remove as much of them as we can,
-   * since they simply eat server memory.
-   *
-   * --adx
-   */
-  DLINK_FOREACH(ptr, qptr->blocks.head)
+  DLINK_FOREACH(node, qptr->blocks.head)
   {
-    struct dbuf_block *block = ptr->data;
+    const struct dbuf_block *block = node->data;
+    unsigned int idx;
 
-    if (ptr == qptr->blocks.head)
+    if (node == qptr->blocks.head)
       idx = qptr->pos;
     else
       idx = 0;
@@ -83,70 +97,69 @@ extract_one_line(struct dbuf_queue *qptr, char *buffer)
     {
       char c = block->data[idx];
 
-      if (IsEol(c) || (c == ' ' && phase != 1))
+      if (IsEol(c))
       {
-        ++empty_bytes;
+        ++eol_bytes;
 
-        if (phase == 1)
-          phase = 2;
-      }
-      else switch (phase)
-      {
-        case 0: phase = 1;
-        case 1: if (line_bytes++ < IRCD_BUFSIZE - 2)
-                  *buffer++ = c;
-                break;
-        case 2: *buffer = '\0';
-                dbuf_delete(qptr, line_bytes + empty_bytes);
-                return IRCD_MIN(line_bytes, IRCD_BUFSIZE - 2);
+        /* Allow 2 eol bytes per message */
+        if (eol_bytes == 2)
+          goto out;
       }
+      else if (eol_bytes)
+        goto out;
+      else if (line_bytes++ < IRCD_BUFSIZE - 2)
+        *buffer++ = c;
     }
   }
 
+out:
+
   /*
-   * Now, if we haven't reached phase 2, ignore all line bytes
+   * Now, if we haven't found an EOL, ignore all line bytes
    * that we have read, since this is a partial line case.
    */
-  if (phase != 2)
-    line_bytes = 0;
-  else
+  if (eol_bytes)
     *buffer = '\0';
+  else
+    line_bytes = 0;
 
   /* Remove what is now unnecessary */
-  dbuf_delete(qptr, line_bytes + empty_bytes);
+  dbuf_delete(qptr, line_bytes + eol_bytes);
+
   return IRCD_MIN(line_bytes, IRCD_BUFSIZE - 2);
 }
+
 /*
  * parse_client_queued - parse client queued messages
  */
 static void
 parse_client_queued(struct Client *client_p)
 {
-  int dolen = 0;
-  int checkflood = 1;
-  struct LocalUser *lclient_p = client_p->localClient;
+  unsigned int dolen = 0;
 
   if (IsUnknown(client_p))
   {
-    int i = 0;
+    unsigned int i = 0;
 
     while (1)
     {
       if (IsDefunct(client_p))
         return;
 
-      /* rate unknown clients at MAX_FLOOD per loop */
+      /* Rate unknown clients at MAX_FLOOD per loop */
       if (i >= MAX_FLOOD)
         break;
 
-      dolen = extract_one_line(&lclient_p->buf_recvq, readBuf);
+      dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf);
+
       if (dolen == 0)
         break;
 
       client_dopacket(client_p, readBuf, dolen);
-      i++;
+      ++i;
 
-      /* if they've dropped out of the unknown state, break and move
+      /*
+       * If they've dropped out of the unknown state, break and move
        * to the parsing for their appropriate status.  --fl
        */
       if (!IsUnknown(client_p))
@@ -160,7 +173,8 @@ parse_client_queued(struct Client *client_p)
     {
       if (IsDefunct(client_p))
         return;
-      if ((dolen = extract_one_line(&lclient_p->buf_recvq, readBuf)) == 0)
+
+      if ((dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf)) == 0)
         break;
 
       client_dopacket(client_p, readBuf, dolen);
@@ -168,17 +182,16 @@ parse_client_queued(struct Client *client_p)
   }
   else if (IsClient(client_p))
   {
-    if (ConfigGeneral.no_oper_flood && (HasUMode(client_p, UMODE_OPER) || IsCanFlood(client_p)))
-    {
-      if (ConfigGeneral.true_no_oper_flood)
-        checkflood = -1;
-      else
-        checkflood = 0;
-    }
+    unsigned int checkflood = 1;
+
+    if (ConfigGeneral.no_oper_flood && HasUMode(client_p, UMODE_OPER))
+      checkflood = 0;
+    else if (IsCanFlood(client_p))
+      checkflood = 0;
 
     /*
-     * Handle flood protection here - if we exceed our flood limit on
-     * messages in this loop, we simply drop out of the loop prematurely.
+     * Handle flood protection here - if we exceed our flood limit on messages
+     * in this loop, we simply drop out of the loop prematurely.
      *   -- adrian
      */
     while (1)
@@ -186,7 +199,8 @@ parse_client_queued(struct Client *client_p)
       if (IsDefunct(client_p))
         break;
 
-      /* This flood protection works as follows:
+      /*
+       * This flood protection works as follows:
        *
        * A client is given allow_read lines to send to the server.  Every
        * time a line is parsed, sent_parsed is increased.  sent_parsed
@@ -199,24 +213,17 @@ parse_client_queued(struct Client *client_p)
        * as sent_parsed will always hover around the allow_read limit
        * and no 'bursts' will be permitted.
        */
-      if (checkflood > 0)
-      {
-        if (lclient_p->sent_parsed >= lclient_p->allow_read)
+      if (checkflood)
+        if (client_p->connection->sent_parsed >= client_p->connection->allow_read)
           break;
-      }
 
-      /* allow opers 4 times the amount of messages as users. why 4?
-       * why not. :) --fl_
-       */
-      else if (lclient_p->sent_parsed >= (4 * lclient_p->allow_read) && checkflood != -1)
-        break;
+      dolen = extract_one_line(&client_p->connection->buf_recvq, readBuf);
 
-      dolen = extract_one_line(&lclient_p->buf_recvq, readBuf);
       if (dolen == 0)
         break;
 
       client_dopacket(client_p, readBuf, dolen);
-      lclient_p->sent_parsed++;
+      ++client_p->connection->sent_parsed;
     }
   }
 }
@@ -231,12 +238,13 @@ flood_endgrace(struct Client *client_p)
   SetFloodDone(client_p);
 
   /* Drop their flood limit back down */
-  client_p->localClient->allow_read = MAX_FLOOD;
+  client_p->connection->allow_read = MAX_FLOOD;
 
-  /* sent_parsed could be way over MAX_FLOOD but under MAX_FLOOD_BURST,
+  /*
+   * sent_parsed could be way over MAX_FLOOD but under MAX_FLOOD_BURST,
    * so reset it.
    */
-  client_p->localClient->sent_parsed = 0;
+  client_p->connection->sent_parsed = 0;
 }
 
 /*
@@ -248,19 +256,19 @@ flood_endgrace(struct Client *client_p)
 void
 flood_recalc(fde_t *fd, void *data)
 {
-  struct Client *client_p = data;
-  struct LocalUser *lclient_p = client_p->localClient;
+  struct Client *const client_p = data;
 
-  /* allow a bursting client their allocation per second, allow
+  /*
+   * Allow a bursting client their allocation per second, allow
    * a client whos flooding an extra 2 per second
    */
   if (IsFloodDone(client_p))
-    lclient_p->sent_parsed -= 2;
+    client_p->connection->sent_parsed -= 2;
   else
-    lclient_p->sent_parsed = 0;
+    client_p->connection->sent_parsed = 0;
 
-  if (lclient_p->sent_parsed < 0)
-    lclient_p->sent_parsed = 0;
+  if (client_p->connection->sent_parsed < 0)
+    client_p->connection->sent_parsed = 0;
 
   parse_client_queued(client_p);
 
@@ -278,7 +286,7 @@ flood_recalc(fde_t *fd, void *data)
 void
 read_packet(fde_t *fd, void *data)
 {
-  struct Client *client_p = data;
+  struct Client *const client_p = data;
   int length = 0;
 
   if (IsDefunct(client_p))
@@ -323,7 +331,7 @@ read_packet(fde_t *fd, void *data)
     if (length <= 0)
     {
       /*
-       * If true, then we can recover from this error.  Just jump out of
+       * If true, then we can recover from this error. Just jump out of
        * the loop and re-register a new io-request.
        */
       if (length < 0 && ignoreErrno(errno))
@@ -333,12 +341,13 @@ read_packet(fde_t *fd, void *data)
       return;
     }
 
-    dbuf_put(&client_p->localClient->buf_recvq, readBuf, length);
+    dbuf_put(&client_p->connection->buf_recvq, readBuf, length);
 
-    if (client_p->localClient->lasttime < CurrentTime)
-      client_p->localClient->lasttime = CurrentTime;
-    if (client_p->localClient->lasttime > client_p->localClient->since)
-      client_p->localClient->since = CurrentTime;
+    if (client_p->connection->lasttime < CurrentTime)
+      client_p->connection->lasttime = CurrentTime;
+
+    if (client_p->connection->lasttime > client_p->connection->since)
+      client_p->connection->since = CurrentTime;
 
     ClearPingSent(client_p);
 
@@ -349,15 +358,12 @@ read_packet(fde_t *fd, void *data)
       return;
 
     /* Check to make sure we're not flooding */
-    if (!(IsServer(client_p) || IsHandshake(client_p) || IsConnecting(client_p))
-        && (dbuf_length(&client_p->localClient->buf_recvq) >
-            get_recvq(&client_p->localClient->confs)))
+    if (!(IsServer(client_p) || IsHandshake(client_p) || IsConnecting(client_p)) &&
+        (dbuf_length(&client_p->connection->buf_recvq) >
+         get_recvq(&client_p->connection->confs)))
     {
-      if (!(ConfigGeneral.no_oper_flood && HasUMode(client_p, UMODE_OPER)))
-      {
-        exit_client(client_p, "Excess Flood");
-        return;
-      }
+      exit_client(client_p, "Excess Flood");
+      return;
     }
   }
 #ifdef HAVE_LIBCRYPTO
@@ -369,33 +375,3 @@ read_packet(fde_t *fd, void *data)
   /* If we get here, we need to register for another COMM_SELECT_READ */
   comm_setselect(fd, COMM_SELECT_READ, read_packet, client_p, 0);
 }
-
-/*
- * client_dopacket - copy packet to client buf and parse it
- *      client_p - pointer to client structure for which the buffer data
- *             applies.
- *      buffer - pointr to the buffer containing the newly read data
- *      length - number of valid bytes of data in the buffer
- *
- * Note:
- *      It is implicitly assumed that dopacket is called only
- *      with client_p of "local" variation, which contains all the
- *      necessary fields (buffer etc..)
- */
-static void
-client_dopacket(struct Client *client_p, char *buffer, size_t length)
-{
-  /*
-   * Update messages received
-   */
-  ++me.localClient->recv.messages;
-  ++client_p->localClient->recv.messages;
-
-  /*
-   * Update bytes received
-   */
-  client_p->localClient->recv.bytes += length;
-  me.localClient->recv.bytes += length;
-
-  parse(client_p, buffer, buffer + length);
-}
