@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2001-2014 ircd-hybrid development team
+ *  Copyright (c) 2001-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file resv.c
  * \brief Functions to reserve(jupe) a nick/channel.
- * \version $Id: resv.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: resv.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -53,7 +53,7 @@
 struct MaskItem *
 create_resv(const char *name, const char *reason, const dlink_list *list)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   struct MaskItem *conf = NULL;
   enum maskitem_type type;
 
@@ -74,21 +74,21 @@ create_resv(const char *name, const char *reason, const dlink_list *list)
 
   if (list)
   {
-    DLINK_FOREACH(ptr, list->head)
+    DLINK_FOREACH(node, list->head)
     {
       char nick[NICKLEN + 1];
       char user[USERLEN + 1];
       char host[HOSTLEN + 1];
       struct split_nuh_item nuh;
       struct exempt *exptr = NULL;
-      char *s = ptr->data;
+      char *s = node->data;
 
       if (strlen(s) == 2 && IsAlpha(*(s + 1) && IsAlpha(*(s + 2))))
       {
 #ifdef HAVE_LIBGEOIP
         exptr = MyCalloc(sizeof(*exptr));
         exptr->name = xstrdup(s);
-        exptr->coid = GeoIP_id_by_code(s);
+        exptr->country_id = GeoIP_id_by_code(s);
         dlinkAdd(exptr, &exptr->node, &conf->exempt_list);
 #endif
       }
@@ -121,15 +121,15 @@ create_resv(const char *name, const char *reason, const dlink_list *list)
 int
 resv_find_exempt(const struct Client *who, const struct MaskItem *conf)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, conf->exempt_list.head)
+  DLINK_FOREACH(node, conf->exempt_list.head)
   {
-    const struct exempt *exptr = ptr->data;
+    const struct exempt *exptr = node->data;
 
-    if (exptr->coid)
+    if (exptr->country_id)
     {
-      if (exptr->coid == who->localClient->country_id)
+      if (exptr->country_id == who->connection->country_id)
         return 1;
     }
     else if (!match(exptr->name, who->name) && !match(exptr->user, who->username))
@@ -141,13 +141,13 @@ resv_find_exempt(const struct Client *who, const struct MaskItem *conf)
             return 1;
           break;
         case HM_IPV4:
-          if (who->localClient->aftype == AF_INET)
-            if (match_ipv4(&who->localClient->ip, &exptr->addr, exptr->bits))
+          if (who->connection->aftype == AF_INET)
+            if (match_ipv4(&who->connection->ip, &exptr->addr, exptr->bits))
               return 1;
           break;
         case HM_IPV6:
-          if (who->localClient->aftype == AF_INET6)
-            if (match_ipv6(&who->localClient->ip, &exptr->addr, exptr->bits))
+          if (who->connection->aftype == AF_INET6)
+            if (match_ipv6(&who->connection->ip, &exptr->addr, exptr->bits))
               return 1;
           break;
         default:
@@ -169,14 +169,14 @@ resv_find_exempt(const struct Client *who, const struct MaskItem *conf)
 struct MaskItem *
 match_find_resv(const char *name)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   if (EmptyString(name))
     return NULL;
 
-  DLINK_FOREACH(ptr, cresv_items.head)
+  DLINK_FOREACH(node, cresv_items.head)
   {
-    struct MaskItem *conf = ptr->data;
+    struct MaskItem *conf = node->data;
 
     if (!match(conf->name, name))
       return conf;
