@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 2000-2014 ircd-hybrid development team
+ *  Copyright (c) 2000-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file rsa.c
  * \brief Functions for use with RSA public key cryptography.
- * \version $Id: rsa.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: rsa.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -57,7 +57,7 @@ binary_to_hex(const unsigned char *bin, char *hex, unsigned int length)
 {
   static const char trans[] = "0123456789ABCDEF";
 
-  for (const unsigned char *end = bin + length; bin < end; ++bin)
+  for (const unsigned char *const end = bin + length; bin < end; ++bin)
   {
     *hex++ = trans[*bin >>  4];
     *hex++ = trans[*bin & 0xf];
