@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file send.c
  * \brief Functions for sending messages.
- * \version $Id: send.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: send.c 5346 2015-01-11 12:41:14Z michael $
  */
 
 #include "stdinc.h"
@@ -32,17 +32,13 @@
 #include "dbuf.h"
 #include "irc_string.h"
 #include "ircd.h"
-#include "numeric.h"
-#include "fdlist.h"
 #include "s_bsd.h"
 #include "server.h"
-#include "conf.h"
+#include "conf_class.h"
 #include "log.h"
-#include "memory.h"
-#include "packet.h"
 
 
-static unsigned int current_serial = 0;
+static uint64_t current_serial;
 
 
 /* send_format()
@@ -71,8 +67,8 @@ send_format(struct dbuf_block *buffer, const char *pattern, va_list args)
    */
   dbuf_put_args(buffer, pattern, args);
 
-  if (buffer->size > sizeof(buffer->data) - 2)
-    buffer->size = sizeof(buffer->data) - 2;
+  if (buffer->size > IRCD_BUFSIZE - 2)
+    buffer->size = IRCD_BUFSIZE - 2;
 
   buffer->data[buffer->size++] = '\r';
   buffer->data[buffer->size++] = '\n';
@@ -88,15 +84,17 @@ send_message(struct Client *to, struct dbuf_block *buf)
 {
   assert(!IsMe(to));
   assert(to != &me);
+  assert(MyConnect(to));
 
-  if (dbuf_length(&to->localClient->buf_sendq) + buf->size > get_sendq(&to->localClient->confs))
+  if (dbuf_length(&to->connection->buf_sendq) + buf->size > get_sendq(&to->connection->confs))
   {
     if (IsServer(to))
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
                            "Max SendQ limit exceeded for %s: %lu > %u",
                            get_client_name(to, HIDE_IP),
-                           (unsigned long)(dbuf_length(&to->localClient->buf_sendq) + buf->size),
-                           get_sendq(&to->localClient->confs));
+                           (unsigned long)(dbuf_length(&to->connection->buf_sendq) + buf->size),
+                           get_sendq(&to->connection->confs));
+
     if (IsClient(to))
       SetSendQExceeded(to);
 
@@ -104,15 +102,15 @@ send_message(struct Client *to, struct dbuf_block *buf)
     return;
   }
 
-  dbuf_add(&to->localClient->buf_sendq, buf);
+  dbuf_add(&to->connection->buf_sendq, buf);
 
   /*
    * Update statistics. The following is slightly incorrect because
    * it counts messages even if queued, but bytes only really sent.
    * Queued bytes get updated in send_queued_write().
    */
-  ++to->localClient->send.messages;
-  ++me.localClient->send.messages;
+  ++to->connection->send.messages;
+  ++me.connection->send.messages;
 
   send_queued_write(to);
 }
@@ -130,47 +128,16 @@ send_message(struct Client *to, struct dbuf_block *buf)
 static void
 send_message_remote(struct Client *to, struct Client *from, struct dbuf_block *buf)
 {
-  to = to->from;
+  assert(MyConnect(to));
+  assert(IsServer(to));
+  assert(!IsMe(to));
+  assert(to->from == to);
 
-  if (!MyConnect(to))
+  if (to == from->from)
   {
     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "Server send message to %s [%s] dropped from %s(Not local server)",
-                         to->name, to->from->name, from->name);
-    return;
-  }
-
-  /* Optimize by checking if (from && to) before everything */
-  /* we set to->from up there.. */
-
-  if (!MyClient(from) && IsClient(to) && (to == from->from))
-  {
-    if (IsServer(from))
-    {
-      sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "Send message to %s [%s] dropped from %s(Fake Dir)",
-                           to->name, to->from->name, from->name);
-      return;
-    }
-
-    sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "Ghosted: %s[%s@%s] from %s[%s@%s] (%s)",
-                         to->name, to->username, to->host,
-                         from->name, from->username, from->host,
-                         to->from->name);
-
-    sendto_server(NULL, NOCAPS, NOCAPS,
-                  ":%s KILL %s :%s (%s[%s@%s] Ghosted %s)",
-                  me.id, to->id, me.name, to->name,
-                  to->username, to->host, to->from->name);
-
-    AddFlag(to, FLAGS_KILLED);
-
-    if (IsClient(from))
-      sendto_one_numeric(from, &me, ERR_GHOSTEDCLIENT, to->name,
-                         to->username, to->host, to->from);
-
-    exit_client(to, "Ghosted client");
+                         "Send message to %s dropped from %s (Fake Dir)",
+                         to->name, from->name);
     return;
   }
 
@@ -184,8 +151,8 @@ send_message_remote(struct Client *to, struct Client *from, struct dbuf_block *b
 void
 sendq_unblocked(fde_t *fd, void *data)
 {
-  struct Client *client_p = data;
-  assert(fd == &client_p->localClient->fd);
+  struct Client *const client_p = data;
+  assert(fd == &client_p->connection->fd);
 
   DelFlag(client_p, FLAGS_BLOCKED);
   send_queued_write(client_p);
@@ -210,21 +177,21 @@ send_queued_write(struct Client *to)
     return;  /* no use calling send() now */
 
   /* Next, lets try to write some data */
-  if (dbuf_length(&to->localClient->buf_sendq))
+  if (dbuf_length(&to->connection->buf_sendq))
   {
     do
     {
-      struct dbuf_block *first = to->localClient->buf_sendq.blocks.head->data;
+      struct dbuf_block *first = to->connection->buf_sendq.blocks.head->data;
 
 #ifdef HAVE_LIBCRYPTO
-      if (to->localClient->fd.ssl)
+      if (to->connection->fd.ssl)
       {
-        retlen = SSL_write(to->localClient->fd.ssl, first->data + to->localClient->buf_sendq.pos, first->size - to->localClient->buf_sendq.pos);
+        retlen = SSL_write(to->connection->fd.ssl, first->data + to->connection->buf_sendq.pos, first->size - to->connection->buf_sendq.pos);
 
         /* translate openssl error codes, sigh */
         if (retlen < 0)
         {
-          switch (SSL_get_error(to->localClient->fd.ssl, retlen))
+          switch (SSL_get_error(to->connection->fd.ssl, retlen))
           {
             case SSL_ERROR_WANT_READ:
               return;  /* retry later, don't register for write events */
@@ -242,24 +209,24 @@ send_queued_write(struct Client *to)
       }
       else
 #endif
-        retlen = send(to->localClient->fd.fd, first->data + to->localClient->buf_sendq.pos, first->size - to->localClient->buf_sendq.pos, 0);
+        retlen = send(to->connection->fd.fd, first->data + to->connection->buf_sendq.pos, first->size - to->connection->buf_sendq.pos, 0);
 
       if (retlen <= 0)
         break;
 
-      dbuf_delete(&to->localClient->buf_sendq, retlen);
+      dbuf_delete(&to->connection->buf_sendq, retlen);
 
       /* We have some data written .. update counters */
-      to->localClient->send.bytes += retlen;
-      me.localClient->send.bytes += retlen;
-    } while (dbuf_length(&to->localClient->buf_sendq));
+      to->connection->send.bytes += retlen;
+      me.connection->send.bytes += retlen;
+    } while (dbuf_length(&to->connection->buf_sendq));
 
     if (retlen < 0 && ignoreErrno(errno))
     {
       AddFlag(to, FLAGS_BLOCKED);
 
       /* we have a non-fatal error, reschedule a write */
-      comm_setselect(&to->localClient->fd, COMM_SELECT_WRITE,
+      comm_setselect(&to->connection->fd, COMM_SELECT_WRITE,
                      sendq_unblocked, to, 0);
     }
     else if (retlen <= 0)
@@ -279,19 +246,19 @@ send_queued_write(struct Client *to)
 void
 send_queued_all(void)
 {
-  dlink_node *ptr;
+  dlink_node *node = NULL;
 
   /* Servers are processed first, mainly because this can generate
    * a notice to opers, which is to be delivered by this function.
    */
-  DLINK_FOREACH(ptr, local_server_list.head)
-    send_queued_write(ptr->data);
+  DLINK_FOREACH(node, local_server_list.head)
+    send_queued_write(node->data);
 
-  DLINK_FOREACH(ptr, unknown_list.head)
-    send_queued_write(ptr->data);
+  DLINK_FOREACH(node, unknown_list.head)
+    send_queued_write(node->data);
 
-  DLINK_FOREACH(ptr, local_client_list.head)
-    send_queued_write(ptr->data);
+  DLINK_FOREACH(node, local_client_list.head)
+    send_queued_write(node->data);
 
   /* NOTE: This can still put clients on aborted_list; unfortunately,
    * exit_aborted_clients takes precedence over send_queued_all,
@@ -353,6 +320,7 @@ sendto_one_numeric(struct Client *to, struct Client *from, enum irc_numerics num
     numstr = va_arg(args, const char *);
   else
     numstr = numeric_form(numeric);
+
   send_format(buffer, numstr, args);
   va_end(args);
 
@@ -407,7 +375,7 @@ sendto_channel_butone(struct Client *one, struct Client *from,
 {
   va_list alocal, aremote;
   struct dbuf_block *local_buf, *remote_buf;
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL;
 
   local_buf = dbuf_alloc(), remote_buf = dbuf_alloc();
 
@@ -428,10 +396,10 @@ sendto_channel_butone(struct Client *one, struct Client *from,
 
   ++current_serial;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, chptr->members.head)
+  DLINK_FOREACH(node, chptr->members.head)
   {
-    struct Membership *ms = ptr->data;
-    struct Client *target_p = ms->client_p;
+    struct Membership *member = node->data;
+    struct Client *target_p = member->client_p;
 
     assert(IsClient(target_p));
 
@@ -439,14 +407,15 @@ sendto_channel_butone(struct Client *one, struct Client *from,
         (one && target_p->from == one->from))
       continue;
 
-    if (type && (ms->flags & type) == 0)
+    if (type && (member->flags & type) == 0)
       continue;
 
     if (MyConnect(target_p))
       send_message(target_p, local_buf);
-    else if (target_p->from->localClient->serial != current_serial)
+    else if (target_p->from->connection->serial != current_serial)
       send_message_remote(target_p->from, from, remote_buf);
-    target_p->from->localClient->serial = current_serial;
+
+    target_p->from->connection->serial = current_serial;
   }
 
   dbuf_ref_free(local_buf);
@@ -478,30 +447,31 @@ sendto_server(struct Client *one,
               const char *format, ...)
 {
   va_list args;
-  dlink_node *ptr = NULL;
-  struct dbuf_block *buffer;
-
-  buffer = dbuf_alloc();
+  dlink_node *node = NULL;
+  struct dbuf_block *buffer = dbuf_alloc();
 
   va_start(args, format);
   send_format(buffer, format, args);
   va_end(args);
 
-  DLINK_FOREACH(ptr, local_server_list.head)
+  DLINK_FOREACH(node, local_server_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
     /* If dead already skip */
     if (IsDead(client_p))
       continue;
+
     /* check against 'one' */
     if (one && (client_p == one->from))
       continue;
+
     /* check we have required capabs */
-    if ((client_p->localClient->caps & caps) != caps)
+    if ((client_p->connection->caps & caps) != caps)
       continue;
+
     /* check we don't have any forbidden capabs */
-    if ((client_p->localClient->caps & nocaps))
+    if ((client_p->connection->caps & nocaps))
       continue;
 
     send_message(client_p, buffer);
@@ -527,11 +497,9 @@ sendto_common_channels_local(struct Client *user, int touser, unsigned int cap,
   dlink_node *uptr;
   dlink_node *cptr;
   struct Channel *chptr;
-  struct Membership *ms;
+  struct Membership *member;
   struct Client *target_p;
-  struct dbuf_block *buffer;
-
-  buffer = dbuf_alloc();
+  struct dbuf_block *buffer = dbuf_alloc();
 
   va_start(args, pattern);
   send_format(buffer, pattern, args);
@@ -545,23 +513,23 @@ sendto_common_channels_local(struct Client *user, int touser, unsigned int cap,
 
     DLINK_FOREACH(uptr, chptr->locmembers.head)
     {
-      ms = uptr->data;
-      target_p = ms->client_p;
+      member = uptr->data;
+      target_p = member->client_p;
 
       if (target_p == user || IsDefunct(target_p) ||
-          target_p->localClient->serial == current_serial)
+          target_p->connection->serial == current_serial)
         continue;
 
       if (HasCap(target_p, cap) != cap)
         continue;
 
-      target_p->localClient->serial = current_serial;
+      target_p->connection->serial = current_serial;
       send_message(target_p, buffer);
     }
   }
 
   if (touser && MyConnect(user) && !IsDead(user) &&
-      user->localClient->serial != current_serial)
+      user->connection->serial != current_serial)
     if (HasCap(user, cap) == cap)
       send_message(user, buffer);
 
@@ -571,7 +539,6 @@ sendto_common_channels_local(struct Client *user, int touser, unsigned int cap,
 /* sendto_channel_local()
  *
  * inputs	- member status mask, e.g. CHFL_CHANOP | CHFL_VOICE
- *              - whether to ignore +D clients (YES/NO)
  *              - pointer to channel to send to
  *              - var args pattern
  * output	- NONE
@@ -579,29 +546,26 @@ sendto_common_channels_local(struct Client *user, int touser, unsigned int cap,
  *		  locally connected to this server.
  */
 void
-sendto_channel_local(unsigned int type, int nodeaf, struct Channel *chptr,
+sendto_channel_local(unsigned int type, struct Channel *chptr,
                      const char *pattern, ...)
 {
   va_list args;
-  dlink_node *ptr = NULL;
-  struct dbuf_block *buffer;
-
-  buffer = dbuf_alloc();
+  dlink_node *node = NULL;
+  struct dbuf_block *buffer = dbuf_alloc();
 
   va_start(args, pattern);
   send_format(buffer, pattern, args);
   va_end(args);
 
-  DLINK_FOREACH(ptr, chptr->locmembers.head)
+  DLINK_FOREACH(node, chptr->locmembers.head)
   {
-    struct Membership *ms = ptr->data;
-    struct Client *target_p = ms->client_p;
+    struct Membership *member = node->data;
+    struct Client *target_p = member->client_p;
 
-    if (type && (ms->flags & type) == 0)
+    if (type && (member->flags & type) == 0)
       continue;
 
-    if (IsDefunct(target_p) ||
-        (nodeaf && HasUMode(target_p, UMODE_DEAF)))
+    if (IsDefunct(target_p))
       continue;
 
     send_message(target_p, buffer);
@@ -623,34 +587,32 @@ sendto_channel_local(unsigned int type, int nodeaf, struct Channel *chptr,
  * WARNING - +D clients are omitted
  */
 void
-sendto_channel_local_butone(struct Client *one, unsigned int type, unsigned int cap,
+sendto_channel_local_butone(struct Client *one, unsigned int poscap, unsigned int negcap,
                             struct Channel *chptr, const char *pattern, ...)
 {
   va_list args;
-  dlink_node *ptr = NULL;
-  struct dbuf_block *buffer;
-
-  buffer = dbuf_alloc();
+  dlink_node *node = NULL;
+  struct dbuf_block *buffer = dbuf_alloc();
 
   va_start(args, pattern);
   send_format(buffer, pattern, args);
   va_end(args);
 
-  DLINK_FOREACH(ptr, chptr->locmembers.head)
+  DLINK_FOREACH(node, chptr->locmembers.head)
   {
-    struct Membership *ms = ptr->data;
-    struct Client *target_p = ms->client_p;
-
-    if (type && (ms->flags & type) == 0)
-      continue;
+    struct Membership *member = node->data;
+    struct Client *target_p = member->client_p;
 
     if (one && target_p == one->from)
       continue;
 
-    if (IsDefunct(target_p) || HasUMode(target_p, UMODE_DEAF))
+    if (IsDefunct(target_p))
       continue;
 
-    if (HasCap(target_p, cap) != cap)
+    if (poscap && HasCap(target_p, poscap) != poscap)
+      continue;
+
+    if (negcap && HasCap(target_p, negcap))
       continue;
 
     send_message(target_p, buffer);
@@ -697,7 +659,7 @@ sendto_match_butone(struct Client *one, struct Client *from, const char *mask,
                     int what, const char *pattern, ...)
 {
   va_list alocal, aremote;
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL;
   struct dbuf_block *local_buf, *remote_buf;
 
   local_buf = dbuf_alloc(), remote_buf = dbuf_alloc();
@@ -713,9 +675,9 @@ sendto_match_butone(struct Client *one, struct Client *from, const char *mask,
   va_end(alocal);
 
   /* scan the local clients */
-  DLINK_FOREACH(ptr, local_client_list.head)
+  DLINK_FOREACH(node, local_client_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
     if ((!one || client_p != one->from) && !IsDefunct(client_p) &&
         match_it(client_p, mask, what))
@@ -723,9 +685,9 @@ sendto_match_butone(struct Client *one, struct Client *from, const char *mask,
   }
 
   /* Now scan servers */
-  DLINK_FOREACH_SAFE(ptr, ptr_next, local_server_list.head)
+  DLINK_FOREACH(node, local_server_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
 
     /*
      * The old code looped through every client on the
@@ -773,10 +735,8 @@ sendto_match_servs(struct Client *source_p, const char *mask, unsigned int cap,
                    const char *pattern, ...)
 {
   va_list args;
-  dlink_node *ptr = NULL, *ptr_next = NULL;
-  struct dbuf_block *buffer;
-
-  buffer = dbuf_alloc();
+  dlink_node *node = NULL;
+  struct dbuf_block *buffer = dbuf_alloc();
 
   dbuf_put_fmt(buffer, ":%s ", source_p->id);
   va_start(args, pattern);
@@ -785,30 +745,30 @@ sendto_match_servs(struct Client *source_p, const char *mask, unsigned int cap,
 
   ++current_serial;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, global_server_list.head)
+  DLINK_FOREACH(node, global_server_list.head)
   {
-    struct Client *target_p = ptr->data;
+    struct Client *target_p = node->data;
 
     /* Do not attempt to send to ourselves, or the source */
     if (IsMe(target_p) || target_p->from == source_p->from)
       continue;
 
-    if (target_p->from->localClient->serial == current_serial)
+    if (target_p->from->connection->serial == current_serial)
       continue;
 
-    if (!match(mask, target_p->name))
-    {
-      /*
-       * if we set the serial here, then we'll never do a
-       * match() again, if !IsCapable()
-       */
-      target_p->from->localClient->serial = current_serial;
+    if (match(mask, target_p->name))
+      continue;
 
-      if (!IsCapable(target_p->from, cap))
-        continue;
+    /*
+     * If we set the serial here, then we'll never do a
+     * match() again, if !IsCapable()
+     */
+    target_p->from->connection->serial = current_serial;
 
-      send_message_remote(target_p->from, source_p, buffer);
-    }
+    if (!IsCapable(target_p->from, cap))
+      continue;
+
+    send_message_remote(target_p->from, source_p, buffer);
   }
 
   dbuf_ref_free(buffer);
@@ -847,10 +807,10 @@ sendto_anywhere(struct Client *to, struct Client *from,
   send_format(buffer, pattern, args);
   va_end(args);
 
-  if (MyClient(to))
+  if (MyConnect(to))
     send_message(to, buffer);
   else
-    send_message_remote(to, from, buffer);
+    send_message_remote(to->from, from, buffer);
 
   dbuf_ref_free(buffer);
 }
@@ -867,7 +827,7 @@ void
 sendto_realops_flags(unsigned int flags, int level, int type, const char *pattern, ...)
 {
   const char *ntype = NULL;
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   char nbuf[IRCD_BUFSIZE] = "";
   va_list args;
 
@@ -890,9 +850,9 @@ sendto_realops_flags(unsigned int flags, int level, int type, const char *patter
       assert(0);
   }
 
-  DLINK_FOREACH(ptr, oper_list.head)
+  DLINK_FOREACH(node, oper_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
     assert(HasUMode(client_p, UMODE_OPER));
 
     /*
@@ -924,6 +884,7 @@ sendto_realops_flags_ratelimited(time_t *rate, const char *pattern, ...)
 
   if ((CurrentTime - *rate) < 20)
     return;
+
   *rate = CurrentTime;
 
   va_start(args, pattern);
@@ -946,11 +907,9 @@ void
 sendto_wallops_flags(unsigned int flags, struct Client *source_p,
                      const char *pattern, ...)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   va_list args;
-  struct dbuf_block *buffer;
-
-  buffer = dbuf_alloc();
+  struct dbuf_block *buffer = dbuf_alloc();
 
   if (IsClient(source_p))
     dbuf_put_fmt(buffer, ":%s!%s@%s WALLOPS :", source_p->name, source_p->username, source_p->host);
@@ -961,9 +920,9 @@ sendto_wallops_flags(unsigned int flags, struct Client *source_p,
   send_format(buffer, pattern, args);
   va_end(args);
 
-  DLINK_FOREACH(ptr, oper_list.head)
+  DLINK_FOREACH(node, oper_list.head)
   {
-    struct Client *client_p = ptr->data;
+    struct Client *client_p = node->data;
     assert(client_p->umodes & UMODE_OPER);
 
     if (HasUMode(client_p, flags) && !IsDefunct(client_p))
