@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -21,7 +21,7 @@
 
 /*! \file s_serv.c
  * \brief Server related functions.
- * \version $Id: server.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: server.c 5775 2015-04-04 17:31:06Z michael $
  */
 
 #include "stdinc.h"
@@ -51,7 +51,7 @@
 #define MIN_CONN_FREQ 300
 
 dlink_list flatten_links;
-static dlink_list cap_list = { NULL, NULL, 0 };
+static dlink_list cap_list;
 static void serv_connect_callback(fde_t *, int, void *);
 
 
@@ -67,22 +67,22 @@ void
 write_links_file(void *unused)
 {
   FILE *file = NULL;
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
   char buff[IRCD_BUFSIZE] = "";
 
   if ((file = fopen(LIPATH, "w")) == NULL)
     return;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, flatten_links.head)
+  DLINK_FOREACH_SAFE(node, node_next, flatten_links.head)
   {
-    dlinkDelete(ptr, &flatten_links);
-    MyFree(ptr->data);
-    free_dlink_node(ptr);
+    dlinkDelete(node, &flatten_links);
+    MyFree(node->data);
+    free_dlink_node(node);
   }
 
-  DLINK_FOREACH(ptr, global_server_list.head)
+  DLINK_FOREACH(node, global_server_list.head)
   {
-    const struct Client *target_p = ptr->data;
+    const struct Client *target_p = node->data;
 
     /*
      * Skip hidden servers, aswell as ourselves, since we already send
@@ -157,7 +157,7 @@ hunt_server(struct Client *source_p, const char *command,
             const int server, const int parc, char *parv[])
 {
   struct Client *target_p = NULL;
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   /* Assume it's me, if no server */
   if (parc <= server || EmptyString(parv[server]))
@@ -177,9 +177,9 @@ hunt_server(struct Client *source_p, const char *command,
 
   if (!target_p && has_wildcards(parv[server]))
   {
-    DLINK_FOREACH(ptr, global_client_list.head)
+    DLINK_FOREACH(node, global_client_list.head)
     {
-      struct Client *tmp = ptr->data;
+      struct Client *tmp = node->data;
 
       assert(IsMe(tmp) || IsServer(tmp) || IsClient(tmp));
       if (!match(parv[server], tmp->name))
@@ -187,7 +187,7 @@ hunt_server(struct Client *source_p, const char *command,
         if (tmp->from == source_p->from && !MyConnect(tmp))
           continue;
 
-        target_p = ptr->data;
+        target_p = node->data;
         break;
       }
     }
@@ -223,16 +223,16 @@ hunt_server(struct Client *source_p, const char *command,
 void
 try_connections(void *unused)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   int confrq = 0;
 
   /* TODO: change this to set active flag to 0 when added to event! --Habeeb */
   if (GlobalSetOptions.autoconn == 0)
     return;
 
-  DLINK_FOREACH(ptr, server_items.head)
+  DLINK_FOREACH(node, server_items.head)
   {
-    struct MaskItem *conf = ptr->data;
+    struct MaskItem *conf = node->data;
 
     assert(conf->type == CONF_SERVER);
 
@@ -269,9 +269,9 @@ try_connections(void *unused)
     if (conf->class->ref_count < conf->class->max_total)
     {
       /* Go to the end of the list, if not already last */
-      if (ptr->next)
+      if (node->next)
       {
-        dlinkDelete(ptr, &server_items);
+        dlinkDelete(node, &server_items);
         dlinkAddTail(conf, &conf->node, &server_items);
       }
 
@@ -324,7 +324,7 @@ valid_servname(const char *name)
 int
 check_server(const char *name, struct Client *client_p)
 {
-  dlink_node *ptr;
+  dlink_node *node = NULL;
   struct MaskItem *conf        = NULL;
   struct MaskItem *server_conf = NULL;
   int error = -1;
@@ -332,9 +332,9 @@ check_server(const char *name, struct Client *client_p)
   assert(client_p);
 
   /* loop through looking for all possible connect items that might work */
-  DLINK_FOREACH(ptr, server_items.head)
+  DLINK_FOREACH(node, server_items.head)
   {
-    conf = ptr->data;
+    conf = node->data;
 
     if (match(name, conf->name))
       continue;
@@ -348,7 +348,7 @@ check_server(const char *name, struct Client *client_p)
     {
       error = -2;
 
-      if (!match_conf_password(client_p->localClient->password, conf))
+      if (!match_conf_password(client_p->connection->password, conf))
         return -2;
 
       if (!EmptyString(conf->certfp))
@@ -376,13 +376,13 @@ check_server(const char *name, struct Client *client_p)
         v6 = (struct sockaddr_in6 *)&server_conf->addr;
 
         if (IN6_IS_ADDR_UNSPECIFIED(&v6->sin6_addr))
-          memcpy(&server_conf->addr, &client_p->localClient->ip, sizeof(struct irc_ssaddr));
+          memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
         break;
       case AF_INET:
         v4 = (struct sockaddr_in *)&server_conf->addr;
 
         if (v4->sin_addr.s_addr == INADDR_NONE)
-          memcpy(&server_conf->addr, &client_p->localClient->ip, sizeof(struct irc_ssaddr));
+          memcpy(&server_conf->addr, &client_p->connection->ip, sizeof(struct irc_ssaddr));
         break;
     }
   }
@@ -418,28 +418,26 @@ add_capability(const char *capab_name, int cap_flag, int add_to_default)
  * output	- NONE
  * side effects	- delete given capability from ones known.
  */
-int
+void
 delete_capability(const char *capab_name)
 {
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, cap_list.head)
+  DLINK_FOREACH_SAFE(node, node_next, cap_list.head)
   {
-    struct Capability *cap = ptr->data;
+    struct Capability *cap = node->data;
 
     if (cap->cap)
     {
       if (!irccmp(cap->name, capab_name))
       {
         default_server_capabs &= ~(cap->cap);
-        dlinkDelete(ptr, &cap_list);
+        dlinkDelete(node, &cap_list);
         MyFree(cap->name);
         MyFree(cap);
       }
     }
   }
-
-  return 0;
 }
 
 /*
@@ -452,11 +450,11 @@ delete_capability(const char *capab_name)
 unsigned int
 find_capability(const char *capab)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, cap_list.head)
+  DLINK_FOREACH(node, cap_list.head)
   {
-    const struct Capability *cap = ptr->data;
+    const struct Capability *cap = node->data;
 
     if (cap->cap && !irccmp(cap->name, capab))
       return cap->cap;
@@ -477,16 +475,16 @@ void
 send_capabilities(struct Client *client_p, int cap_can_send)
 {
   char buf[IRCD_BUFSIZE] = "";
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, cap_list.head)
+  DLINK_FOREACH(node, cap_list.head)
   {
-    const struct Capability *cap = ptr->data;
+    const struct Capability *cap = node->data;
 
     if (cap->cap & (cap_can_send|default_server_capabs))
     {
       strlcat(buf, cap->name, sizeof(buf));
-      if (ptr->next)
+      if (node->next)
         strlcat(buf, " ", sizeof(buf));
     }
   }
@@ -505,13 +503,13 @@ const char *
 show_capabilities(const struct Client *target_p)
 {
   static char msgbuf[IRCD_BUFSIZE] = "";
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
   strlcpy(msgbuf, "TS", sizeof(msgbuf));
 
-  DLINK_FOREACH(ptr, cap_list.head)
+  DLINK_FOREACH(node, cap_list.head)
   {
-    const struct Capability *cap = ptr->data;
+    const struct Capability *cap = node->data;
 
     if (!IsCapable(target_p, cap->cap))
       continue;
@@ -572,7 +570,7 @@ serv_connect(struct MaskItem *conf, struct Client *by)
   /* Make sure conf is useful */
   assert(conf);
 
-  getnameinfo((struct sockaddr *)&conf->addr, conf->addr.ss_len,
+  getnameinfo((const struct sockaddr *)&conf->addr, conf->addr.ss_len,
               buf, sizeof(buf), NULL, 0, NI_NUMERICHOST);
   ilog(LOG_TYPE_IRCD, "Connect to %s[%s] @%s", conf->name, conf->host,
        buf);
@@ -622,7 +620,7 @@ serv_connect(struct MaskItem *conf, struct Client *by)
   strlcpy(client_p->sockhost, buf, sizeof(client_p->sockhost));
 
   /* create a socket for the server connection */
-  if (comm_open(&client_p->localClient->fd, conf->addr.ss.ss_family, SOCK_STREAM, 0, NULL) < 0)
+  if (comm_open(&client_p->connection->fd, conf->addr.ss.ss_family, SOCK_STREAM, 0, NULL) < 0)
   {
     /* Eek, failure to create the socket */
     report_error(L_ALL, "opening stream socket to %s: %s", conf->name, errno);
@@ -633,7 +631,7 @@ serv_connect(struct MaskItem *conf, struct Client *by)
   }
 
   /* servernames are always guaranteed under HOSTLEN chars */
-  fd_note(&client_p->localClient->fd, "Server: %s", conf->name);
+  fd_note(&client_p->connection->fd, "Server: %s", conf->name);
 
   /* Attach config entries to client here rather than in
    * serv_connect_callback(). This to avoid null pointer references.
@@ -641,10 +639,10 @@ serv_connect(struct MaskItem *conf, struct Client *by)
   if (!attach_connect_block(client_p, conf->name, conf->host))
   {
     sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                         "Host %s is not enabled for connecting: no connect{} block",
+                         "Host %s is not enabled for connecting: no connect {} block",
                          conf->name);
     if (by && IsClient(by) && !MyClient(by))
-      sendto_one_notice(by, &me, ":Connect to host %s failed.", client_p->name);
+      sendto_one_notice(by, &me, ":Connect to host %s failed: no connect {} block", client_p->name);
 
     SetDead(client_p);
     exit_client(client_p, "Connection failed");
@@ -665,7 +663,7 @@ serv_connect(struct MaskItem *conf, struct Client *by)
     strlcpy(client_p->serv->by, "AutoConn.", sizeof(client_p->serv->by));
 
   SetConnecting(client_p);
-  client_p->localClient->aftype = conf->aftype;
+  client_p->connection->aftype = conf->aftype;
 
   /* Now, initiate the connection */
   /* XXX assume that a non 0 type means a specific bind address
@@ -682,7 +680,7 @@ serv_connect(struct MaskItem *conf, struct Client *by)
         ipn.ss.ss_family = AF_INET;
         ipn.ss_port = 0;
         memcpy(&ipn, &conf->bind, sizeof(struct irc_ssaddr));
-        comm_connect_tcp(&client_p->localClient->fd, conf->host, conf->port,
+        comm_connect_tcp(&client_p->connection->fd, conf->host, conf->port,
                          (struct sockaddr *)&ipn, ipn.ss_len,
                          serv_connect_callback, client_p, conf->aftype,
                          CONNECTTIMEOUT);
@@ -694,13 +692,13 @@ serv_connect(struct MaskItem *conf, struct Client *by)
         ipn.ss.ss_family = AF_INET;
         ipn.ss_port = 0;
         memcpy(&ipn, &ConfigServerInfo.ip, sizeof(struct irc_ssaddr));
-        comm_connect_tcp(&client_p->localClient->fd, conf->host, conf->port,
+        comm_connect_tcp(&client_p->connection->fd, conf->host, conf->port,
                          (struct sockaddr *)&ipn, ipn.ss_len,
                          serv_connect_callback, client_p, conf->aftype,
                          CONNECTTIMEOUT);
       }
       else
-        comm_connect_tcp(&client_p->localClient->fd, conf->host, conf->port,
+        comm_connect_tcp(&client_p->connection->fd, conf->host, conf->port,
                          NULL, 0, serv_connect_callback, client_p, conf->aftype,
                          CONNECTTIMEOUT);
       break;
@@ -719,7 +717,7 @@ serv_connect(struct MaskItem *conf, struct Client *by)
           memcpy(&ipn, &conf->bind, sizeof(struct irc_ssaddr));
           ipn.ss.ss_family = AF_INET6;
           ipn.ss_port = 0;
-          comm_connect_tcp(&client_p->localClient->fd,
+          comm_connect_tcp(&client_p->connection->fd,
                            conf->host, conf->port,
                            (struct sockaddr *)&ipn, ipn.ss_len,
                            serv_connect_callback, client_p,
@@ -730,14 +728,14 @@ serv_connect(struct MaskItem *conf, struct Client *by)
           memcpy(&ipn, &ConfigServerInfo.ip6, sizeof(struct irc_ssaddr));
           ipn.ss.ss_family = AF_INET6;
           ipn.ss_port = 0;
-          comm_connect_tcp(&client_p->localClient->fd,
+          comm_connect_tcp(&client_p->connection->fd,
                            conf->host, conf->port,
                            (struct sockaddr *)&ipn, ipn.ss_len,
                            serv_connect_callback, client_p,
                            conf->aftype, CONNECTTIMEOUT);
         }
         else
-          comm_connect_tcp(&client_p->localClient->fd,
+          comm_connect_tcp(&client_p->connection->fd,
                            conf->host, conf->port,
                            NULL, 0, serv_connect_callback, client_p,
                            conf->aftype, CONNECTTIMEOUT);
@@ -753,7 +751,7 @@ finish_ssl_server_handshake(struct Client *client_p)
 {
   struct MaskItem *conf = NULL;
 
-  conf = find_conf_name(&client_p->localClient->confs,
+  conf = find_conf_name(&client_p->connection->confs,
                         client_p->name, CONF_SERVER);
   if (conf == NULL)
   {
@@ -790,7 +788,7 @@ finish_ssl_server_handshake(struct Client *client_p)
 
   /* don't move to serv_list yet -- we haven't sent a burst! */
   /* If we get here, we're ok, so lets start reading some data */
-  comm_setselect(&client_p->localClient->fd, COMM_SELECT_READ, read_packet, client_p, 0);
+  comm_setselect(&client_p->connection->fd, COMM_SELECT_READ, read_packet, client_p, 0);
 }
 
 static void
@@ -800,17 +798,23 @@ ssl_server_handshake(fde_t *fd, void *data)
   X509 *cert = NULL;
   int ret = 0;
 
-  if ((ret = SSL_connect(client_p->localClient->fd.ssl)) <= 0)
+  if ((ret = SSL_connect(client_p->connection->fd.ssl)) <= 0)
   {
-    switch (SSL_get_error(client_p->localClient->fd.ssl, ret))
+    if ((CurrentTime - client_p->connection->firsttime) > CONNECTTIMEOUT)
+    {
+      exit_client(client_p, "Timeout during SSL handshake");
+      return;
+    }
+
+    switch (SSL_get_error(client_p->connection->fd.ssl, ret))
     {
       case SSL_ERROR_WANT_WRITE:
-        comm_setselect(&client_p->localClient->fd, COMM_SELECT_WRITE,
-                       ssl_server_handshake, client_p, 0);
+        comm_setselect(&client_p->connection->fd, COMM_SELECT_WRITE,
+                       ssl_server_handshake, client_p, CONNECTTIMEOUT);
         return;
       case SSL_ERROR_WANT_READ:
-        comm_setselect(&client_p->localClient->fd, COMM_SELECT_READ,
-                       ssl_server_handshake, client_p, 0);
+        comm_setselect(&client_p->connection->fd, COMM_SELECT_READ,
+                       ssl_server_handshake, client_p, CONNECTTIMEOUT);
         return;
       default:
       {
@@ -824,9 +828,11 @@ ssl_server_handshake(fde_t *fd, void *data)
     }
   }
 
-  if ((cert = SSL_get_peer_certificate(client_p->localClient->fd.ssl)))
+  comm_settimeout(&client_p->connection->fd, 0, NULL, NULL);
+
+  if ((cert = SSL_get_peer_certificate(client_p->connection->fd.ssl)))
   {
-    int res = SSL_get_verify_result(client_p->localClient->fd.ssl);
+    int res = SSL_get_verify_result(client_p->connection->fd.ssl);
     char buf[EVP_MAX_MD_SIZE * 2 + 1] = "";
     unsigned char md[EVP_MAX_MD_SIZE] = "";
 
@@ -854,7 +860,7 @@ ssl_server_handshake(fde_t *fd, void *data)
 static void
 ssl_connect_init(struct Client *client_p, struct MaskItem *conf, fde_t *fd)
 {
-  if ((client_p->localClient->fd.ssl = SSL_new(ConfigServerInfo.client_ctx)) == NULL)
+  if ((client_p->connection->fd.ssl = SSL_new(ConfigServerInfo.client_ctx)) == NULL)
   {
     ilog(LOG_TYPE_IRCD, "SSL_new() ERROR! -- %s",
          ERR_error_string(ERR_get_error(), NULL));
@@ -866,7 +872,7 @@ ssl_connect_init(struct Client *client_p, struct MaskItem *conf, fde_t *fd)
   SSL_set_fd(fd->ssl, fd->fd);
 
   if (!EmptyString(conf->cipher_list))
-    SSL_set_cipher_list(client_p->localClient->fd.ssl, conf->cipher_list);
+    SSL_set_cipher_list(client_p->connection->fd.ssl, conf->cipher_list);
 
   ssl_server_handshake(NULL, client_p);
 }
@@ -888,10 +894,10 @@ serv_connect_callback(fde_t *fd, int status, void *data)
 
   /* First, make sure it's a real client! */
   assert(client_p);
-  assert(&client_p->localClient->fd == fd);
+  assert(&client_p->connection->fd == fd);
 
   /* Next, for backward purposes, record the ip of the server */
-  memcpy(&client_p->localClient->ip, &fd->connect.hostaddr,
+  memcpy(&client_p->connection->ip, &fd->connect.hostaddr,
          sizeof(struct irc_ssaddr));
 
   /* Check the status */
@@ -922,7 +928,7 @@ serv_connect_callback(fde_t *fd, int status, void *data)
 
   /* COMM_OK, so continue the connection procedure */
   /* Get the C/N lines */
-  conf = find_conf_name(&client_p->localClient->confs,
+  conf = find_conf_name(&client_p->connection->confs,
                         client_p->name, CONF_SERVER);
   if (conf == NULL)
   {
