@@ -1,7 +1,7 @@
 /*
  *  ircd-hybrid: an advanced, lightweight Internet Relay Chat Daemon (ircd)
  *
- *  Copyright (c) 1997-2014 ircd-hybrid development team
+ *  Copyright (c) 1997-2015 ircd-hybrid development team
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,9 +19,9 @@
  *  USA
  */
 
-/*! \file s_user.c
+/*! \file user.c
  * \brief User related functions.
- * \version $Id: user.c 4564 2014-08-24 10:24:47Z michael $
+ * \version $Id: user.c 5785 2015-04-05 15:17:51Z michael $
  */
 
 #include "stdinc.h"
@@ -65,89 +65,50 @@ struct Isupport
 static dlink_list support_list;
 static dlink_list support_list_lines;
 
-/* memory is cheap. map 0-255 to equivalent mode */
-const unsigned int user_modes[256] =
+const struct user_modes *umode_map[256];
+const struct user_modes  umode_tab[] =
 {
-  /* 0x00 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0x0F */
-  /* 0x10 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0x1F */
-  /* 0x20 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0x2F */
-  /* 0x30 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0x3F */
-  0,                  /* @ */
-  0,                  /* A */
-  0,                  /* B */
-  0,                  /* C */
-  UMODE_DEAF,         /* D */
-  0,                  /* E */
-  UMODE_FARCONNECT,   /* F */
-  UMODE_SOFTCALLERID, /* G */
-  UMODE_HIDDEN,       /* H */
-  0,                  /* I */
-  0,                  /* J */
-  0,                  /* K */
-  0,                  /* L */
-  0,                  /* M */
-  0,                  /* N */
-  0,                  /* O */
-  0,                  /* P */
-  0,                  /* Q */
-  UMODE_REGONLY,      /* R */
-  UMODE_SSL,          /* S */
-  0,                  /* T */
-  0,                  /* U */
-  0,                  /* V */
-  UMODE_WEBIRC,       /* W */
-  0,                  /* X */
-  0,                  /* Y */
-  0,                  /* Z 0x5A */
-  0, 0, 0, 0, 0,      /* 0x5F   */
-  0,                  /* 0x60   */
-  UMODE_ADMIN,        /* a */
-  UMODE_BOTS,         /* b */
-  UMODE_CCONN,        /* c */
-  UMODE_DEBUG,        /* d */
-  UMODE_EXTERNAL,     /* e */
-  UMODE_FULL,         /* f */
-  UMODE_CALLERID,     /* g */
-  0,                  /* h */
-  UMODE_INVISIBLE,    /* i */
-  UMODE_REJ,          /* j */
-  UMODE_SKILL,        /* k */
-  UMODE_LOCOPS,       /* l */
-  0,                  /* m */
-  UMODE_NCHANGE,      /* n */
-  UMODE_OPER,         /* o */
-  UMODE_HIDECHANS,    /* p */
-  UMODE_HIDEIDLE,     /* q */
-  UMODE_REGISTERED,   /* r */
-  UMODE_SERVNOTICE,   /* s */
-  0,                  /* t */
-  UMODE_UNAUTH,       /* u */
-  0,                  /* v */
-  UMODE_WALLOP,       /* w */
-  UMODE_HIDDENHOST,   /* x */
-  UMODE_SPY,          /* y */
-  0,                  /* z      0x7A */
-  0,0,0,0,0,          /* 0x7B - 0x7F */
-
-  /* 0x80 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0x8F */
-  /* 0x90 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0x9F */
-  /* 0xA0 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0xAF */
-  /* 0xB0 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0xBF */
-  /* 0xC0 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0xCF */
-  /* 0xD0 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0xDF */
-  /* 0xE0 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0, /* 0xEF */
-  /* 0xF0 */ 0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0  /* 0xFF */
+  { 'D', UMODE_DEAF         },
+  { 'F', UMODE_FARCONNECT   },
+  { 'G', UMODE_SOFTCALLERID },
+  { 'H', UMODE_HIDDEN       },
+  { 'R', UMODE_REGONLY      },
+  { 'S', UMODE_SSL          },
+  { 'W', UMODE_WEBIRC       },
+  { 'a', UMODE_ADMIN        },
+  { 'b', UMODE_BOTS         },
+  { 'c', UMODE_CCONN        },
+  { 'd', UMODE_DEBUG        },
+  { 'e', UMODE_EXTERNAL     },
+  { 'f', UMODE_FULL         },
+  { 'g', UMODE_CALLERID     },
+  { 'i', UMODE_INVISIBLE    },
+  { 'j', UMODE_REJ          },
+  { 'k', UMODE_SKILL        },
+  { 'l', UMODE_LOCOPS       },
+  { 'n', UMODE_NCHANGE      },
+  { 'o', UMODE_OPER         },
+  { 'p', UMODE_HIDECHANS    },
+  { 'q', UMODE_HIDEIDLE     },
+  { 'r', UMODE_REGISTERED   },
+  { 's', UMODE_SERVNOTICE   },
+  { 'u', UMODE_UNAUTH       },
+  { 'w', UMODE_WALLOP       },
+  { 'x', UMODE_HIDDENHOST   },
+  { 'y', UMODE_SPY          },
+  { '\0', 0 }
 };
 
 void
-assemble_umode_buffer(void)
+user_usermodes_init(void)
 {
-  unsigned int idx = 0;
   char *umode_buffer_ptr = umode_buffer;
 
-  for (; idx < (sizeof(user_modes) / sizeof(user_modes[0])); ++idx)
-    if (user_modes[idx])
-      *umode_buffer_ptr++ = idx;
+  for (const struct user_modes *tab = umode_tab; tab->c; ++tab)
+  {
+    umode_map[tab->c] = tab;
+    *umode_buffer_ptr++ = tab->c;
+  }
 
   *umode_buffer_ptr = '\0';
 }
@@ -162,11 +123,11 @@ void
 show_lusers(struct Client *source_p)
 {
   if (!ConfigServerHide.hide_servers || HasUMode(source_p, UMODE_OPER))
-    sendto_one_numeric(source_p, &me, RPL_LUSERCLIENT, (Count.total-Count.invisi),
+    sendto_one_numeric(source_p, &me, RPL_LUSERCLIENT, (Count.total - Count.invisi),
                        Count.invisi, dlink_list_length(&global_server_list));
   else
-    sendto_one_numeric(source_p, &me, RPL_LUSERCLIENT,
-                       (Count.total - Count.invisi), Count.invisi, 1);
+    sendto_one_numeric(source_p, &me, RPL_LUSERCLIENT, (Count.total - Count.invisi),
+                       Count.invisi, 1);
 
   if (Count.oper)
     sendto_one_numeric(source_p, &me, RPL_LUSEROP, Count.oper);
@@ -210,10 +171,10 @@ show_lusers(struct Client *source_p)
 void
 show_isupport(struct Client *source_p)
 {
-  const dlink_node *ptr = NULL;
+  const dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, support_list_lines.head)
-    sendto_one_numeric(source_p, &me, RPL_ISUPPORT, ptr->data);
+  DLINK_FOREACH(node, support_list_lines.head)
+    sendto_one_numeric(source_p, &me, RPL_ISUPPORT, node->data);
 }
 
 
@@ -232,7 +193,7 @@ report_and_set_user_flags(struct Client *source_p, const struct MaskItem *conf)
   if (IsConfDoSpoofIp(conf))
     sendto_one_notice(source_p, &me, ":*** Spoofing your IP. Congrats.");
 
-  /* If this user is in the exception class, Set it "E lined" */
+  /* If this user is in the exception class, set it "E lined" */
   if (IsConfExemptKline(conf))
   {
     SetExemptKline(source_p);
@@ -281,7 +242,7 @@ report_and_set_user_flags(struct Client *source_p, const struct MaskItem *conf)
 static void
 introduce_client(struct Client *source_p)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
   char ubuf[IRCD_BUFSIZE] = "";
 
   if (MyClient(source_p))
@@ -297,31 +258,29 @@ introduce_client(struct Client *source_p)
     ubuf[1] = '\0';
   }
 
-  DLINK_FOREACH(ptr, local_server_list.head)
+  DLINK_FOREACH(node, local_server_list.head)
   {
-    struct Client *server = ptr->data;
+    struct Client *server = node->data;
 
     if (server == source_p->from)
       continue;
 
     if (IsCapable(server, CAP_SVS))
-      sendto_one(server, ":%s UID %s %d %lu %s %s %s %s %s %s :%s",
+      sendto_one(server, ":%s UID %s %u %lu %s %s %s %s %s %s :%s",
                  source_p->servptr->id,
                  source_p->name, source_p->hopcount+1,
                  (unsigned long)source_p->tsinfo,
                  ubuf, source_p->username, source_p->host,
-                 (MyClient(source_p) && IsIPSpoof(source_p)) ?
-                 "0" : source_p->sockhost, source_p->id,
-                 source_p->svid,
+                 source_p->sockhost, source_p->id,
+                 source_p->account,
                  source_p->info);
     else
-      sendto_one(server, ":%s UID %s %d %lu %s %s %s %s %s :%s",
+      sendto_one(server, ":%s UID %s %u %lu %s %s %s %s %s :%s",
                  source_p->servptr->id,
                  source_p->name, source_p->hopcount+1,
                  (unsigned long)source_p->tsinfo,
                  ubuf, source_p->username, source_p->host,
-                 (MyClient(source_p) && IsIPSpoof(source_p)) ?
-                 "0" : source_p->sockhost, source_p->id, source_p->info);
+                 source_p->sockhost, source_p->id, source_p->info);
 
     if (!EmptyString(source_p->certfp))
       sendto_one(server, ":%s CERTFP %s", source_p->id, source_p->certfp);
@@ -348,14 +307,14 @@ user_welcome(struct Client *source_p)
   {
     AddUMode(source_p, UMODE_SSL);
     sendto_one_notice(source_p, &me, ":*** Connected securely via %s",
-                      ssl_get_cipher(source_p->localClient->fd.ssl));
+                      ssl_get_cipher(source_p->connection->fd.ssl));
   }
 #endif
 
   sendto_one_numeric(source_p, &me, RPL_WELCOME, ConfigServerInfo.network_name,
                      source_p->name);
   sendto_one_numeric(source_p, &me, RPL_YOURHOST,
-                     get_listener_name(source_p->localClient->listener), ircd_version);
+                     get_listener_name(source_p->connection->listener), ircd_version);
   sendto_one_numeric(source_p, &me, RPL_CREATED, built_date);
   sendto_one_numeric(source_p, &me, RPL_MYINFO, me.name, ircd_version, umode_buffer);
   show_isupport(source_p);
@@ -375,20 +334,13 @@ static int
 check_xline(struct Client *source_p)
 {
   struct MaskItem *conf = NULL;
-  const char *reason = NULL;
 
   if ((conf = find_matching_name_conf(CONF_XLINE, source_p->info, NULL, NULL, 0)))
   {
     ++conf->count;
-
-    if (conf->reason)
-      reason = conf->reason;
-    else
-      reason = CONF_NOREASON;
-
     sendto_realops_flags(UMODE_REJ, L_ALL, SEND_NOTICE,
                          "X-line Rejecting [%s] [%s], user %s [%s]",
-                         source_p->info, reason,
+                         source_p->info, conf->reason,
                          get_client_name(source_p, HIDE_IP),
                          source_p->sockhost);
 
@@ -413,20 +365,18 @@ register_local_user(struct Client *source_p)
 
   assert(source_p == source_p->from);
   assert(MyConnect(source_p));
-  assert(!source_p->localClient->registration);
-
-  ClearCap(source_p, CAP_TS6);
+  assert(IsUnknown(source_p));
+  assert(!source_p->connection->registration);
 
   if (ConfigGeneral.ping_cookie)
   {
-    if (!IsPingSent(source_p) && !source_p->localClient->random_ping)
+    if (!IsPingSent(source_p) && !source_p->connection->random_ping)
     {
       do
-        source_p->localClient->random_ping = genrand_int32();
-      while (!source_p->localClient->random_ping);
+        source_p->connection->random_ping = genrand_int32();
+      while (!source_p->connection->random_ping);
 
-      sendto_one(source_p, "PING :%u",
-                 source_p->localClient->random_ping);
+      sendto_one(source_p, "PING :%u", source_p->connection->random_ping);
       SetPingSent(source_p);
       return;
     }
@@ -435,9 +385,9 @@ register_local_user(struct Client *source_p)
       return;
   }
 
-  source_p->localClient->last_privmsg = CurrentTime;
+  source_p->connection->last_privmsg = CurrentTime;
   /* Straight up the maximum rate of flooding... */
-  source_p->localClient->allow_read = MAX_FLOOD_BURST;
+  source_p->connection->allow_read = MAX_FLOOD_BURST;
 
   if (!check_client(source_p))
     return;
@@ -446,11 +396,10 @@ register_local_user(struct Client *source_p)
   {
     sendto_one_notice(source_p, &me, ":*** Notice -- You have an illegal "
                       "character in your hostname");
-    strlcpy(source_p->host, source_p->sockhost,
-            sizeof(source_p->host));
+    strlcpy(source_p->host, source_p->sockhost, sizeof(source_p->host));
   }
 
-  conf = source_p->localClient->confs.head->data;
+  conf = source_p->connection->confs.head->data;
 
   if (!IsGotId(source_p))
   {
@@ -481,7 +430,7 @@ register_local_user(struct Client *source_p)
   /* Password check */
   if (!EmptyString(conf->passwd))
   {
-    if (!match_conf_password(source_p->localClient->password, conf))
+    if (!match_conf_password(source_p->connection->password, conf))
     {
       ++ServerStats.is_ref;
 
@@ -492,8 +441,8 @@ register_local_user(struct Client *source_p)
   }
 
   /*
-   * Don't free source_p->localClient->password here - it can be required
-   * by masked /stats I if there are auth{} blocks with need_password = no;
+   * Don't free source_p->connection->password here - it can be required
+   * by masked /stats I if there are auth {} blocks with need_password = no;
    * --adx
    */
 
@@ -513,8 +462,8 @@ register_local_user(struct Client *source_p)
    * probably be just a percentage of the MAXCLIENTS...
    *   -Taner
    */
-  if ((Count.local >= ConfigServerInfo.max_clients + MAX_BUFFER) ||
-      (Count.local >= ConfigServerInfo.max_clients && !IsExemptLimits(source_p)))
+  if ((Count.local >= GlobalSetOptions.maxclients + MAX_BUFFER) ||
+      (Count.local >= GlobalSetOptions.maxclients && !IsExemptLimits(source_p)))
   {
     sendto_realops_flags(UMODE_FULL, L_ALL, SEND_NOTICE,
                          "Too many clients, rejecting %s[%s].",
@@ -549,9 +498,8 @@ register_local_user(struct Client *source_p)
   sendto_realops_flags(UMODE_CCONN, L_ALL, SEND_NOTICE,
                        "Client connecting: %s (%s@%s) [%s] {%s} [%s] <%s>",
                        source_p->name, source_p->username, source_p->host,
-                       ConfigGeneral.hide_spoof_ips && IsIPSpoof(source_p) ?
-                       "255.255.255.255" : source_p->sockhost,
-                       get_client_class(&source_p->localClient->confs),
+                       source_p->sockhost,
+                       get_client_class(&source_p->connection->confs),
                        source_p->info, source_p->id);
 
   if (ConfigGeneral.invisible_on_connect)
@@ -566,7 +514,7 @@ register_local_user(struct Client *source_p)
 
     if (!(Count.max_loc % 10))
       sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE,
-                           "New Max Local Clients: %d",
+                           "New maximum local client connections: %u",
                            Count.max_loc);
   }
 
@@ -581,7 +529,7 @@ register_local_user(struct Client *source_p)
 
   assert(dlinkFind(&unknown_list, source_p));
 
-  dlink_move_node(&source_p->localClient->lclient_node,
+  dlink_move_node(&source_p->connection->lclient_node,
                   &unknown_list, &local_client_list);
 
   user_welcome(source_p);
@@ -614,12 +562,12 @@ register_remote_user(struct Client *source_p)
                          source_p->host, source_p->servptr->name,
                          target_p->name, target_p->from->name);
     sendto_one(source_p->from,
-               ":%s KILL %s :%s (NICK from wrong direction (%s != %s))",
+               ":%s KILL %s :%s (UID from wrong direction (%s != %s))",
                me.id, source_p->id, me.name, source_p->servptr->name,
                target_p->from->name);
 
     AddFlag(source_p, FLAGS_KILLED);
-    exit_client(source_p, "USER server wrong direction");
+    exit_client(source_p, "UID server wrong direction");
     return;
   }
 
@@ -641,10 +589,10 @@ register_remote_user(struct Client *source_p)
 
   if (HasFlag(source_p->servptr, FLAGS_EOB))
     sendto_realops_flags(UMODE_FARCONNECT, L_ALL, SEND_NOTICE,
-                         "Client connecting at %s: %s (%s@%s) [%s] <%s>",
+                         "Client connecting at %s: %s (%s@%s) [%s] [%s] <%s>",
                          source_p->servptr->name,
                          source_p->name, source_p->username, source_p->host,
-                         source_p->info, source_p->id);
+                         source_p->sockhost, source_p->info, source_p->id);
 
   introduce_client(source_p);
 }
@@ -742,12 +690,12 @@ valid_nickname(const char *nickname, const int local)
 {
   const char *p = nickname;
 
-  assert(nickname && *nickname);
+  assert(p);
 
   /*
    * Nicks can't start with a digit or - or be 0 length.
    */
-  if (*p == '-' || (IsDigit(*p) && local) || *p == '\0')
+  if (EmptyString(p) || *p == '-' || (IsDigit(*p) && local))
     return 0;
 
   for (; *p; ++p)
@@ -779,33 +727,28 @@ send_umode(struct Client *client_p, struct Client *source_p,
    * Build a string in umode_buf to represent the change in the user's
    * mode between the new (source_p->umodes) and 'old'.
    */
-  for (unsigned int i = 0; i < 128; ++i)
+  for (const struct user_modes *tab = umode_tab; tab->c; ++tab)
   {
-    unsigned int flag = user_modes[i];
-
-    if (!flag)
-      continue;
-
-    if ((flag & old) && !HasUMode(source_p, flag))
+    if ((tab->flag & old) && !HasUMode(source_p, tab->flag))
     {
       if (what == MODE_DEL)
-        *m++ = (char)i;
+        *m++ = tab->c;
       else
       {
         what = MODE_DEL;
         *m++ = '-';
-        *m++ = (char)i;
+        *m++ = tab->c;
       }
     }
-    else if (!(flag & old) && HasUMode(source_p, flag))
+    else if (!(tab->flag & old) && HasUMode(source_p, tab->flag))
     {
       if (what == MODE_ADD)
-        *m++ = (char)i;
+        *m++ = tab->c;
       else
       {
         what = MODE_ADD;
         *m++ = '+';
-        *m++ = (char)i;
+        *m++ = tab->c;
       }
     }
   }
@@ -814,8 +757,8 @@ send_umode(struct Client *client_p, struct Client *source_p,
 
   if (*umode_buf && client_p)
     sendto_one(client_p, ":%s!%s@%s MODE %s :%s",
-               source_p->name, source_p->username,
-               source_p->host, source_p->name, umode_buf);
+               client_p->name, client_p->username,
+               client_p->host, client_p->name, umode_buf);
 }
 
 /* send_umode_out()
@@ -825,25 +768,21 @@ send_umode(struct Client *client_p, struct Client *source_p,
  * side effects - Only send ubuf out to servers that know about this client
  */
 void
-send_umode_out(struct Client *client_p, struct Client *source_p,
-               unsigned int old)
+send_umode_out(struct Client *source_p, unsigned int old)
 {
   char buf[IRCD_BUFSIZE] = "";
 
-  send_umode(NULL, source_p, old, buf);
+  send_umode(MyClient(source_p) ? source_p : NULL, source_p, old, buf);
 
   if (buf[0])
-    sendto_server(source_p, NOCAPS, NOCAPS, ":%s MODE %s :%s",
+    sendto_server(source_p, 0, 0, ":%s MODE %s :%s",
                   source_p->id, source_p->id, buf);
-
-  if (client_p && MyClient(client_p))
-    send_umode(client_p, source_p, old, buf);
 }
 
 void
 user_set_hostmask(struct Client *target_p, const char *hostname, const int what)
 {
-  dlink_node *ptr = NULL;
+  dlink_node *node = NULL;
 
   if (!strcmp(target_p->host, hostname))
     return;
@@ -852,13 +791,9 @@ user_set_hostmask(struct Client *target_p, const char *hostname, const int what)
   {
     case MODE_ADD:
       AddUMode(target_p, UMODE_HIDDENHOST);
-      AddFlag(target_p, FLAGS_IP_SPOOFING);
       break;
     case MODE_DEL:
       DelUMode(target_p, UMODE_HIDDENHOST);
-
-      if (!HasFlag(target_p, FLAGS_AUTH_SPOOF))
-        DelFlag(target_p, FLAGS_IP_SPOOFING);
       break;
     default: return;
   }
@@ -884,26 +819,26 @@ user_set_hostmask(struct Client *target_p, const char *hostname, const int what)
   if (!ConfigGeneral.cycle_on_host_change)
     return;
 
-  DLINK_FOREACH(ptr, target_p->channel.head)
+  DLINK_FOREACH(node, target_p->channel.head)
   {
     char modebuf[4], nickbuf[NICKLEN * 3 + 3] = "";
     char *p = modebuf;
     int len = 0;
-    const struct Membership *ms = ptr->data;
+    const struct Membership *member = node->data;
 
-    if (has_member_flags(ms, CHFL_CHANOP))
+    if (has_member_flags(member, CHFL_CHANOP))
     {
       *p++ = 'o';
       len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", target_p->name);
     }
 
-    if (has_member_flags(ms, CHFL_HALFOP))
+    if (has_member_flags(member, CHFL_HALFOP))
     {
       *p++ = 'h';
       len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", target_p->name);
     }
 
-    if (has_member_flags(ms, CHFL_VOICE))
+    if (has_member_flags(member, CHFL_VOICE))
     {
       *p++ = 'v';
       len += snprintf(nickbuf + len, sizeof(nickbuf) - len, len ? " %s" : "%s", target_p->name);
@@ -911,12 +846,19 @@ user_set_hostmask(struct Client *target_p, const char *hostname, const int what)
 
     *p = '\0';
 
-    sendto_channel_local_butone(target_p, 0, 0, ms->chptr, ":%s!%s@%s JOIN :%s",
-                                target_p->name, target_p->username, target_p->host,
-                                ms->chptr->chname);
+
+    sendto_channel_local_butone(target_p, CAP_EXTENDED_JOIN, 0, member->chptr, ":%s!%s@%s JOIN %s %s :%s",
+                                target_p->name, target_p->username,
+                                target_p->host, member->chptr->name,
+                                (!IsDigit(target_p->account[0]) && target_p->account[0] != '*') ? target_p->account : "*",
+                                target_p->info);
+    sendto_channel_local_butone(target_p, 0, CAP_EXTENDED_JOIN, member->chptr, ":%s!%s@%s JOIN :%s",
+                                target_p->name, target_p->username,
+                                target_p->host, member->chptr->name);
+
     if (nickbuf[0])
-      sendto_channel_local_butone(target_p, 0, 0, ms->chptr, ":%s MODE %s +%s %s",
-                                  target_p->servptr->name, ms->chptr->chname,
+      sendto_channel_local_butone(target_p, 0, 0, member->chptr, ":%s MODE %s +%s %s",
+                                  target_p->servptr->name, member->chptr->name,
                                   modebuf, nickbuf);
 
   }
@@ -936,9 +878,9 @@ void
 oper_up(struct Client *source_p)
 {
   const unsigned int old = source_p->umodes;
-  const struct MaskItem *conf = source_p->localClient->confs.head->data;
+  const struct MaskItem *const conf = source_p->connection->confs.head->data;
 
-  assert(source_p->localClient->confs.head);
+  assert(source_p->connection->confs.head);
 
   ++Count.oper;
   SetOper(source_p);
@@ -961,11 +903,19 @@ oper_up(struct Client *source_p)
   if (HasOFlag(source_p, OPER_FLAG_ADMIN))
     AddUMode(source_p, UMODE_ADMIN);
 
+  if (!EmptyString(conf->whois))
+  {
+    client_attach_svstag(source_p, RPL_WHOISOPERATOR, "+", conf->whois);
+    sendto_server(source_p, 0, 0, ":%s SVSTAG %s %lu %u + :%s",
+                  me.id, source_p->id, (unsigned long)source_p->tsinfo,
+                  RPL_WHOISOPERATOR, conf->whois);
+  }
+
   sendto_realops_flags(UMODE_ALL, L_ALL, SEND_NOTICE, "%s is now an operator",
                        get_oper_name(source_p));
-  sendto_server(NULL, NOCAPS, NOCAPS, ":%s GLOBOPS :%s is now an operator",
+  sendto_server(NULL, 0, 0, ":%s GLOBOPS :%s is now an operator",
                 me.id, get_oper_name(source_p));
-  send_umode_out(source_p, source_p, old);
+  send_umode_out(source_p, old);
   sendto_one_numeric(source_p, &me, RPL_YOUREOPER);
 }
 
@@ -988,23 +938,14 @@ valid_sid(const char *sid)
  * inputs	- NONE
  * output	- NONE
  * side effects	- new_uid is filled in with server id portion (sid)
- *		  (first 3 bytes) or defaulted to 'A'.
- *	          Rest is filled in with 'A'
+ *		  (first 3 bytes). Rest is filled in with '9'.
+ *
+ * NOTE: this function assumes that 'ConfigServerInfo.sid' has been set to a proper value
  */
 void
 init_uid(void)
 {
-  memset(new_uid, 0, sizeof(new_uid));
-
-  if (!EmptyString(ConfigServerInfo.sid))
-    strlcpy(new_uid, ConfigServerInfo.sid, sizeof(new_uid));
-
-  for (unsigned int i = 0; i < IRC_MAXSID; ++i)
-    if (new_uid[i] == '\0')
-      new_uid[i] = 'A';
-
-  /* NOTE: if IRC_MAXUID != 6, this will have to be rewritten */
-  memcpy(new_uid + IRC_MAXSID, "AAAAA@", IRC_MAXUID);
+  snprintf(new_uid, sizeof(new_uid), "%s999999", ConfigServerInfo.sid);
 }
 
 /*
@@ -1018,26 +959,18 @@ init_uid(void)
 static void
 add_one_to_uid(unsigned int i)
 {
-  if (i != IRC_MAXSID)  /* Not reached server SID portion yet? */
+  if (i < IRC_MAXSID)
+    return;
+
+  if (new_uid[i] == 'Z')
+    new_uid[i] = '0';
+  else if (new_uid[i] == '9')
   {
-    if (new_uid[i] == 'Z')
-      new_uid[i] = '0';
-    else if (new_uid[i] == '9')
-    {
-      new_uid[i] = 'A';
-      add_one_to_uid(i - 1);
-    }
-    else
-      ++new_uid[i];
+    new_uid[i] = 'A';
+    add_one_to_uid(i - 1);
   }
   else
-  {
-    /* NOTE: if IRC_MAXUID != 6, this will have to be rewritten */
-    if (new_uid[i] == 'Z')
-      memcpy(new_uid + IRC_MAXSID, "AAAAAA", IRC_MAXUID);
-    else
-      ++new_uid[i];
-  }
+    ++new_uid[i];
 }
 
 /*
@@ -1071,8 +1004,8 @@ init_isupport(void)
   add_isupport("MODES", NULL, MAXMODEPARAMS);
   add_isupport("PREFIX", "(ohv)@%+", -1);
   add_isupport("STATUSMSG", "@%+", -1);
-  add_isupport("EXCEPTS", "e", -1);
-  add_isupport("INVEX", "I", -1);
+  add_isupport("EXCEPTS", NULL, -1);
+  add_isupport("INVEX", NULL, -1);
 }
 
 /*
@@ -1087,12 +1020,12 @@ init_isupport(void)
 void
 add_isupport(const char *name, const char *options, int n)
 {
-  dlink_node *ptr;
+  dlink_node *node = NULL;
   struct Isupport *support = NULL;
 
-  DLINK_FOREACH(ptr, support_list.head)
+  DLINK_FOREACH(node, support_list.head)
   {
-    support = ptr->data;
+    support = node->data;
     if (irccmp(support->name, name) == 0)
     {
       MyFree(support->name);
@@ -1101,7 +1034,7 @@ add_isupport(const char *name, const char *options, int n)
     }
   }
 
-  if (ptr == NULL)
+  if (node == NULL)
   {
     support = MyCalloc(sizeof(*support));
     dlinkAddTail(support, &support->node, &support_list);
@@ -1125,15 +1058,15 @@ add_isupport(const char *name, const char *options, int n)
 void
 delete_isupport(const char *name)
 {
-  dlink_node *ptr;
-  struct Isupport *support;
+  dlink_node *node = NULL;
 
-  DLINK_FOREACH(ptr, support_list.head)
+  DLINK_FOREACH(node, support_list.head)
   {
-    support = ptr->data;
+    struct Isupport *support = node->data;
+
     if (irccmp(support->name, name) == 0)
     {
-      dlinkDelete(ptr, &support_list);
+      dlinkDelete(node, &support_list);
       MyFree(support->name);
       MyFree(support->options);
       MyFree(support);
@@ -1156,22 +1089,22 @@ rebuild_isupport_message_line(void)
 {
   char isupportbuffer[IRCD_BUFSIZE];
   char *p = isupportbuffer;
-  dlink_node *ptr = NULL, *ptr_next = NULL;
+  dlink_node *node = NULL, *node_next = NULL;
   int n = 0;
   int tokens = 0;
   size_t len = 0;
   size_t reserve = strlen(me.name) + HOSTLEN + strlen(numeric_form(RPL_ISUPPORT));
 
-  DLINK_FOREACH_SAFE(ptr, ptr_next, support_list_lines.head)
+  DLINK_FOREACH_SAFE(node, node_next, support_list_lines.head)
   {
-    dlinkDelete(ptr, &support_list_lines);
-    MyFree(ptr->data);
-    free_dlink_node(ptr);
+    dlinkDelete(node, &support_list_lines);
+    MyFree(node->data);
+    free_dlink_node(node);
   }
 
-  DLINK_FOREACH(ptr, support_list.head)
+  DLINK_FOREACH(node, support_list.head)
   {
-    struct Isupport *support = ptr->data;
+    struct Isupport *support = node->data;
 
     p += (n = sprintf(p, "%s", support->name));
     len += n;
