@@ -9,7 +9,7 @@
 ** /dev/random for salt generation added by 
 ** Aaron Sethman <androsyn@ratbox.org>
 **
-** $Id: mkpasswd.c 3126 2014-03-09 20:10:33Z michael $
+** $Id: mkpasswd.c 5009 2014-12-09 14:37:06Z michael $
 */
 
 #include <stdio.h>
@@ -133,7 +133,7 @@ main(int argc, char *argv[])
   {
     if (flag & FLAG_SALT)
     {
-      if ((strlen(saltpara) == 2))
+      if (strlen(saltpara) == 2)
         salt = saltpara;
       else
       {
@@ -176,7 +176,7 @@ main(int argc, char *argv[])
     /* XXX - rounds needs to be done */
     if (flag & FLAG_SALT)
     {
-      if ((strlen(saltpara) == 4))
+      if (strlen(saltpara) == 4)
       {
         salt = make_ext_salt_para(rounds, saltpara);
       }
